"""SI Bunch-by-bunch feedback system configuration."""
from copy import deepcopy as _dcopy
import numpy as _np

_ZERO_INT = 0
_ZERO_FLOAT = 0.0
_EMPTY_NDARRAY_INT = _np.zeros(32)
_EMPTY_STR = ''


def get_dict():
    """Return configuration type dictionary."""
    module_name = __name__.split('.')[-1]
    _dict = {
        'config_type_name': module_name,
        'value': _dcopy(_template_dict),
        'check': False,
    }
    return _dict


# When using this type of configuration to set the machine,
# the list of PVs should be processed in the same order they are stored
# in the configuration. The second numeric parameter in the pair is the
# delay [s] the client should wait before setting the next PV.


_pvs_bbb_proc_h = [
    ['SI-Glob:DI-BbBProc-H:GDEN', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FBCTRL', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SETSEL', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:DELAY', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:CLKRST', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SHIFTGAIN', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:PROC_DS', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:COEFF', _EMPTY_NDARRAY_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:CSET0', _EMPTY_NDARRAY_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:CSET1', _EMPTY_NDARRAY_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:LDSET', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:DESC_COEFF', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-H:DESC_CSET0', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-H:DESC_CSET1', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-H:FID_DELAY', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FLT_GAIN', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FLT_PHASE', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FLT_FREQ', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FLT_TAPS', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FTF_TUNE', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA31', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA30', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA29', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA28', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA27', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA26', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA25', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA24', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA23', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA22', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA21', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA20', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA19', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA18', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA17', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA16', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA15', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA14', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA13', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA12', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA11', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA10', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA9', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA8', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA7', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA6', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA5', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA4', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA3', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA2', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA1', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DATA0', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR31', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR30', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR29', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR28', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR27', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR26', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR25', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR24', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR23', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR22', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR21', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR20', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR19', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR18', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR17', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR16', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR15', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR14', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR13', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR12', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR11', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR10', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR9', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR8', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR7', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR6', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR5', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR4', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR3', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR2', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR1', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_DIR0', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:DRIVE_FREQ', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:DRIVE_AMPL', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:DRIVE_SPAN', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:DRIVE_PERIOD', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:DRIVE_WAVEFORM', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:DRIVE_PATTERN', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-H:DRIVE_MASK', _EMPTY_NDARRAY_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FE_PHASE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FE_ATTEN', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:BE_PHASE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:BE_ATTEN', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:TADC', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:TDAC', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:OFF_FIDC', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:OFF_FIDS', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:OFF_DAC', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:DEL_CAL', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:PHASE_SERVO_OFFSET', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:PHASE_SERVO_SETPT', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:PHASE_SERVO_MAXDELTA', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:PHASE_SERVO_GAIN', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:PHASE_SERVO_MODE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:PHASE_SERVO_SIGN', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:GPIO_SEL', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SAT_THRESHOLD', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FB_PATTERN', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-H:FB_MASK', _EMPTY_NDARRAY_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:CLEAN_TUNE', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:CLEAN_AMPL', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:CLEAN_PATTERN', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-H:CLEAN_ENABLE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:CLEAN_RENABLE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:CLEAN_SAVE_FREQ', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:CLEAN_SAVE_AMPL', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:CLEAN_SAVE_DRV_PATTERN', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-H:CLEAN_SAVE_FB_PATTERN', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-H:CLEAN_SAVE_MODE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:MMGRAW_0_SLOPE', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:MMGRAW_1_SLOPE', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:MMGRAW_0_OFFSET', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:MMGRAW_1_OFFSET', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:MCLRAW_0_FWDLOSS', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:MCLRAW_1_FWDLOSS', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:MCLRAW_0_REVLOSS', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:MCLRAW_1_REVLOSS', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:LEVEL_FID_ENABLE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:LEVEL_TRIG1_ENABLE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:LEVEL_TRIG2_ENABLE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:AD5644_V_CH0', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:AD5644_V_CH1', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:AD5644_V_CH2', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:AD5644_V_CH3', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:AD5644_V_CH4', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:AD5644_V_CH5', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:AD5644_V_CH6', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:AD5644_V_CH7', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:AD5644_V_CH8', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:AD5644_V_CH9', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:AD5644_V_CH10', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:AD5644_V_CH11', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:AD5644REF0_BO', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:AD5644REF1_BO', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:AD5644REF2_BO', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:LEVEL_FID', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:LEVEL_TRIG1', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:LEVEL_TRIG2', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:LEVEL_VTRIG1', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:LEVEL_VTRIG2', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:PHPLL', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FBELT_SERVO_SETPT', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FBE_X_PHASE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FBE_Y_PHASE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FBE_BE_PHASE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FBE_Z_ATT', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FBE_X_ATT', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FBE_Y_ATT', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FBE_BE_ATT', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FBELT_SERVO_MODE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FBELT_SERVO_SIGN', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FBELT_SERVO_GAIN', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FBELT_SERVO_OFFSET', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FBELT_SERVO_MAXDELTA', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FBELT_FAN_SETPT', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FBELT_FAN_MODE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FBELT_FAN_GAIN_P', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FBELT_FAN_GAIN_I', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SHAPE_C0', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SHAPE_C2', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SRAM_DACQ', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SRAM_ACQTIME', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SRAM_GDTIME', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SRAM_HOLDTIME', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SRAM_POSTTIME', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SRAM_ARM', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SRAM_EXTEN', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SRAM_REC_DS', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SRAM_BR_ARM', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SRAM_ACQ_SINGLE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SRAM_ACQ_EN', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SRAM_ACQ_PATTERN', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-H:SRAM_ACQ_MASK', _EMPTY_NDARRAY_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SRAM_SP_LOW1', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SRAM_SP_HIGH1', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SRAM_SP_SEARCH1', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SRAM_SP_LOW2', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SRAM_SP_HIGH2', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SRAM_SP_SEARCH2', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SRAM_SP_AVG', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SRAM_TRIG_IN_SEL', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:SRAM_POSTSEL', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:BRAM_DACQ', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:BRAM_ACQTIME', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:BRAM_GDTIME', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:BRAM_HOLDTIME', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:BRAM_POSTTIME', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:BRAM_ARM', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:BRAM_EXTEN', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:BRAM_REC_DS', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:BRAM_BR_ARM', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:BRAM_ACQ_SINGLE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:BRAM_ACQ_EN', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:BRAM_ACQ_PATTERN', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-H:BRAM_ACQ_MASK', _EMPTY_NDARRAY_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:BRAM_SP_LOW1', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:BRAM_SP_HIGH1', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:BRAM_SP_SEARCH1', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:BRAM_SP_LOW2', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:BRAM_SP_HIGH2', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:BRAM_SP_SEARCH2', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:BRAM_SP_AVG', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-H:BRAM_TRIG_IN_SEL', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:BRAM_POSTSEL', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-H:FBE_DEV_ID', _EMPTY_STR, 0.0]]


_pvs_bbb_proc_v = [
    ['SI-Glob:DI-BbBProc-V:GDEN', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FBCTRL', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SETSEL', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:DELAY', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:CLKRST', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SHIFTGAIN', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:PROC_DS', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:COEFF', _EMPTY_NDARRAY_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:CSET0', _EMPTY_NDARRAY_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:CSET1', _EMPTY_NDARRAY_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:LDSET', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:DESC_COEFF', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-V:DESC_CSET0', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-V:DESC_CSET1', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-V:FID_DELAY', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FLT_GAIN', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FLT_PHASE', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FLT_FREQ', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FLT_TAPS', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FTF_TUNE', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA31', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA30', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA29', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA28', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA27', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA26', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA25', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA24', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA23', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA22', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA21', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA20', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA19', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA18', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA17', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA16', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA15', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA14', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA13', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA12', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA11', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA10', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA9', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA8', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA7', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA6', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA5', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA4', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA3', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA2', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA1', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DATA0', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR31', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR30', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR29', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR28', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR27', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR26', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR25', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR24', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR23', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR22', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR21', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR20', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR19', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR18', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR17', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR16', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR15', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR14', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR13', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR12', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR11', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR10', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR9', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR8', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR7', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR6', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR5', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR4', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR3', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR2', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR1', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_DIR0', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:DRIVE_FREQ', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:DRIVE_AMPL', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:DRIVE_SPAN', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:DRIVE_PERIOD', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:DRIVE_WAVEFORM', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:DRIVE_PATTERN', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-V:DRIVE_MASK', _EMPTY_NDARRAY_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FE_PHASE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FE_ATTEN', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:BE_PHASE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:BE_ATTEN', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:TADC', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:TDAC', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:OFF_FIDC', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:OFF_FIDS', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:OFF_DAC', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:DEL_CAL', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:PHASE_SERVO_OFFSET', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:PHASE_SERVO_SETPT', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:PHASE_SERVO_MAXDELTA', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:PHASE_SERVO_GAIN', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:PHASE_SERVO_MODE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:PHASE_SERVO_SIGN', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:GPIO_SEL', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SAT_THRESHOLD', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FB_PATTERN', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-V:FB_MASK', _EMPTY_NDARRAY_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:CLEAN_TUNE', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:CLEAN_AMPL', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:CLEAN_PATTERN', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-V:CLEAN_ENABLE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:CLEAN_SAVE_FREQ', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:CLEAN_SAVE_AMPL', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:CLEAN_SAVE_DRV_PATTERN', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-V:CLEAN_SAVE_FB_PATTERN', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-V:CLEAN_SAVE_MODE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:MMGRAW_0_SLOPE', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:MMGRAW_1_SLOPE', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:MMGRAW_0_OFFSET', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:MMGRAW_1_OFFSET', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:MCLRAW_0_FWDLOSS', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:MCLRAW_1_FWDLOSS', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:MCLRAW_0_REVLOSS', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:MCLRAW_1_REVLOSS', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:LEVEL_FID_ENABLE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:LEVEL_TRIG1_ENABLE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:LEVEL_TRIG2_ENABLE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:AD5644_V_CH0', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:AD5644_V_CH1', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:AD5644_V_CH2', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:AD5644_V_CH3', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:AD5644_V_CH4', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:AD5644_V_CH5', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:AD5644_V_CH6', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:AD5644_V_CH7', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:AD5644_V_CH8', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:AD5644_V_CH9', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:AD5644_V_CH10', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:AD5644_V_CH11', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:AD5644REF0_BO', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:AD5644REF1_BO', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:AD5644REF2_BO', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:LEVEL_FID', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:LEVEL_TRIG1', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:LEVEL_TRIG2', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:LEVEL_VTRIG1', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:LEVEL_VTRIG2', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:PHPLL', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FBELT_SERVO_SETPT', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FBE_X_PHASE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FBE_Y_PHASE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FBE_BE_PHASE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FBE_Z_ATT', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FBE_X_ATT', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FBE_Y_ATT', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FBE_BE_ATT', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FBELT_SERVO_MODE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FBELT_SERVO_SIGN', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FBELT_SERVO_GAIN', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FBELT_SERVO_OFFSET', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FBELT_SERVO_MAXDELTA', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FBELT_FAN_SETPT', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FBELT_FAN_MODE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FBELT_FAN_GAIN_P', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FBELT_FAN_GAIN_I', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SHAPE_C0', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SHAPE_C2', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SRAM_DACQ', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SRAM_ACQTIME', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SRAM_GDTIME', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SRAM_HOLDTIME', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SRAM_POSTTIME', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SRAM_ARM', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SRAM_EXTEN', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SRAM_REC_DS', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SRAM_BR_ARM', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SRAM_ACQ_SINGLE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SRAM_ACQ_EN', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SRAM_ACQ_PATTERN', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-V:SRAM_ACQ_MASK', _EMPTY_NDARRAY_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SRAM_SP_LOW1', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SRAM_SP_HIGH1', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SRAM_SP_SEARCH1', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SRAM_SP_LOW2', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SRAM_SP_HIGH2', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SRAM_SP_SEARCH2', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SRAM_SP_AVG', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SRAM_TRIG_IN_SEL', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:SRAM_POSTSEL', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:BRAM_DACQ', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:BRAM_ACQTIME', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:BRAM_GDTIME', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:BRAM_HOLDTIME', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:BRAM_POSTTIME', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:BRAM_ARM', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:BRAM_EXTEN', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:BRAM_REC_DS', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:BRAM_BR_ARM', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:BRAM_ACQ_SINGLE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:BRAM_ACQ_EN', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:BRAM_ACQ_PATTERN', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-V:BRAM_ACQ_MASK', _EMPTY_NDARRAY_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:BRAM_SP_LOW1', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:BRAM_SP_HIGH1', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:BRAM_SP_SEARCH1', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:BRAM_SP_LOW2', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:BRAM_SP_HIGH2', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:BRAM_SP_SEARCH2', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:BRAM_SP_AVG', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-V:BRAM_TRIG_IN_SEL', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:BRAM_POSTSEL', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-V:FBE_DEV_ID', _EMPTY_STR, 0.0]]


_pvs_bbb_proc_l = [
    ['SI-Glob:DI-BbBProc-L:GDEN', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FBCTRL', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SETSEL', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:DELAY', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:CLKRST', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SHIFTGAIN', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:PROC_DS', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:COEFF', _EMPTY_NDARRAY_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:CSET0', _EMPTY_NDARRAY_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:CSET1', _EMPTY_NDARRAY_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:LDSET', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:DESC_COEFF', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-L:DESC_CSET0', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-L:DESC_CSET1', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-L:FID_DELAY', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FLT_GAIN', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FLT_PHASE', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FLT_FREQ', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FLT_TAPS', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FTF_TUNE', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA31', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA30', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA29', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA28', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA27', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA26', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA25', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA24', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA23', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA22', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA21', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA20', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA19', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA18', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA17', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA16', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA15', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA14', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA13', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA12', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA11', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA10', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA9', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA8', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA7', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA6', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA5', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA4', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA3', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA2', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA1', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DATA0', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR31', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR30', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR29', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR28', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR27', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR26', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR25', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR24', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR23', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR22', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR21', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR20', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR19', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR18', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR17', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR16', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR15', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR14', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR13', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR12', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR11', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR10', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR9', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR8', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR7', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR6', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR5', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR4', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR3', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR2', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR1', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_DIR0', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:DRIVE_FREQ', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:DRIVE_AMPL', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:DRIVE_SPAN', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:DRIVE_PERIOD', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:DRIVE_WAVEFORM', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:DRIVE_PATTERN', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-L:DRIVE_MASK', _EMPTY_NDARRAY_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FE_PHASE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FE_ATTEN', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:BE_PHASE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:BE_ATTEN', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:TADC', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:TDAC', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:OFF_FIDC', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:OFF_FIDS', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:OFF_DAC', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:DEL_CAL', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:PHASE_SERVO_OFFSET', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:PHASE_SERVO_SETPT', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:PHASE_SERVO_MAXDELTA', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:PHASE_SERVO_GAIN', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:PHASE_SERVO_MODE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:PHASE_SERVO_SIGN', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:GPIO_SEL', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SAT_THRESHOLD', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FB_PATTERN', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-L:FB_MASK', _EMPTY_NDARRAY_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:CLEAN_TUNE', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:CLEAN_AMPL', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:CLEAN_PATTERN', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-L:CLEAN_ENABLE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:CLEAN_SAVE_FREQ', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:CLEAN_SAVE_AMPL', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:CLEAN_SAVE_DRV_PATTERN', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-L:CLEAN_SAVE_FB_PATTERN', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-L:CLEAN_SAVE_MODE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:MMGRAW_0_SLOPE', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:MMGRAW_1_SLOPE', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:MMGRAW_0_OFFSET', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:MMGRAW_1_OFFSET', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:MCLRAW_0_FWDLOSS', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:MCLRAW_1_FWDLOSS', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:MCLRAW_0_REVLOSS', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:MCLRAW_1_REVLOSS', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:LEVEL_FID_ENABLE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:LEVEL_TRIG1_ENABLE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:LEVEL_TRIG2_ENABLE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:AD5644_V_CH0', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:AD5644_V_CH1', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:AD5644_V_CH2', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:AD5644_V_CH3', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:AD5644_V_CH4', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:AD5644_V_CH5', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:AD5644_V_CH6', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:AD5644_V_CH7', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:AD5644_V_CH8', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:AD5644_V_CH9', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:AD5644_V_CH10', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:AD5644_V_CH11', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:AD5644REF0_BO', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:AD5644REF1_BO', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:AD5644REF2_BO', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:LEVEL_FID', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:LEVEL_TRIG1', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:LEVEL_TRIG2', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:LEVEL_VTRIG1', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:LEVEL_VTRIG2', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:PHPLL', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FBELT_SERVO_SETPT', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FBE_X_PHASE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FBE_Y_PHASE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FBE_BE_PHASE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FBE_Z_ATT', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FBE_X_ATT', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FBE_Y_ATT', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FBE_BE_ATT', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FBELT_SERVO_MODE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FBELT_SERVO_SIGN', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FBELT_SERVO_GAIN', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FBELT_SERVO_OFFSET', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FBELT_SERVO_MAXDELTA', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FBELT_FAN_SETPT', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FBELT_FAN_MODE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FBELT_FAN_GAIN_P', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FBELT_FAN_GAIN_I', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SHAPE_C0', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SHAPE_C2', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SRAM_DACQ', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SRAM_ACQTIME', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SRAM_GDTIME', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SRAM_HOLDTIME', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SRAM_POSTTIME', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SRAM_ARM', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SRAM_EXTEN', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SRAM_REC_DS', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SRAM_BR_ARM', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SRAM_ACQ_SINGLE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SRAM_ACQ_EN', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SRAM_ACQ_PATTERN', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-L:SRAM_ACQ_MASK', _EMPTY_NDARRAY_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SRAM_SP_LOW1', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SRAM_SP_HIGH1', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SRAM_SP_SEARCH1', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SRAM_SP_LOW2', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SRAM_SP_HIGH2', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SRAM_SP_SEARCH2', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SRAM_SP_AVG', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SRAM_TRIG_IN_SEL', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:SRAM_POSTSEL', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:BRAM_DACQ', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:BRAM_ACQTIME', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:BRAM_GDTIME', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:BRAM_HOLDTIME', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:BRAM_POSTTIME', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:BRAM_ARM', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:BRAM_EXTEN', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:BRAM_REC_DS', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:BRAM_BR_ARM', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:BRAM_ACQ_SINGLE', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:BRAM_ACQ_EN', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:BRAM_ACQ_PATTERN', _EMPTY_STR, 0.0],
    ['SI-Glob:DI-BbBProc-L:BRAM_ACQ_MASK', _EMPTY_NDARRAY_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:BRAM_SP_LOW1', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:BRAM_SP_HIGH1', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:BRAM_SP_SEARCH1', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:BRAM_SP_LOW2', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:BRAM_SP_HIGH2', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:BRAM_SP_SEARCH2', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:BRAM_SP_AVG', _ZERO_FLOAT, 0.0],
    ['SI-Glob:DI-BbBProc-L:BRAM_TRIG_IN_SEL', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:BRAM_POSTSEL', _ZERO_INT, 0.0],
    ['SI-Glob:DI-BbBProc-L:FBE_DEV_ID', _EMPTY_STR, 0.0]]


_template_dict = {
    'pvs':
        _pvs_bbb_proc_h + _pvs_bbb_proc_v + _pvs_bbb_proc_l
    }
