"""Diagnostic equipments configuration."""
from copy import deepcopy as _dcopy


def get_dict():
    """Return configuration type dictionary."""
    module_name = __name__.split('.')[-1]
    _dict = {
        'config_type_name': module_name,
        'value': _dcopy(_template_dict),
        'check': False
    }
    return _dict


_li_diags = [
    # Screens
    ['LA-BI:PRF1:CAM:AcquireTime', 0.001, 0],
    ['LA-BI:PRF1:CAM:Gain', 0, 0],
    ['LA-BI:PRF1:CAL:CentroidThreshold', 0, 0],
    ['LA-BI:PRF1:ROI:MinX_', 0, 0],
    ['LA-BI:PRF1:ROI:MinY_', 0, 0],
    ['LA-BI:PRF1:X:Gauss:Coef', 0.0, 0],
    ['LA-BI:PRF1:Y:Gauss:Coef', 0.0, 0],
    ['LA-BI:PRF2:CAM:AcquireTime', 0.001, 0],
    ['LA-BI:PRF2:CAM:Gain', 0, 0],
    ['LA-BI:PRF2:CAL:CentroidThreshold', 0, 0],
    ['LA-BI:PRF2:ROI:MinX_', 0, 0],
    ['LA-BI:PRF2:ROI:MinY_', 0, 0],
    ['LA-BI:PRF2:X:Gauss:Coef', 0.0, 0],
    ['LA-BI:PRF2:Y:Gauss:Coef', 0.0, 0],
    ['LA-BI:PRF3:CAM:AcquireTime', 0.001, 0],
    ['LA-BI:PRF3:CAM:Gain', 0, 0],
    ['LA-BI:PRF3:CAL:CentroidThreshold', 0, 0],
    ['LA-BI:PRF3:ROI:MinX_', 0, 0],
    ['LA-BI:PRF3:ROI:MinY_', 0, 0],
    ['LA-BI:PRF3:X:Gauss:Coef', 0.0, 0],
    ['LA-BI:PRF3:Y:Gauss:Coef', 0.0, 0],
    ['LA-BI:PRF4:CAM:AcquireTime', 0.001, 0],
    ['LA-BI:PRF4:CAM:Gain', 0, 0],
    ['LA-BI:PRF4:CAL:CentroidThreshold', 0, 0],
    ['LA-BI:PRF4:ROI:MinX_', 0, 0],
    ['LA-BI:PRF4:ROI:MinY_', 0, 0],
    ['LA-BI:PRF4:X:Gauss:Coef', 0.0, 0],
    ['LA-BI:PRF4:Y:Gauss:Coef', 0.0, 0],
    ['LA-BI:PRF5:CAM:AcquireTime', 0.001, 0],
    ['LA-BI:PRF5:CAM:Gain', 0, 0],
    ['LA-BI:PRF5:CAL:CentroidThreshold', 0, 0],
    ['LA-BI:PRF5:ROI:MinX_', 0, 0],
    ['LA-BI:PRF5:ROI:MinY_', 0, 0],
    ['LA-BI:PRF5:X:Gauss:Coef', 0.0, 0],
    ['LA-BI:PRF5:Y:Gauss:Coef', 0.0, 0],

    # BPMs
    ['LA-BI:BPM2:FFT_CENTER', 0, 0],
    ['LA-BI:BPM2:FFT_WIDTH', 0, 0],
    ['LA-BI:BPM2:HIB_CENTER', 0, 0],
    ['LA-BI:BPM2:HIB_WIDTH', 0, 0],
    ['LA-BI:BPM2:POS_KX', 0, 0],
    ['LA-BI:BPM2:POS_KY', 0, 0],
    ['LA-BI:BPM2:POS_KS', 0, 0],
    ['LA-BI:BPM2:POS_OX', 0, 0],
    ['LA-BI:BPM2:POS_OY', 0, 0],
    ['LA-BI:BPM2:FE_ATTEN_SP', 0, 0],
    ['LA-BI:BPM2:ADC_THD', 0, 0],
    ['LA-BI:BPM2:ACQ_TRIGGER', 0, 0],
    ['LA-BI:BPM2:POS_ALG', 0, 0],
    ['LA-BI:BPM2:BPM_STRIP', 0, 0],
    ['LA-BI:BPM2:OPI:SEL', 0, 0],
    ['LA-BI:BPM3:FFT_CENTER', 0, 0],
    ['LA-BI:BPM3:FFT_WIDTH', 0, 0],
    ['LA-BI:BPM3:HIB_CENTER', 0, 0],
    ['LA-BI:BPM3:HIB_WIDTH', 0, 0],
    ['LA-BI:BPM3:POS_KX', 0, 0],
    ['LA-BI:BPM3:POS_KY', 0, 0],
    ['LA-BI:BPM3:POS_KS', 0, 0],
    ['LA-BI:BPM3:POS_OX', 0, 0],
    ['LA-BI:BPM3:POS_OY', 0, 0],
    ['LA-BI:BPM3:FE_ATTEN_SP', 0, 0],
    ['LA-BI:BPM3:ADC_THD', 0, 0],
    ['LA-BI:BPM3:ACQ_TRIGGER', 0, 0],
    ['LA-BI:BPM3:POS_ALG', 0, 0],
    ['LA-BI:BPM3:BPM_STRIP', 0, 0],
    ['LA-BI:BPM3:OPI:SEL', 0, 0],
]

_bpm_pvs = [
    # AMCFPGAEVR PVs related to BPMs
    ['IA-01RaBPM:TI-AMCFPGAEVR:RTMFreq-SP', 124914500, 0.0],    # Hz
    ['IA-01RaBPM:TI-AMCFPGAEVR:AFCFreq-SP', 69396944, 0.0],     # Hz
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC2State-Sel', 0, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC3State-Sel', 0, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC4State-Sel', 1, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC5State-Sel', 1, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC6State-Sel', 0, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC7State-Sel', 1, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC2Src-Sel', 0, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC3Src-Sel', 0, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC4Src-Sel', 5, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC5Src-Sel', 6, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC6Src-Sel', 0, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC7Src-Sel', 3, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC2Dir-Sel', 0, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC3Dir-Sel', 0, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC4Dir-Sel', 0, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC5Dir-Sel', 0, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC6Dir-Sel', 0, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC7Dir-Sel', 0, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC2Evt-SP', 0, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC3Evt-SP', 0, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC4Evt-SP', 0, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC5Evt-SP', 0, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC6Evt-SP', 0, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC7Evt-SP', 0, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC2WidthRaw-SP', 1, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC3WidthRaw-SP', 1, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC4WidthRaw-SP', 1, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC5WidthRaw-SP', 1, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC6WidthRaw-SP', 1, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC7WidthRaw-SP', 1, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC2Polarity-Sel', 0, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC3Polarity-Sel', 0, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC4Polarity-Sel', 0, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC5Polarity-Sel', 0, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC6Polarity-Sel', 0, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC7Polarity-Sel', 0, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC2NrPulses-SP', 1, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC3NrPulses-SP', 1, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC4NrPulses-SP', 1, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC5NrPulses-SP', 1, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC6NrPulses-SP', 1, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC7NrPulses-SP', 1, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC2DelayRaw-SP', 1, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC3DelayRaw-SP', 1, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC4DelayRaw-SP', 1, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC5DelayRaw-SP', 1, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC6DelayRaw-SP', 1, 0.0],
    ['IA-01RaBPM:TI-AMCFPGAEVR:AMC7DelayRaw-SP', 1, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:RTMFreq-SP', 124914500, 0.0],    # Hz
    ['IA-02RaBPM:TI-AMCFPGAEVR:AFCFreq-SP', 69396944, 0.0],     # Hz
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC2State-Sel', 0, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC3State-Sel', 0, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC4State-Sel', 1, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC5State-Sel', 1, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC6State-Sel', 0, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC7State-Sel', 1, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC2Src-Sel', 0, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC3Src-Sel', 0, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC4Src-Sel', 5, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC5Src-Sel', 6, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC6Src-Sel', 0, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC7Src-Sel', 3, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC2Dir-Sel', 0, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC3Dir-Sel', 0, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC4Dir-Sel', 0, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC5Dir-Sel', 0, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC6Dir-Sel', 0, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC7Dir-Sel', 0, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC2Evt-SP', 0, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC3Evt-SP', 0, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC4Evt-SP', 0, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC5Evt-SP', 0, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC6Evt-SP', 0, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC7Evt-SP', 0, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC2WidthRaw-SP', 1, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC3WidthRaw-SP', 1, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC4WidthRaw-SP', 1, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC5WidthRaw-SP', 1, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC6WidthRaw-SP', 1, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC7WidthRaw-SP', 1, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC2Polarity-Sel', 0, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC3Polarity-Sel', 0, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC4Polarity-Sel', 0, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC5Polarity-Sel', 0, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC6Polarity-Sel', 0, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC7Polarity-Sel', 0, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC2NrPulses-SP', 1, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC3NrPulses-SP', 1, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC4NrPulses-SP', 1, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC5NrPulses-SP', 1, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC6NrPulses-SP', 1, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC7NrPulses-SP', 1, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC2DelayRaw-SP', 1, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC3DelayRaw-SP', 1, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC4DelayRaw-SP', 1, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC5DelayRaw-SP', 1, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC6DelayRaw-SP', 1, 0.0],
    ['IA-02RaBPM:TI-AMCFPGAEVR:AMC7DelayRaw-SP', 1, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:RTMFreq-SP', 124914500, 0.0],    # Hz
    ['IA-03RaBPM:TI-AMCFPGAEVR:AFCFreq-SP', 69396944, 0.0],     # Hz
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC2State-Sel', 0, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC3State-Sel', 0, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC4State-Sel', 1, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC5State-Sel', 1, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC6State-Sel', 0, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC7State-Sel', 1, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC2Src-Sel', 0, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC3Src-Sel', 0, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC4Src-Sel', 5, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC5Src-Sel', 6, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC6Src-Sel', 0, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC7Src-Sel', 3, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC2Dir-Sel', 0, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC3Dir-Sel', 0, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC4Dir-Sel', 0, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC5Dir-Sel', 0, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC6Dir-Sel', 0, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC7Dir-Sel', 0, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC2Evt-SP', 0, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC3Evt-SP', 0, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC4Evt-SP', 0, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC5Evt-SP', 0, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC6Evt-SP', 0, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC7Evt-SP', 0, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC2WidthRaw-SP', 1, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC3WidthRaw-SP', 1, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC4WidthRaw-SP', 1, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC5WidthRaw-SP', 1, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC6WidthRaw-SP', 1, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC7WidthRaw-SP', 1, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC2Polarity-Sel', 0, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC3Polarity-Sel', 0, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC4Polarity-Sel', 0, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC5Polarity-Sel', 0, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC6Polarity-Sel', 0, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC7Polarity-Sel', 0, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC2NrPulses-SP', 1, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC3NrPulses-SP', 1, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC4NrPulses-SP', 1, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC5NrPulses-SP', 1, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC6NrPulses-SP', 1, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC7NrPulses-SP', 1, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC2DelayRaw-SP', 1, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC3DelayRaw-SP', 1, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC4DelayRaw-SP', 1, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC5DelayRaw-SP', 1, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC6DelayRaw-SP', 1, 0.0],
    ['IA-03RaBPM:TI-AMCFPGAEVR:AMC7DelayRaw-SP', 1, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:RTMFreq-SP', 124914500, 0.0],    # Hz
    ['IA-04RaBPM:TI-AMCFPGAEVR:AFCFreq-SP', 69396944, 0.0],     # Hz
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC2State-Sel', 0, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC3State-Sel', 0, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC4State-Sel', 1, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC5State-Sel', 1, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC6State-Sel', 0, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC7State-Sel', 1, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC2Src-Sel', 0, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC3Src-Sel', 0, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC4Src-Sel', 5, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC5Src-Sel', 6, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC6Src-Sel', 0, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC7Src-Sel', 3, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC2Dir-Sel', 0, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC3Dir-Sel', 0, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC4Dir-Sel', 0, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC5Dir-Sel', 0, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC6Dir-Sel', 0, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC7Dir-Sel', 0, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC2Evt-SP', 0, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC3Evt-SP', 0, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC4Evt-SP', 0, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC5Evt-SP', 0, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC6Evt-SP', 0, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC7Evt-SP', 0, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC2WidthRaw-SP', 1, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC3WidthRaw-SP', 1, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC4WidthRaw-SP', 1, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC5WidthRaw-SP', 1, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC6WidthRaw-SP', 1, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC7WidthRaw-SP', 1, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC2Polarity-Sel', 0, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC3Polarity-Sel', 0, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC4Polarity-Sel', 0, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC5Polarity-Sel', 0, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC6Polarity-Sel', 0, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC7Polarity-Sel', 0, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC2NrPulses-SP', 1, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC3NrPulses-SP', 1, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC4NrPulses-SP', 1, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC5NrPulses-SP', 1, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC6NrPulses-SP', 1, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC7NrPulses-SP', 1, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC2DelayRaw-SP', 1, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC3DelayRaw-SP', 1, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC4DelayRaw-SP', 1, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC5DelayRaw-SP', 1, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC6DelayRaw-SP', 1, 0.0],
    ['IA-04RaBPM:TI-AMCFPGAEVR:AMC7DelayRaw-SP', 1, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:RTMFreq-SP', 124914500, 0.0],    # Hz
    ['IA-05RaBPM:TI-AMCFPGAEVR:AFCFreq-SP', 69396944, 0.0],     # Hz
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC2State-Sel', 0, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC3State-Sel', 0, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC4State-Sel', 1, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC5State-Sel', 1, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC6State-Sel', 0, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC7State-Sel', 1, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC2Src-Sel', 0, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC3Src-Sel', 0, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC4Src-Sel', 5, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC5Src-Sel', 6, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC6Src-Sel', 0, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC7Src-Sel', 3, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC2Dir-Sel', 0, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC3Dir-Sel', 0, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC4Dir-Sel', 0, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC5Dir-Sel', 0, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC6Dir-Sel', 0, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC7Dir-Sel', 0, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC2Evt-SP', 0, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC3Evt-SP', 0, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC4Evt-SP', 0, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC5Evt-SP', 0, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC6Evt-SP', 0, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC7Evt-SP', 0, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC2WidthRaw-SP', 1, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC3WidthRaw-SP', 1, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC4WidthRaw-SP', 1, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC5WidthRaw-SP', 1, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC6WidthRaw-SP', 1, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC7WidthRaw-SP', 1, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC2Polarity-Sel', 0, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC3Polarity-Sel', 0, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC4Polarity-Sel', 0, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC5Polarity-Sel', 0, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC6Polarity-Sel', 0, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC7Polarity-Sel', 0, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC2NrPulses-SP', 1, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC3NrPulses-SP', 1, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC4NrPulses-SP', 1, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC5NrPulses-SP', 1, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC6NrPulses-SP', 1, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC7NrPulses-SP', 1, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC2DelayRaw-SP', 1, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC3DelayRaw-SP', 1, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC4DelayRaw-SP', 1, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC5DelayRaw-SP', 1, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC6DelayRaw-SP', 1, 0.0],
    ['IA-05RaBPM:TI-AMCFPGAEVR:AMC7DelayRaw-SP', 1, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:RTMFreq-SP', 124914500, 0.0],    # Hz
    ['IA-06RaBPM:TI-AMCFPGAEVR:AFCFreq-SP', 69396944, 0.0],     # Hz
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC2State-Sel', 0, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC3State-Sel', 0, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC4State-Sel', 1, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC5State-Sel', 1, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC6State-Sel', 0, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC7State-Sel', 1, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC2Src-Sel', 0, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC3Src-Sel', 0, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC4Src-Sel', 5, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC5Src-Sel', 6, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC6Src-Sel', 0, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC7Src-Sel', 3, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC2Dir-Sel', 0, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC3Dir-Sel', 0, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC4Dir-Sel', 0, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC5Dir-Sel', 0, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC6Dir-Sel', 0, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC7Dir-Sel', 0, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC2Evt-SP', 0, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC3Evt-SP', 0, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC4Evt-SP', 0, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC5Evt-SP', 0, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC6Evt-SP', 0, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC7Evt-SP', 0, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC2WidthRaw-SP', 1, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC3WidthRaw-SP', 1, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC4WidthRaw-SP', 1, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC5WidthRaw-SP', 1, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC6WidthRaw-SP', 1, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC7WidthRaw-SP', 1, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC2Polarity-Sel', 0, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC3Polarity-Sel', 0, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC4Polarity-Sel', 0, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC5Polarity-Sel', 0, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC6Polarity-Sel', 0, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC7Polarity-Sel', 0, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC2NrPulses-SP', 1, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC3NrPulses-SP', 1, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC4NrPulses-SP', 1, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC5NrPulses-SP', 1, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC6NrPulses-SP', 1, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC7NrPulses-SP', 1, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC2DelayRaw-SP', 1, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC3DelayRaw-SP', 1, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC4DelayRaw-SP', 1, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC5DelayRaw-SP', 1, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC6DelayRaw-SP', 1, 0.0],
    ['IA-06RaBPM:TI-AMCFPGAEVR:AMC7DelayRaw-SP', 1, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:RTMFreq-SP', 124914500, 0.0],    # Hz
    ['IA-07RaBPM:TI-AMCFPGAEVR:AFCFreq-SP', 69396944, 0.0],     # Hz
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC2State-Sel', 0, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC3State-Sel', 0, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC4State-Sel', 1, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC5State-Sel', 1, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC6State-Sel', 0, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC7State-Sel', 1, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC2Src-Sel', 0, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC3Src-Sel', 0, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC4Src-Sel', 5, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC5Src-Sel', 6, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC6Src-Sel', 0, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC7Src-Sel', 3, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC2Dir-Sel', 0, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC3Dir-Sel', 0, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC4Dir-Sel', 0, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC5Dir-Sel', 0, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC6Dir-Sel', 0, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC7Dir-Sel', 0, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC2Evt-SP', 0, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC3Evt-SP', 0, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC4Evt-SP', 0, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC5Evt-SP', 0, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC6Evt-SP', 0, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC7Evt-SP', 0, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC2WidthRaw-SP', 1, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC3WidthRaw-SP', 1, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC4WidthRaw-SP', 1, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC5WidthRaw-SP', 1, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC6WidthRaw-SP', 1, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC7WidthRaw-SP', 1, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC2Polarity-Sel', 0, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC3Polarity-Sel', 0, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC4Polarity-Sel', 0, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC5Polarity-Sel', 0, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC6Polarity-Sel', 0, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC7Polarity-Sel', 0, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC2NrPulses-SP', 1, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC3NrPulses-SP', 1, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC4NrPulses-SP', 1, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC5NrPulses-SP', 1, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC6NrPulses-SP', 1, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC7NrPulses-SP', 1, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC2DelayRaw-SP', 1, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC3DelayRaw-SP', 1, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC4DelayRaw-SP', 1, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC5DelayRaw-SP', 1, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC6DelayRaw-SP', 1, 0.0],
    ['IA-07RaBPM:TI-AMCFPGAEVR:AMC7DelayRaw-SP', 1, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:RTMFreq-SP', 124914500, 0.0],    # Hz
    ['IA-08RaBPM:TI-AMCFPGAEVR:AFCFreq-SP', 69396944, 0.0],     # Hz
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC2State-Sel', 0, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC3State-Sel', 0, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC4State-Sel', 1, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC5State-Sel', 1, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC6State-Sel', 0, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC7State-Sel', 1, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC2Src-Sel', 0, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC3Src-Sel', 0, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC4Src-Sel', 5, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC5Src-Sel', 6, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC6Src-Sel', 0, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC7Src-Sel', 3, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC2Dir-Sel', 0, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC3Dir-Sel', 0, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC4Dir-Sel', 0, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC5Dir-Sel', 0, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC6Dir-Sel', 0, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC7Dir-Sel', 0, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC2Evt-SP', 0, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC3Evt-SP', 0, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC4Evt-SP', 0, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC5Evt-SP', 0, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC6Evt-SP', 0, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC7Evt-SP', 0, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC2WidthRaw-SP', 1, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC3WidthRaw-SP', 1, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC4WidthRaw-SP', 1, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC5WidthRaw-SP', 1, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC6WidthRaw-SP', 1, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC7WidthRaw-SP', 1, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC2Polarity-Sel', 0, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC3Polarity-Sel', 0, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC4Polarity-Sel', 0, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC5Polarity-Sel', 0, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC6Polarity-Sel', 0, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC7Polarity-Sel', 0, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC2NrPulses-SP', 1, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC3NrPulses-SP', 1, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC4NrPulses-SP', 1, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC5NrPulses-SP', 1, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC6NrPulses-SP', 1, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC7NrPulses-SP', 1, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC2DelayRaw-SP', 1, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC3DelayRaw-SP', 1, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC4DelayRaw-SP', 1, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC5DelayRaw-SP', 1, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC6DelayRaw-SP', 1, 0.0],
    ['IA-08RaBPM:TI-AMCFPGAEVR:AMC7DelayRaw-SP', 1, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:RTMFreq-SP', 124914500, 0.0],    # Hz
    ['IA-09RaBPM:TI-AMCFPGAEVR:AFCFreq-SP', 69396944, 0.0],     # Hz
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC2State-Sel', 0, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC3State-Sel', 0, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC4State-Sel', 1, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC5State-Sel', 1, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC6State-Sel', 0, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC7State-Sel', 1, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC2Src-Sel', 0, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC3Src-Sel', 0, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC4Src-Sel', 5, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC5Src-Sel', 6, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC6Src-Sel', 0, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC7Src-Sel', 3, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC2Dir-Sel', 0, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC3Dir-Sel', 0, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC4Dir-Sel', 0, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC5Dir-Sel', 0, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC6Dir-Sel', 0, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC7Dir-Sel', 0, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC2Evt-SP', 0, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC3Evt-SP', 0, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC4Evt-SP', 0, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC5Evt-SP', 0, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC6Evt-SP', 0, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC7Evt-SP', 0, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC2WidthRaw-SP', 1, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC3WidthRaw-SP', 1, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC4WidthRaw-SP', 1, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC5WidthRaw-SP', 1, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC6WidthRaw-SP', 1, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC7WidthRaw-SP', 1, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC2Polarity-Sel', 0, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC3Polarity-Sel', 0, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC4Polarity-Sel', 0, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC5Polarity-Sel', 0, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC6Polarity-Sel', 0, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC7Polarity-Sel', 0, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC2NrPulses-SP', 1, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC3NrPulses-SP', 1, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC4NrPulses-SP', 1, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC5NrPulses-SP', 1, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC6NrPulses-SP', 1, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC7NrPulses-SP', 1, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC2DelayRaw-SP', 1, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC3DelayRaw-SP', 1, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC4DelayRaw-SP', 1, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC5DelayRaw-SP', 1, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC6DelayRaw-SP', 1, 0.0],
    ['IA-09RaBPM:TI-AMCFPGAEVR:AMC7DelayRaw-SP', 1, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:RTMFreq-SP', 124914500, 0.0],    # Hz
    ['IA-10RaBPM:TI-AMCFPGAEVR:AFCFreq-SP', 69396944, 0.0],     # Hz
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC2State-Sel', 0, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC3State-Sel', 0, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC4State-Sel', 1, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC5State-Sel', 1, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC6State-Sel', 0, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC7State-Sel', 1, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC2Src-Sel', 0, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC3Src-Sel', 0, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC4Src-Sel', 5, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC5Src-Sel', 6, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC6Src-Sel', 0, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC7Src-Sel', 3, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC2Dir-Sel', 0, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC3Dir-Sel', 0, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC4Dir-Sel', 0, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC5Dir-Sel', 0, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC6Dir-Sel', 0, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC7Dir-Sel', 0, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC2Evt-SP', 0, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC3Evt-SP', 0, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC4Evt-SP', 0, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC5Evt-SP', 0, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC6Evt-SP', 0, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC7Evt-SP', 0, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC2WidthRaw-SP', 1, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC3WidthRaw-SP', 1, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC4WidthRaw-SP', 1, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC5WidthRaw-SP', 1, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC6WidthRaw-SP', 1, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC7WidthRaw-SP', 1, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC2Polarity-Sel', 0, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC3Polarity-Sel', 0, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC4Polarity-Sel', 0, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC5Polarity-Sel', 0, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC6Polarity-Sel', 0, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC7Polarity-Sel', 0, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC2NrPulses-SP', 1, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC3NrPulses-SP', 1, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC4NrPulses-SP', 1, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC5NrPulses-SP', 1, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC6NrPulses-SP', 1, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC7NrPulses-SP', 1, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC2DelayRaw-SP', 1, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC3DelayRaw-SP', 1, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC4DelayRaw-SP', 1, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC5DelayRaw-SP', 1, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC6DelayRaw-SP', 1, 0.0],
    ['IA-10RaBPM:TI-AMCFPGAEVR:AMC7DelayRaw-SP', 1, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:RTMFreq-SP', 124914500, 0.0],    # Hz
    ['IA-11RaBPM:TI-AMCFPGAEVR:AFCFreq-SP', 69396944, 0.0],     # Hz
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC2State-Sel', 0, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC3State-Sel', 0, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC4State-Sel', 1, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC5State-Sel', 1, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC6State-Sel', 0, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC7State-Sel', 1, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC2Src-Sel', 0, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC3Src-Sel', 0, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC4Src-Sel', 5, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC5Src-Sel', 6, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC6Src-Sel', 0, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC7Src-Sel', 3, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC2Dir-Sel', 0, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC3Dir-Sel', 0, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC4Dir-Sel', 0, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC5Dir-Sel', 0, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC6Dir-Sel', 0, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC7Dir-Sel', 0, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC2Evt-SP', 0, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC3Evt-SP', 0, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC4Evt-SP', 0, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC5Evt-SP', 0, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC6Evt-SP', 0, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC7Evt-SP', 0, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC2WidthRaw-SP', 1, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC3WidthRaw-SP', 1, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC4WidthRaw-SP', 1, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC5WidthRaw-SP', 1, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC6WidthRaw-SP', 1, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC7WidthRaw-SP', 1, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC2Polarity-Sel', 0, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC3Polarity-Sel', 0, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC4Polarity-Sel', 0, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC5Polarity-Sel', 0, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC6Polarity-Sel', 0, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC7Polarity-Sel', 0, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC2NrPulses-SP', 1, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC3NrPulses-SP', 1, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC4NrPulses-SP', 1, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC5NrPulses-SP', 1, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC6NrPulses-SP', 1, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC7NrPulses-SP', 1, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC2DelayRaw-SP', 1, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC3DelayRaw-SP', 1, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC4DelayRaw-SP', 1, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC5DelayRaw-SP', 1, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC6DelayRaw-SP', 1, 0.0],
    ['IA-11RaBPM:TI-AMCFPGAEVR:AMC7DelayRaw-SP', 1, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:RTMFreq-SP', 124914500, 0.0],    # Hz
    ['IA-12RaBPM:TI-AMCFPGAEVR:AFCFreq-SP', 69396944, 0.0],     # Hz
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC2State-Sel', 0, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC3State-Sel', 0, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC4State-Sel', 1, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC5State-Sel', 1, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC6State-Sel', 0, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC7State-Sel', 1, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC2Src-Sel', 0, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC3Src-Sel', 0, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC4Src-Sel', 5, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC5Src-Sel', 6, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC6Src-Sel', 0, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC7Src-Sel', 3, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC2Dir-Sel', 0, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC3Dir-Sel', 0, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC4Dir-Sel', 0, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC5Dir-Sel', 0, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC6Dir-Sel', 0, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC7Dir-Sel', 0, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC2Evt-SP', 0, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC3Evt-SP', 0, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC4Evt-SP', 0, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC5Evt-SP', 0, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC6Evt-SP', 0, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC7Evt-SP', 0, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC2WidthRaw-SP', 1, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC3WidthRaw-SP', 1, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC4WidthRaw-SP', 1, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC5WidthRaw-SP', 1, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC6WidthRaw-SP', 1, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC7WidthRaw-SP', 1, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC2Polarity-Sel', 0, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC3Polarity-Sel', 0, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC4Polarity-Sel', 0, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC5Polarity-Sel', 0, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC6Polarity-Sel', 0, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC7Polarity-Sel', 0, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC2NrPulses-SP', 1, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC3NrPulses-SP', 1, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC4NrPulses-SP', 1, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC5NrPulses-SP', 1, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC6NrPulses-SP', 1, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC7NrPulses-SP', 1, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC2DelayRaw-SP', 1, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC3DelayRaw-SP', 1, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC4DelayRaw-SP', 1, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC5DelayRaw-SP', 1, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC6DelayRaw-SP', 1, 0.0],
    ['IA-12RaBPM:TI-AMCFPGAEVR:AMC7DelayRaw-SP', 1, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:RTMFreq-SP', 124914500, 0.0],    # Hz
    ['IA-13RaBPM:TI-AMCFPGAEVR:AFCFreq-SP', 69396944, 0.0],     # Hz
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC2State-Sel', 0, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC3State-Sel', 0, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC4State-Sel', 1, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC5State-Sel', 1, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC6State-Sel', 0, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC7State-Sel', 1, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC2Src-Sel', 0, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC3Src-Sel', 0, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC4Src-Sel', 5, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC5Src-Sel', 6, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC6Src-Sel', 0, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC7Src-Sel', 3, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC2Dir-Sel', 0, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC3Dir-Sel', 0, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC4Dir-Sel', 0, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC5Dir-Sel', 0, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC6Dir-Sel', 0, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC7Dir-Sel', 0, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC2Evt-SP', 0, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC3Evt-SP', 0, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC4Evt-SP', 0, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC5Evt-SP', 0, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC6Evt-SP', 0, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC7Evt-SP', 0, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC2WidthRaw-SP', 1, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC3WidthRaw-SP', 1, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC4WidthRaw-SP', 1, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC5WidthRaw-SP', 1, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC6WidthRaw-SP', 1, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC7WidthRaw-SP', 1, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC2Polarity-Sel', 0, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC3Polarity-Sel', 0, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC4Polarity-Sel', 0, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC5Polarity-Sel', 0, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC6Polarity-Sel', 0, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC7Polarity-Sel', 0, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC2NrPulses-SP', 1, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC3NrPulses-SP', 1, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC4NrPulses-SP', 1, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC5NrPulses-SP', 1, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC6NrPulses-SP', 1, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC7NrPulses-SP', 1, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC2DelayRaw-SP', 1, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC3DelayRaw-SP', 1, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC4DelayRaw-SP', 1, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC5DelayRaw-SP', 1, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC6DelayRaw-SP', 1, 0.0],
    ['IA-13RaBPM:TI-AMCFPGAEVR:AMC7DelayRaw-SP', 1, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:RTMFreq-SP', 124914500, 0.0],    # Hz
    ['IA-14RaBPM:TI-AMCFPGAEVR:AFCFreq-SP', 69396944, 0.0],     # Hz
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC2State-Sel', 0, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC3State-Sel', 0, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC4State-Sel', 1, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC5State-Sel', 1, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC6State-Sel', 0, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC7State-Sel', 1, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC2Src-Sel', 0, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC3Src-Sel', 0, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC4Src-Sel', 5, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC5Src-Sel', 6, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC6Src-Sel', 0, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC7Src-Sel', 3, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC2Dir-Sel', 0, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC3Dir-Sel', 0, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC4Dir-Sel', 0, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC5Dir-Sel', 0, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC6Dir-Sel', 0, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC7Dir-Sel', 0, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC2Evt-SP', 0, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC3Evt-SP', 0, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC4Evt-SP', 0, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC5Evt-SP', 0, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC6Evt-SP', 0, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC7Evt-SP', 0, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC2WidthRaw-SP', 1, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC3WidthRaw-SP', 1, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC4WidthRaw-SP', 1, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC5WidthRaw-SP', 1, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC6WidthRaw-SP', 1, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC7WidthRaw-SP', 1, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC2Polarity-Sel', 0, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC3Polarity-Sel', 0, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC4Polarity-Sel', 0, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC5Polarity-Sel', 0, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC6Polarity-Sel', 0, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC7Polarity-Sel', 0, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC2NrPulses-SP', 1, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC3NrPulses-SP', 1, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC4NrPulses-SP', 1, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC5NrPulses-SP', 1, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC6NrPulses-SP', 1, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC7NrPulses-SP', 1, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC2DelayRaw-SP', 1, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC3DelayRaw-SP', 1, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC4DelayRaw-SP', 1, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC5DelayRaw-SP', 1, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC6DelayRaw-SP', 1, 0.0],
    ['IA-14RaBPM:TI-AMCFPGAEVR:AMC7DelayRaw-SP', 1, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:RTMFreq-SP', 124914500, 0.0],    # Hz
    ['IA-15RaBPM:TI-AMCFPGAEVR:AFCFreq-SP', 69396944, 0.0],     # Hz
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC2State-Sel', 0, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC3State-Sel', 0, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC4State-Sel', 1, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC5State-Sel', 1, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC6State-Sel', 0, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC7State-Sel', 1, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC2Src-Sel', 0, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC3Src-Sel', 0, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC4Src-Sel', 5, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC5Src-Sel', 6, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC6Src-Sel', 0, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC7Src-Sel', 3, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC2Dir-Sel', 0, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC3Dir-Sel', 0, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC4Dir-Sel', 0, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC5Dir-Sel', 0, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC6Dir-Sel', 0, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC7Dir-Sel', 0, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC2Evt-SP', 0, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC3Evt-SP', 0, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC4Evt-SP', 0, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC5Evt-SP', 0, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC6Evt-SP', 0, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC7Evt-SP', 0, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC2WidthRaw-SP', 1, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC3WidthRaw-SP', 1, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC4WidthRaw-SP', 1, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC5WidthRaw-SP', 1, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC6WidthRaw-SP', 1, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC7WidthRaw-SP', 1, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC2Polarity-Sel', 0, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC3Polarity-Sel', 0, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC4Polarity-Sel', 0, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC5Polarity-Sel', 0, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC6Polarity-Sel', 0, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC7Polarity-Sel', 0, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC2NrPulses-SP', 1, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC3NrPulses-SP', 1, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC4NrPulses-SP', 1, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC5NrPulses-SP', 1, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC6NrPulses-SP', 1, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC7NrPulses-SP', 1, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC2DelayRaw-SP', 1, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC3DelayRaw-SP', 1, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC4DelayRaw-SP', 1, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC5DelayRaw-SP', 1, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC6DelayRaw-SP', 1, 0.0],
    ['IA-15RaBPM:TI-AMCFPGAEVR:AMC7DelayRaw-SP', 1, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:RTMFreq-SP', 124914500, 0.0],    # Hz
    ['IA-16RaBPM:TI-AMCFPGAEVR:AFCFreq-SP', 69396944, 0.0],     # Hz
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC2State-Sel', 0, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC3State-Sel', 0, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC4State-Sel', 1, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC5State-Sel', 1, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC6State-Sel', 0, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC7State-Sel', 1, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC2Src-Sel', 0, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC3Src-Sel', 0, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC4Src-Sel', 5, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC5Src-Sel', 6, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC6Src-Sel', 0, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC7Src-Sel', 3, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC2Dir-Sel', 0, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC3Dir-Sel', 0, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC4Dir-Sel', 0, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC5Dir-Sel', 0, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC6Dir-Sel', 0, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC7Dir-Sel', 0, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC2Evt-SP', 0, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC3Evt-SP', 0, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC4Evt-SP', 0, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC5Evt-SP', 0, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC6Evt-SP', 0, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC7Evt-SP', 0, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC2WidthRaw-SP', 1, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC3WidthRaw-SP', 1, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC4WidthRaw-SP', 1, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC5WidthRaw-SP', 1, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC6WidthRaw-SP', 1, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC7WidthRaw-SP', 1, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC2Polarity-Sel', 0, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC3Polarity-Sel', 0, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC4Polarity-Sel', 0, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC5Polarity-Sel', 0, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC6Polarity-Sel', 0, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC7Polarity-Sel', 0, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC2NrPulses-SP', 1, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC3NrPulses-SP', 1, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC4NrPulses-SP', 1, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC5NrPulses-SP', 1, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC6NrPulses-SP', 1, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC7NrPulses-SP', 1, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC2DelayRaw-SP', 1, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC3DelayRaw-SP', 1, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC4DelayRaw-SP', 1, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC5DelayRaw-SP', 1, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC6DelayRaw-SP', 1, 0.0],
    ['IA-16RaBPM:TI-AMCFPGAEVR:AMC7DelayRaw-SP', 1, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:RTMFreq-SP', 124914500, 0.0],    # Hz
    ['IA-17RaBPM:TI-AMCFPGAEVR:AFCFreq-SP', 69396944, 0.0],     # Hz
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC2State-Sel', 0, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC3State-Sel', 0, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC4State-Sel', 1, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC5State-Sel', 1, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC6State-Sel', 0, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC7State-Sel', 1, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC2Src-Sel', 0, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC3Src-Sel', 0, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC4Src-Sel', 5, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC5Src-Sel', 6, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC6Src-Sel', 0, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC7Src-Sel', 3, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC2Dir-Sel', 0, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC3Dir-Sel', 0, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC4Dir-Sel', 0, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC5Dir-Sel', 0, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC6Dir-Sel', 0, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC7Dir-Sel', 0, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC2Evt-SP', 0, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC3Evt-SP', 0, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC4Evt-SP', 0, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC5Evt-SP', 0, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC6Evt-SP', 0, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC7Evt-SP', 0, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC2WidthRaw-SP', 1, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC3WidthRaw-SP', 1, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC4WidthRaw-SP', 1, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC5WidthRaw-SP', 1, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC6WidthRaw-SP', 1, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC7WidthRaw-SP', 1, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC2Polarity-Sel', 0, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC3Polarity-Sel', 0, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC4Polarity-Sel', 0, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC5Polarity-Sel', 0, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC6Polarity-Sel', 0, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC7Polarity-Sel', 0, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC2NrPulses-SP', 1, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC3NrPulses-SP', 1, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC4NrPulses-SP', 1, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC5NrPulses-SP', 1, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC6NrPulses-SP', 1, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC7NrPulses-SP', 1, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC2DelayRaw-SP', 1, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC3DelayRaw-SP', 1, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC4DelayRaw-SP', 1, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC5DelayRaw-SP', 1, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC6DelayRaw-SP', 1, 0.0],
    ['IA-17RaBPM:TI-AMCFPGAEVR:AMC7DelayRaw-SP', 1, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:RTMFreq-SP', 124914500, 0.0],    # Hz
    ['IA-18RaBPM:TI-AMCFPGAEVR:AFCFreq-SP', 69396944, 0.0],     # Hz
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC2State-Sel', 0, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC3State-Sel', 0, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC4State-Sel', 1, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC5State-Sel', 1, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC6State-Sel', 0, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC7State-Sel', 1, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC2Src-Sel', 0, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC3Src-Sel', 0, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC4Src-Sel', 5, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC5Src-Sel', 6, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC6Src-Sel', 0, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC7Src-Sel', 3, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC2Dir-Sel', 0, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC3Dir-Sel', 0, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC4Dir-Sel', 0, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC5Dir-Sel', 0, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC6Dir-Sel', 0, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC7Dir-Sel', 0, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC2Evt-SP', 0, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC3Evt-SP', 0, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC4Evt-SP', 0, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC5Evt-SP', 0, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC6Evt-SP', 0, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC7Evt-SP', 0, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC2WidthRaw-SP', 1, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC3WidthRaw-SP', 1, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC4WidthRaw-SP', 1, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC5WidthRaw-SP', 1, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC6WidthRaw-SP', 1, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC7WidthRaw-SP', 1, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC2Polarity-Sel', 0, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC3Polarity-Sel', 0, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC4Polarity-Sel', 0, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC5Polarity-Sel', 0, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC6Polarity-Sel', 0, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC7Polarity-Sel', 0, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC2NrPulses-SP', 1, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC3NrPulses-SP', 1, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC4NrPulses-SP', 1, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC5NrPulses-SP', 1, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC6NrPulses-SP', 1, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC7NrPulses-SP', 1, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC2DelayRaw-SP', 1, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC3DelayRaw-SP', 1, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC4DelayRaw-SP', 1, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC5DelayRaw-SP', 1, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC6DelayRaw-SP', 1, 0.0],
    ['IA-18RaBPM:TI-AMCFPGAEVR:AMC7DelayRaw-SP', 1, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:RTMFreq-SP', 124914500, 0.0],    # Hz
    ['IA-19RaBPM:TI-AMCFPGAEVR:AFCFreq-SP', 69396944, 0.0],     # Hz
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC2State-Sel', 0, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC3State-Sel', 0, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC4State-Sel', 1, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC5State-Sel', 1, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC6State-Sel', 0, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC7State-Sel', 1, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC2Src-Sel', 0, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC3Src-Sel', 0, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC4Src-Sel', 5, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC5Src-Sel', 6, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC6Src-Sel', 0, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC7Src-Sel', 3, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC2Dir-Sel', 0, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC3Dir-Sel', 0, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC4Dir-Sel', 0, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC5Dir-Sel', 0, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC6Dir-Sel', 0, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC7Dir-Sel', 0, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC2Evt-SP', 0, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC3Evt-SP', 0, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC4Evt-SP', 0, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC5Evt-SP', 0, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC6Evt-SP', 0, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC7Evt-SP', 0, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC2WidthRaw-SP', 1, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC3WidthRaw-SP', 1, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC4WidthRaw-SP', 1, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC5WidthRaw-SP', 1, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC6WidthRaw-SP', 1, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC7WidthRaw-SP', 1, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC2Polarity-Sel', 0, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC3Polarity-Sel', 0, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC4Polarity-Sel', 0, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC5Polarity-Sel', 0, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC6Polarity-Sel', 0, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC7Polarity-Sel', 0, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC2NrPulses-SP', 1, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC3NrPulses-SP', 1, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC4NrPulses-SP', 1, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC5NrPulses-SP', 1, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC6NrPulses-SP', 1, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC7NrPulses-SP', 1, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC2DelayRaw-SP', 1, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC3DelayRaw-SP', 1, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC4DelayRaw-SP', 1, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC5DelayRaw-SP', 1, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC6DelayRaw-SP', 1, 0.0],
    ['IA-19RaBPM:TI-AMCFPGAEVR:AMC7DelayRaw-SP', 1, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:RTMFreq-SP', 124914500, 0.0],    # Hz
    ['IA-20RaBPM:TI-AMCFPGAEVR:AFCFreq-SP', 69396944, 0.0],     # Hz
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC2State-Sel', 0, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC3State-Sel', 0, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC4State-Sel', 1, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC5State-Sel', 1, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC6State-Sel', 0, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC7State-Sel', 1, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC2Src-Sel', 0, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC3Src-Sel', 0, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC4Src-Sel', 5, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC5Src-Sel', 6, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC6Src-Sel', 0, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC7Src-Sel', 3, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC2Dir-Sel', 0, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC3Dir-Sel', 0, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC4Dir-Sel', 0, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC5Dir-Sel', 0, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC6Dir-Sel', 0, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC7Dir-Sel', 0, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC2Evt-SP', 0, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC3Evt-SP', 0, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC4Evt-SP', 0, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC5Evt-SP', 0, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC6Evt-SP', 0, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC7Evt-SP', 0, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC2WidthRaw-SP', 1, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC3WidthRaw-SP', 1, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC4WidthRaw-SP', 1, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC5WidthRaw-SP', 1, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC6WidthRaw-SP', 1, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC7WidthRaw-SP', 1, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC2Polarity-Sel', 0, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC3Polarity-Sel', 0, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC4Polarity-Sel', 0, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC5Polarity-Sel', 0, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC6Polarity-Sel', 0, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC7Polarity-Sel', 0, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC2NrPulses-SP', 1, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC3NrPulses-SP', 1, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC4NrPulses-SP', 1, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC5NrPulses-SP', 1, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC6NrPulses-SP', 1, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC7NrPulses-SP', 1, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC2DelayRaw-SP', 1, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC3DelayRaw-SP', 1, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC4DelayRaw-SP', 1, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC5DelayRaw-SP', 1, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC6DelayRaw-SP', 1, 0.0],
    ['IA-20RaBPM:TI-AMCFPGAEVR:AMC7DelayRaw-SP', 1, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:RTMFreq-SP', 124914500, 0.0],    # Hz
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AFCFreq-SP', 69396944, 0.0],     # Hz
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC2State-Sel', 0, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC3State-Sel', 0, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC4State-Sel', 1, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC5State-Sel', 1, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC6State-Sel', 0, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC7State-Sel', 1, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC2Src-Sel', 0, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC3Src-Sel', 0, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC4Src-Sel', 5, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC5Src-Sel', 6, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC6Src-Sel', 0, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC7Src-Sel', 3, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC2Dir-Sel', 0, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC3Dir-Sel', 0, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC4Dir-Sel', 0, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC5Dir-Sel', 0, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC6Dir-Sel', 0, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC7Dir-Sel', 0, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC2Evt-SP', 0, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC3Evt-SP', 0, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC4Evt-SP', 0, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC5Evt-SP', 0, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC6Evt-SP', 0, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC7Evt-SP', 0, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC2WidthRaw-SP', 1, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC3WidthRaw-SP', 1, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC4WidthRaw-SP', 1, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC5WidthRaw-SP', 1, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC6WidthRaw-SP', 1, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC7WidthRaw-SP', 1, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC2Polarity-Sel', 0, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC3Polarity-Sel', 0, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC4Polarity-Sel', 0, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC5Polarity-Sel', 0, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC6Polarity-Sel', 0, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC7Polarity-Sel', 0, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC2NrPulses-SP', 1, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC3NrPulses-SP', 1, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC4NrPulses-SP', 1, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC5NrPulses-SP', 1, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC6NrPulses-SP', 1, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC7NrPulses-SP', 1, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC2DelayRaw-SP', 1, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC3DelayRaw-SP', 1, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC4DelayRaw-SP', 1, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC5DelayRaw-SP', 1, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC6DelayRaw-SP', 1, 0.0],
    ['IA-20RaBPMTL:TI-AMCFPGAEVR:AMC7DelayRaw-SP', 1, 0.0],

    # TB BPMs
    ['TB-01:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['TB-01:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['TB-01:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['TB-01:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['TB-01:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['TB-01:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['TB-01:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['TB-01:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['TB-01:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['TB-01:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['TB-01:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['TB-01:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['TB-01:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['TB-01:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['TB-01:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['TB-01:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['TB-01:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['TB-01:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['TB-01:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['TB-01:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['TB-01:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['TB-01:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['TB-01:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['TB-01:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['TB-01:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['TB-01:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['TB-01:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['TB-01:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['TB-01:DI-BPM-1:PosKx-SP', 21389980, 0.0],
    ['TB-01:DI-BPM-1:PosKy-SP', 21389980, 0.0],
    ['TB-01:DI-BPM-1:PosKq-SP', 21389980, 0.0],
    ['TB-01:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['TB-01:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['TB-01:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['TB-01:DI-BPM-1:ADCSi57xFreq-SP', 220910069.0, 0.0],
    ['TB-01:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['TB-01:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['TB-01:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['TB-01:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['TB-01:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['TB-01:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['TB-01:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['TB-01:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['TB-01:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['TB-01:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['TB-01:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['TB-01:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['TB-01:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['TB-01:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['TB-01:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['TB-01:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['TB-01:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['TB-01:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['TB-01:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['TB-01:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['TB-01:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['TB-01:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['TB-01:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['TB-01:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['TB-01:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['TB-01:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['TB-01:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['TB-01:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['TB-01:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['TB-01:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['TB-01:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['TB-01:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['TB-01:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['TB-01:DI-BPM-2:PosKx-SP', 21389980, 0.0],
    ['TB-01:DI-BPM-2:PosKy-SP', 21389980, 0.0],
    ['TB-01:DI-BPM-2:PosKq-SP', 21389980, 0.0],
    ['TB-01:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['TB-01:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['TB-01:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['TB-01:DI-BPM-2:ADCSi57xFreq-SP', 220910069.0, 0.0],
    ['TB-01:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['TB-01:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['TB-01:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['TB-01:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['TB-01:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['TB-02:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['TB-02:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['TB-02:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['TB-02:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['TB-02:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['TB-02:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['TB-02:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['TB-02:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['TB-02:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['TB-02:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['TB-02:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['TB-02:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['TB-02:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['TB-02:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['TB-02:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['TB-02:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['TB-02:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['TB-02:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['TB-02:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['TB-02:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['TB-02:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['TB-02:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['TB-02:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['TB-02:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['TB-02:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['TB-02:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['TB-02:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['TB-02:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['TB-02:DI-BPM-1:PosKx-SP', 21389980, 0.0],
    ['TB-02:DI-BPM-1:PosKy-SP', 21389980, 0.0],
    ['TB-02:DI-BPM-1:PosKq-SP', 21389980, 0.0],
    ['TB-02:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['TB-02:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['TB-02:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['TB-02:DI-BPM-1:ADCSi57xFreq-SP', 220910069.0, 0.0],
    ['TB-02:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['TB-02:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['TB-02:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['TB-02:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['TB-02:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['TB-02:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['TB-02:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['TB-02:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['TB-02:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['TB-02:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['TB-02:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['TB-02:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['TB-02:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['TB-02:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['TB-02:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['TB-02:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['TB-02:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['TB-02:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['TB-02:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['TB-02:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['TB-02:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['TB-02:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['TB-02:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['TB-02:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['TB-02:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['TB-02:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['TB-02:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['TB-02:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['TB-02:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['TB-02:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['TB-02:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['TB-02:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['TB-02:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['TB-02:DI-BPM-2:PosKx-SP', 21389980, 0.0],
    ['TB-02:DI-BPM-2:PosKy-SP', 21389980, 0.0],
    ['TB-02:DI-BPM-2:PosKq-SP', 21389980, 0.0],
    ['TB-02:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['TB-02:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['TB-02:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['TB-02:DI-BPM-2:ADCSi57xFreq-SP', 220910069.0, 0.0],
    ['TB-02:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['TB-02:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['TB-02:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['TB-02:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['TB-02:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['TB-03:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['TB-03:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['TB-03:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['TB-03:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['TB-03:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['TB-03:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['TB-03:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['TB-03:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['TB-03:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['TB-03:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['TB-03:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['TB-03:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['TB-03:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['TB-03:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['TB-03:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['TB-03:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['TB-03:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['TB-03:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['TB-03:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['TB-03:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['TB-03:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['TB-03:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['TB-03:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['TB-03:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['TB-03:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['TB-03:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['TB-03:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['TB-03:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['TB-03:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['TB-03:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['TB-03:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['TB-03:DI-BPM:ACQShots-SP', 1, 0.0],
    ['TB-03:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['TB-03:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['TB-03:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['TB-03:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['TB-03:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['TB-03:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['TB-03:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['TB-03:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['TB-03:DI-BPM:PosKsum-SP', 1, 0.0],
    ['TB-03:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['TB-03:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['TB-03:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['TB-03:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['TB-03:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['TB-03:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['TB-03:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['TB-03:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['TB-03:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['TB-03:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['TB-03:DI-BPM:PosKx-SP', 21389980, 0.0],
    ['TB-03:DI-BPM:PosKy-SP', 21389980, 0.0],
    ['TB-03:DI-BPM:PosKq-SP', 21389980, 0.0],
    ['TB-03:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['TB-03:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['TB-03:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['TB-03:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['TB-03:DI-BPM:ADCSi57xFreq-SP', 220910069.0, 0.0],
    ['TB-03:DI-BPM:SwMode-Sel', 1, 0.0],
    ['TB-03:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['TB-03:DI-BPM:SwDly-SP', 29, 0.0],
    ['TB-03:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['TB-03:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['TB-03:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['TB-04:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['TB-04:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['TB-04:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['TB-04:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['TB-04:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['TB-04:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['TB-04:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['TB-04:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['TB-04:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['TB-04:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['TB-04:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['TB-04:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['TB-04:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['TB-04:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['TB-04:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['TB-04:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['TB-04:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['TB-04:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['TB-04:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['TB-04:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['TB-04:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['TB-04:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['TB-04:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['TB-04:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['TB-04:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['TB-04:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['TB-04:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['TB-04:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['TB-04:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['TB-04:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['TB-04:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['TB-04:DI-BPM:ACQShots-SP', 1, 0.0],
    ['TB-04:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['TB-04:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['TB-04:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['TB-04:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['TB-04:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['TB-04:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['TB-04:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['TB-04:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['TB-04:DI-BPM:PosKsum-SP', 1, 0.0],
    ['TB-04:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['TB-04:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['TB-04:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['TB-04:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['TB-04:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['TB-04:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['TB-04:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['TB-04:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['TB-04:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['TB-04:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['TB-04:DI-BPM:PosKx-SP', 21389980, 0.0],
    ['TB-04:DI-BPM:PosKy-SP', 21389980, 0.0],
    ['TB-04:DI-BPM:PosKq-SP', 21389980, 0.0],
    ['TB-04:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['TB-04:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['TB-04:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['TB-04:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['TB-04:DI-BPM:ADCSi57xFreq-SP', 220910069.0, 0.0],
    ['TB-04:DI-BPM:SwMode-Sel', 1, 0.0],
    ['TB-04:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['TB-04:DI-BPM:SwDly-SP', 29, 0.0],
    ['TB-04:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['TB-04:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['TB-04:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],

    # BO BPMs
    ['BO-02U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-02U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-02U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-02U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-02U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-02U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-02U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-02U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-02U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-02U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-02U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-02U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-02U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-02U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-02U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-02U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-02U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-02U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-02U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-02U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-02U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-02U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-02U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-02U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-02U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-02U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-02U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-02U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-02U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-02U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-02U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-02U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-02U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-02U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-02U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-02U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-02U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-02U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-02U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-02U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-02U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-02U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-02U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-02U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-02U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-02U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-02U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-03U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-03U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-03U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-03U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-03U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-03U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-03U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-03U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-03U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-03U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-03U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-03U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-03U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-03U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-03U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-03U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-03U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-03U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-03U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-03U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-03U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-03U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-03U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-03U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-03U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-03U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-03U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-03U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-03U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-03U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-03U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-03U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-03U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-03U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-03U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-03U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-03U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-03U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-03U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-03U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-03U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-03U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-03U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-03U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-03U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-03U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-03U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-04U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-04U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-04U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-04U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-04U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-04U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-04U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-04U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-04U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-04U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-04U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-04U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-04U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-04U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-04U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-04U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-04U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-04U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-04U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-04U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-04U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-04U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-04U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-04U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-04U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-04U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-04U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-04U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-04U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-04U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-04U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-04U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-04U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-04U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-04U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-04U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-04U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-04U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-04U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-04U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-04U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-04U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-04U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-04U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-04U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-04U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-04U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-05U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-05U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-05U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-05U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-05U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-05U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-05U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-05U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-05U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-05U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-05U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-05U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-05U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-05U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-05U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-05U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-05U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-05U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-05U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-05U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-05U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-05U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-05U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-05U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-05U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-05U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-05U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-05U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-05U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-05U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-05U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-05U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-05U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-05U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-05U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-05U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-05U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-05U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-05U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-05U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-05U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-05U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-05U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-05U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-05U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-05U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-05U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-06U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-06U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-06U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-06U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-06U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-06U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-06U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-06U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-06U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-06U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-06U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-06U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-06U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-06U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-06U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-06U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-06U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-06U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-06U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-06U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-06U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-06U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-06U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-06U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-06U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-06U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-06U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-06U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-06U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-06U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-06U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-06U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-06U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-06U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-06U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-06U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-06U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-06U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-06U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-06U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-06U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-06U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-06U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-06U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-06U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-06U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-06U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-07U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-07U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-07U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-07U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-07U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-07U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-07U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-07U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-07U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-07U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-07U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-07U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-07U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-07U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-07U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-07U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-07U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-07U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-07U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-07U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-07U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-07U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-07U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-07U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-07U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-07U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-07U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-07U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-07U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-07U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-07U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-07U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-07U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-07U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-07U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-07U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-07U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-07U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-07U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-07U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-07U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-07U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-07U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-07U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-07U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-07U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-07U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-08U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-08U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-08U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-08U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-08U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-08U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-08U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-08U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-08U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-08U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-08U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-08U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-08U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-08U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-08U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-08U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-08U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-08U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-08U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-08U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-08U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-08U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-08U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-08U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-08U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-08U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-08U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-08U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-08U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-08U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-08U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-08U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-08U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-08U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-08U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-08U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-08U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-08U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-08U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-08U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-08U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-08U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-08U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-08U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-08U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-08U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-08U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-09U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-09U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-09U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-09U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-09U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-09U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-09U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-09U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-09U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-09U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-09U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-09U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-09U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-09U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-09U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-09U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-09U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-09U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-09U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-09U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-09U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-09U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-09U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-09U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-09U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-09U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-09U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-09U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-09U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-09U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-09U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-09U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-09U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-09U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-09U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-09U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-09U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-09U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-09U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-09U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-09U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-09U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-09U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-09U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-09U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-09U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-09U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-10U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-10U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-10U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-10U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-10U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-10U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-10U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-10U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-10U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-10U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-10U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-10U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-10U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-10U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-10U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-10U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-10U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-10U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-10U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-10U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-10U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-10U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-10U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-10U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-10U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-10U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-10U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-10U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-10U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-10U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-10U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-10U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-10U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-10U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-10U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-10U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-10U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-10U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-10U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-10U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-10U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-10U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-10U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-10U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-10U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-10U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-10U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-11U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-11U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-11U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-11U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-11U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-11U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-11U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-11U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-11U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-11U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-11U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-11U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-11U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-11U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-11U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-11U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-11U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-11U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-11U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-11U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-11U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-11U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-11U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-11U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-11U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-11U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-11U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-11U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-11U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-11U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-11U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-11U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-11U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-11U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-11U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-11U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-11U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-11U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-11U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-11U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-11U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-11U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-11U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-11U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-11U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-11U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-11U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-12U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-12U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-12U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-12U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-12U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-12U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-12U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-12U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-12U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-12U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-12U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-12U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-12U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-12U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-12U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-12U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-12U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-12U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-12U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-12U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-12U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-12U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-12U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-12U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-12U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-12U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-12U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-12U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-12U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-12U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-12U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-12U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-12U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-12U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-12U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-12U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-12U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-12U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-12U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-12U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-12U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-12U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-12U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-12U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-12U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-12U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-12U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-13U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-13U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-13U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-13U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-13U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-13U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-13U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-13U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-13U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-13U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-13U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-13U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-13U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-13U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-13U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-13U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-13U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-13U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-13U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-13U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-13U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-13U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-13U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-13U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-13U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-13U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-13U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-13U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-13U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-13U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-13U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-13U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-13U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-13U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-13U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-13U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-13U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-13U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-13U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-13U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-13U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-13U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-13U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-13U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-13U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-13U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-13U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-14U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-14U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-14U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-14U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-14U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-14U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-14U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-14U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-14U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-14U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-14U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-14U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-14U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-14U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-14U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-14U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-14U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-14U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-14U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-14U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-14U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-14U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-14U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-14U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-14U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-14U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-14U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-14U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-14U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-14U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-14U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-14U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-14U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-14U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-14U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-14U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-14U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-14U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-14U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-14U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-14U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-14U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-14U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-14U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-14U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-14U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-14U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-15U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-15U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-15U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-15U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-15U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-15U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-15U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-15U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-15U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-15U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-15U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-15U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-15U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-15U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-15U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-15U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-15U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-15U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-15U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-15U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-15U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-15U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-15U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-15U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-15U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-15U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-15U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-15U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-15U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-15U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-15U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-15U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-15U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-15U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-15U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-15U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-15U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-15U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-15U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-15U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-15U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-15U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-15U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-15U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-15U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-15U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-15U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-16U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-16U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-16U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-16U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-16U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-16U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-16U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-16U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-16U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-16U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-16U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-16U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-16U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-16U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-16U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-16U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-16U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-16U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-16U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-16U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-16U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-16U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-16U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-16U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-16U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-16U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-16U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-16U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-16U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-16U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-16U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-16U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-16U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-16U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-16U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-16U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-16U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-16U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-16U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-16U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-16U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-16U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-16U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-16U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-16U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-16U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-16U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-17U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-17U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-17U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-17U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-17U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-17U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-17U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-17U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-17U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-17U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-17U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-17U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-17U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-17U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-17U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-17U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-17U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-17U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-17U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-17U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-17U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-17U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-17U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-17U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-17U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-17U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-17U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-17U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-17U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-17U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-17U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-17U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-17U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-17U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-17U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-17U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-17U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-17U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-17U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-17U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-17U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-17U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-17U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-17U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-17U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-17U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-17U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-18U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-18U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-18U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-18U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-18U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-18U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-18U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-18U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-18U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-18U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-18U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-18U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-18U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-18U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-18U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-18U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-18U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-18U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-18U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-18U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-18U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-18U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-18U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-18U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-18U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-18U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-18U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-18U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-18U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-18U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-18U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-18U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-18U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-18U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-18U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-18U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-18U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-18U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-18U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-18U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-18U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-18U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-18U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-18U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-18U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-18U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-18U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-19U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-19U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-19U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-19U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-19U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-19U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-19U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-19U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-19U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-19U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-19U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-19U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-19U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-19U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-19U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-19U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-19U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-19U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-19U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-19U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-19U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-19U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-19U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-19U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-19U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-19U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-19U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-19U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-19U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-19U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-19U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-19U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-19U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-19U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-19U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-19U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-19U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-19U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-19U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-19U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-19U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-19U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-19U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-19U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-19U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-19U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-19U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-20U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-20U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-20U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-20U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-20U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-20U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-20U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-20U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-20U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-20U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-20U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-20U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-20U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-20U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-20U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-20U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-20U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-20U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-20U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-20U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-20U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-20U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-20U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-20U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-20U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-20U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-20U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-20U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-20U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-20U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-20U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-20U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-20U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-20U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-20U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-20U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-20U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-20U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-20U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-20U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-20U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-20U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-20U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-20U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-20U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-20U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-20U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-21U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-21U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-21U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-21U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-21U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-21U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-21U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-21U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-21U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-21U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-21U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-21U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-21U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-21U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-21U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-21U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-21U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-21U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-21U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-21U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-21U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-21U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-21U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-21U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-21U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-21U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-21U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-21U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-21U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-21U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-21U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-21U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-21U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-21U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-21U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-21U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-21U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-21U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-21U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-21U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-21U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-21U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-21U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-21U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-21U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-21U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-21U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-22U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-22U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-22U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-22U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-22U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-22U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-22U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-22U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-22U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-22U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-22U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-22U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-22U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-22U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-22U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-22U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-22U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-22U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-22U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-22U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-22U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-22U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-22U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-22U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-22U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-22U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-22U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-22U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-22U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-22U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-22U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-22U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-22U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-22U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-22U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-22U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-22U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-22U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-22U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-22U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-22U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-22U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-22U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-22U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-22U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-22U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-22U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-23U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-23U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-23U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-23U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-23U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-23U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-23U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-23U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-23U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-23U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-23U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-23U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-23U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-23U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-23U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-23U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-23U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-23U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-23U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-23U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-23U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-23U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-23U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-23U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-23U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-23U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-23U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-23U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-23U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-23U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-23U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-23U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-23U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-23U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-23U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-23U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-23U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-23U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-23U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-23U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-23U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-23U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-23U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-23U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-23U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-23U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-23U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-24U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-24U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-24U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-24U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-24U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-24U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-24U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-24U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-24U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-24U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-24U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-24U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-24U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-24U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-24U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-24U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-24U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-24U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-24U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-24U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-24U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-24U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-24U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-24U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-24U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-24U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-24U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-24U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-24U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-24U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-24U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-24U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-24U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-24U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-24U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-24U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-24U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-24U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-24U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-24U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-24U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-24U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-24U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-24U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-24U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-24U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-24U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-25U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-25U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-25U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-25U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-25U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-25U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-25U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-25U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-25U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-25U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-25U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-25U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-25U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-25U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-25U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-25U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-25U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-25U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-25U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-25U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-25U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-25U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-25U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-25U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-25U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-25U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-25U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-25U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-25U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-25U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-25U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-25U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-25U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-25U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-25U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-25U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-25U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-25U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-25U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-25U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-25U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-25U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-25U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-25U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-25U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-25U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-25U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-26U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-26U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-26U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-26U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-26U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-26U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-26U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-26U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-26U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-26U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-26U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-26U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-26U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-26U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-26U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-26U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-26U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-26U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-26U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-26U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-26U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-26U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-26U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-26U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-26U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-26U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-26U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-26U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-26U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-26U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-26U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-26U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-26U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-26U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-26U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-26U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-26U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-26U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-26U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-26U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-26U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-26U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-26U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-26U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-26U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-26U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-26U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-27U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-27U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-27U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-27U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-27U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-27U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-27U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-27U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-27U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-27U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-27U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-27U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-27U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-27U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-27U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-27U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-27U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-27U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-27U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-27U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-27U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-27U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-27U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-27U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-27U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-27U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-27U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-27U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-27U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-27U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-27U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-27U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-27U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-27U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-27U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-27U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-27U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-27U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-27U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-27U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-27U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-27U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-27U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-27U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-27U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-27U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-27U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-28U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-28U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-28U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-28U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-28U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-28U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-28U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-28U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-28U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-28U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-28U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-28U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-28U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-28U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-28U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-28U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-28U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-28U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-28U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-28U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-28U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-28U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-28U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-28U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-28U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-28U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-28U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-28U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-28U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-28U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-28U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-28U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-28U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-28U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-28U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-28U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-28U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-28U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-28U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-28U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-28U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-28U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-28U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-28U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-28U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-28U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-28U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-29U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-29U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-29U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-29U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-29U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-29U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-29U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-29U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-29U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-29U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-29U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-29U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-29U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-29U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-29U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-29U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-29U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-29U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-29U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-29U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-29U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-29U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-29U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-29U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-29U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-29U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-29U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-29U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-29U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-29U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-29U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-29U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-29U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-29U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-29U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-29U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-29U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-29U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-29U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-29U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-29U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-29U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-29U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-29U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-29U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-29U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-29U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-30U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-30U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-30U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-30U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-30U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-30U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-30U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-30U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-30U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-30U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-30U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-30U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-30U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-30U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-30U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-30U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-30U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-30U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-30U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-30U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-30U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-30U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-30U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-30U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-30U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-30U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-30U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-30U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-30U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-30U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-30U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-30U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-30U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-30U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-30U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-30U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-30U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-30U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-30U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-30U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-30U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-30U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-30U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-30U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-30U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-30U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-30U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-31U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-31U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-31U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-31U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-31U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-31U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-31U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-31U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-31U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-31U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-31U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-31U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-31U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-31U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-31U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-31U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-31U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-31U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-31U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-31U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-31U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-31U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-31U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-31U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-31U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-31U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-31U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-31U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-31U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-31U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-31U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-31U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-31U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-31U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-31U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-31U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-31U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-31U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-31U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-31U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-31U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-31U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-31U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-31U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-31U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-31U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-31U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-32U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-32U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-32U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-32U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-32U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-32U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-32U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-32U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-32U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-32U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-32U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-32U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-32U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-32U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-32U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-32U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-32U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-32U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-32U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-32U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-32U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-32U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-32U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-32U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-32U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-32U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-32U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-32U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-32U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-32U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-32U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-32U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-32U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-32U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-32U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-32U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-32U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-32U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-32U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-32U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-32U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-32U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-32U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-32U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-32U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-32U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-32U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-33U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-33U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-33U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-33U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-33U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-33U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-33U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-33U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-33U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-33U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-33U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-33U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-33U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-33U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-33U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-33U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-33U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-33U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-33U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-33U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-33U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-33U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-33U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-33U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-33U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-33U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-33U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-33U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-33U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-33U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-33U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-33U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-33U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-33U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-33U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-33U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-33U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-33U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-33U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-33U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-33U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-33U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-33U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-33U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-33U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-33U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-33U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-34U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-34U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-34U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-34U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-34U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-34U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-34U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-34U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-34U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-34U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-34U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-34U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-34U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-34U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-34U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-34U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-34U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-34U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-34U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-34U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-34U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-34U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-34U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-34U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-34U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-34U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-34U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-34U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-34U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-34U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-34U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-34U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-34U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-34U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-34U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-34U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-34U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-34U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-34U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-34U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-34U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-34U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-34U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-34U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-34U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-34U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-34U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-35U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-35U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-35U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-35U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-35U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-35U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-35U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-35U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-35U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-35U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-35U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-35U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-35U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-35U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-35U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-35U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-35U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-35U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-35U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-35U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-35U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-35U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-35U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-35U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-35U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-35U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-35U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-35U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-35U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-35U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-35U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-35U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-35U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-35U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-35U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-35U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-35U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-35U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-35U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-35U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-35U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-35U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-35U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-35U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-35U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-35U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-35U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-36U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-36U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-36U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-36U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-36U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-36U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-36U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-36U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-36U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-36U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-36U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-36U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-36U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-36U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-36U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-36U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-36U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-36U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-36U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-36U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-36U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-36U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-36U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-36U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-36U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-36U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-36U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-36U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-36U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-36U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-36U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-36U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-36U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-36U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-36U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-36U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-36U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-36U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-36U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-36U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-36U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-36U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-36U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-36U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-36U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-36U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-36U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-37U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-37U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-37U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-37U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-37U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-37U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-37U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-37U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-37U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-37U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-37U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-37U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-37U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-37U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-37U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-37U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-37U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-37U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-37U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-37U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-37U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-37U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-37U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-37U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-37U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-37U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-37U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-37U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-37U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-37U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-37U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-37U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-37U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-37U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-37U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-37U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-37U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-37U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-37U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-37U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-37U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-37U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-37U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-37U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-37U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-37U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-37U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-38U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-38U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-38U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-38U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-38U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-38U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-38U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-38U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-38U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-38U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-38U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-38U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-38U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-38U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-38U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-38U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-38U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-38U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-38U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-38U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-38U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-38U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-38U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-38U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-38U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-38U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-38U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-38U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-38U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-38U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-38U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-38U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-38U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-38U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-38U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-38U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-38U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-38U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-38U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-38U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-38U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-38U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-38U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-38U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-38U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-38U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-38U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-39U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-39U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-39U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-39U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-39U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-39U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-39U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-39U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-39U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-39U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-39U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-39U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-39U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-39U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-39U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-39U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-39U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-39U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-39U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-39U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-39U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-39U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-39U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-39U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-39U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-39U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-39U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-39U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-39U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-39U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-39U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-39U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-39U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-39U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-39U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-39U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-39U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-39U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-39U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-39U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-39U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-39U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-39U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-39U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-39U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-39U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-39U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-40U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-40U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-40U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-40U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-40U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-40U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-40U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-40U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-40U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-40U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-40U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-40U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-40U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-40U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-40U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-40U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-40U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-40U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-40U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-40U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-40U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-40U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-40U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-40U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-40U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-40U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-40U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-40U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-40U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-40U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-40U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-40U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-40U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-40U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-40U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-40U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-40U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-40U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-40U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-40U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-40U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-40U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-40U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-40U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-40U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-40U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-40U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-41U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-41U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-41U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-41U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-41U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-41U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-41U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-41U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-41U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-41U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-41U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-41U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-41U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-41U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-41U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-41U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-41U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-41U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-41U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-41U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-41U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-41U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-41U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-41U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-41U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-41U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-41U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-41U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-41U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-41U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-41U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-41U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-41U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-41U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-41U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-41U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-41U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-41U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-41U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-41U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-41U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-41U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-41U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-41U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-41U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-41U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-41U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-42U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-42U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-42U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-42U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-42U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-42U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-42U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-42U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-42U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-42U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-42U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-42U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-42U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-42U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-42U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-42U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-42U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-42U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-42U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-42U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-42U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-42U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-42U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-42U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-42U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-42U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-42U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-42U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-42U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-42U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-42U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-42U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-42U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-42U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-42U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-42U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-42U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-42U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-42U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-42U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-42U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-42U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-42U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-42U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-42U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-42U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-42U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-43U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-43U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-43U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-43U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-43U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-43U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-43U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-43U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-43U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-43U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-43U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-43U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-43U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-43U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-43U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-43U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-43U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-43U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-43U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-43U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-43U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-43U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-43U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-43U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-43U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-43U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-43U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-43U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-43U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-43U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-43U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-43U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-43U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-43U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-43U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-43U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-43U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-43U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-43U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-43U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-43U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-43U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-43U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-43U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-43U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-43U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-43U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-44U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-44U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-44U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-44U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-44U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-44U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-44U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-44U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-44U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-44U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-44U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-44U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-44U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-44U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-44U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-44U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-44U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-44U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-44U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-44U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-44U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-44U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-44U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-44U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-44U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-44U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-44U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-44U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-44U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-44U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-44U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-44U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-44U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-44U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-44U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-44U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-44U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-44U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-44U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-44U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-44U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-44U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-44U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-44U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-44U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-44U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-44U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-45U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-45U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-45U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-45U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-45U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-45U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-45U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-45U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-45U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-45U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-45U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-45U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-45U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-45U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-45U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-45U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-45U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-45U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-45U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-45U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-45U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-45U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-45U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-45U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-45U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-45U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-45U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-45U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-45U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-45U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-45U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-45U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-45U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-45U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-45U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-45U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-45U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-45U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-45U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-45U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-45U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-45U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-45U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-45U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-45U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-45U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-45U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-46U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-46U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-46U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-46U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-46U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-46U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-46U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-46U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-46U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-46U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-46U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-46U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-46U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-46U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-46U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-46U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-46U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-46U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-46U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-46U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-46U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-46U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-46U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-46U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-46U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-46U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-46U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-46U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-46U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-46U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-46U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-46U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-46U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-46U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-46U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-46U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-46U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-46U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-46U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-46U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-46U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-46U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-46U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-46U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-46U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-46U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-46U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-47U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-47U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-47U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-47U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-47U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-47U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-47U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-47U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-47U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-47U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-47U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-47U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-47U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-47U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-47U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-47U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-47U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-47U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-47U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-47U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-47U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-47U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-47U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-47U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-47U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-47U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-47U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-47U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-47U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-47U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-47U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-47U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-47U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-47U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-47U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-47U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-47U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-47U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-47U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-47U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-47U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-47U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-47U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-47U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-47U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-47U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-47U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-48U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-48U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-48U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-48U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-48U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-48U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-48U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-48U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-48U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-48U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-48U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-48U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-48U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-48U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-48U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-48U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-48U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-48U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-48U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-48U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-48U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-48U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-48U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-48U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-48U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-48U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-48U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-48U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-48U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-48U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-48U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-48U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-48U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-48U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-48U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-48U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-48U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-48U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-48U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-48U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-48U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-48U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-48U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-48U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-48U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-48U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-48U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-49U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-49U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-49U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-49U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-49U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-49U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-49U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-49U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-49U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-49U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-49U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-49U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-49U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-49U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-49U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-49U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-49U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-49U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-49U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-49U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-49U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-49U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-49U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-49U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-49U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-49U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-49U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-49U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-49U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-49U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-49U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-49U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-49U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-49U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-49U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-49U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-49U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-49U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-49U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-49U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-49U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-49U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-49U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-49U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-49U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-49U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-49U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-50U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-50U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-50U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-50U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-50U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-50U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-50U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-50U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-50U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-50U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-50U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-50U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-50U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-50U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-50U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-50U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-50U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-50U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-50U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-50U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-50U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-50U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-50U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-50U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-50U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-50U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-50U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-50U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-50U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-50U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-50U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-50U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-50U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-50U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-50U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-50U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-50U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-50U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-50U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-50U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-50U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-50U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-50U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-50U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-50U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-50U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-50U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],
    ['BO-01U:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['BO-01U:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['BO-01U:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['BO-01U:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['BO-01U:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['BO-01U:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['BO-01U:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['BO-01U:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['BO-01U:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['BO-01U:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['BO-01U:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['BO-01U:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['BO-01U:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['BO-01U:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['BO-01U:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['BO-01U:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['BO-01U:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['BO-01U:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['BO-01U:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:ACQShots-SP', 1, 0.0],
    ['BO-01U:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['BO-01U:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['BO-01U:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['BO-01U:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['BO-01U:DI-BPM:PosKsum-SP', 1, 0.0],
    ['BO-01U:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['BO-01U:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['BO-01U:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['BO-01U:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['BO-01U:DI-BPM:INFOClkFreq-SP', 218446014.0, 0.0],
    ['BO-01U:DI-BPM:INFOHarmonicNumber-SP', 828, 0.0],
    ['BO-01U:DI-BPM:INFOTBTRate-SP', 362, 0.0],
    ['BO-01U:DI-BPM:INFOFOFBRate-SP', 8688, 0.0],
    ['BO-01U:DI-BPM:INFOMONITRate-SP', 21685248, 0.0],
    ['BO-01U:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['BO-01U:DI-BPM:PosKx-SP', 12798633, 0.0],
    ['BO-01U:DI-BPM:PosKy-SP', 12798633, 0.0],
    ['BO-01U:DI-BPM:PosKq-SP', 12798633, 0.0],
    ['BO-01U:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['BO-01U:DI-BPM:ADCAD9510BDiv-SP', 362, 0.0],
    ['BO-01U:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['BO-01U:DI-BPM:ADCAD9510RDiv-SP', 115, 0.0],
    ['BO-01U:DI-BPM:ADCSi57xFreq-SP', 218406014.0, 0.0],
    ['BO-01U:DI-BPM:SwMode-Sel', 1, 0.0],
    ['BO-01U:DI-BPM:SwDivClk-SP', 8688, 0.0],
    ['BO-01U:DI-BPM:SwDly-SP', 28, 0.0],
    ['BO-01U:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['BO-01U:DI-BPM:SwDataMaskSamples-SP', 1810, 0.0],

    # TS BPMs
    ['TS-01:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['TS-01:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['TS-01:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['TS-01:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['TS-01:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['TS-01:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['TS-01:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['TS-01:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['TS-01:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['TS-01:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['TS-01:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['TS-01:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['TS-01:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['TS-01:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['TS-01:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['TS-01:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['TS-01:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['TS-01:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['TS-01:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['TS-01:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['TS-01:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['TS-01:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['TS-01:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['TS-01:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['TS-01:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['TS-01:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['TS-01:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['TS-01:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['TS-01:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['TS-01:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['TS-01:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['TS-01:DI-BPM:ACQShots-SP', 1, 0.0],
    ['TS-01:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['TS-01:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['TS-01:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['TS-01:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['TS-01:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['TS-01:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['TS-01:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['TS-01:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['TS-01:DI-BPM:PosKsum-SP', 1, 0.0],
    ['TS-01:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['TS-01:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['TS-01:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['TS-01:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['TS-01:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['TS-01:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['TS-01:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['TS-01:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['TS-01:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['TS-01:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['TS-01:DI-BPM:PosKx-SP', 21389980, 0.0],
    ['TS-01:DI-BPM:PosKy-SP', 21389980, 0.0],
    ['TS-01:DI-BPM:PosKq-SP', 21389980, 0.0],
    ['TS-01:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['TS-01:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['TS-01:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['TS-01:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['TS-01:DI-BPM:ADCSi57xFreq-SP', 220910069.0, 0.0],
    ['TS-01:DI-BPM:SwMode-Sel', 1, 0.0],
    ['TS-01:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['TS-01:DI-BPM:SwDly-SP', 29, 0.0],
    ['TS-01:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['TS-01:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['TS-01:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['TS-02:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['TS-02:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['TS-02:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['TS-02:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['TS-02:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['TS-02:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['TS-02:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['TS-02:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['TS-02:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['TS-02:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['TS-02:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['TS-02:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['TS-02:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['TS-02:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['TS-02:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['TS-02:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['TS-02:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['TS-02:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['TS-02:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['TS-02:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['TS-02:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['TS-02:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['TS-02:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['TS-02:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['TS-02:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['TS-02:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['TS-02:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['TS-02:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['TS-02:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['TS-02:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['TS-02:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['TS-02:DI-BPM:ACQShots-SP', 1, 0.0],
    ['TS-02:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['TS-02:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['TS-02:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['TS-02:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['TS-02:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['TS-02:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['TS-02:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['TS-02:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['TS-02:DI-BPM:PosKsum-SP', 1, 0.0],
    ['TS-02:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['TS-02:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['TS-02:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['TS-02:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['TS-02:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['TS-02:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['TS-02:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['TS-02:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['TS-02:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['TS-02:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['TS-02:DI-BPM:PosKx-SP', 21389980, 0.0],
    ['TS-02:DI-BPM:PosKy-SP', 21389980, 0.0],
    ['TS-02:DI-BPM:PosKq-SP', 21389980, 0.0],
    ['TS-02:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['TS-02:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['TS-02:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['TS-02:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['TS-02:DI-BPM:ADCSi57xFreq-SP', 220910069.0, 0.0],
    ['TS-02:DI-BPM:SwMode-Sel', 1, 0.0],
    ['TS-02:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['TS-02:DI-BPM:SwDly-SP', 29, 0.0],
    ['TS-02:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['TS-02:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['TS-02:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['TS-03:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['TS-03:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['TS-03:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['TS-03:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['TS-03:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['TS-03:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['TS-03:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['TS-03:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['TS-03:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['TS-03:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['TS-03:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['TS-03:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['TS-03:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['TS-03:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['TS-03:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['TS-03:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['TS-03:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['TS-03:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['TS-03:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['TS-03:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['TS-03:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['TS-03:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['TS-03:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['TS-03:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['TS-03:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['TS-03:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['TS-03:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['TS-03:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['TS-03:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['TS-03:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['TS-03:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['TS-03:DI-BPM:ACQShots-SP', 1, 0.0],
    ['TS-03:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['TS-03:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['TS-03:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['TS-03:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['TS-03:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['TS-03:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['TS-03:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['TS-03:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['TS-03:DI-BPM:PosKsum-SP', 1, 0.0],
    ['TS-03:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['TS-03:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['TS-03:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['TS-03:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['TS-03:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['TS-03:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['TS-03:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['TS-03:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['TS-03:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['TS-03:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['TS-03:DI-BPM:PosKx-SP', 21389980, 0.0],
    ['TS-03:DI-BPM:PosKy-SP', 21389980, 0.0],
    ['TS-03:DI-BPM:PosKq-SP', 21389980, 0.0],
    ['TS-03:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['TS-03:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['TS-03:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['TS-03:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['TS-03:DI-BPM:ADCSi57xFreq-SP', 220910069.0, 0.0],
    ['TS-03:DI-BPM:SwMode-Sel', 1, 0.0],
    ['TS-03:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['TS-03:DI-BPM:SwDly-SP', 29, 0.0],
    ['TS-03:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['TS-03:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['TS-03:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['TS-04:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['TS-04:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['TS-04:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['TS-04:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['TS-04:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['TS-04:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['TS-04:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['TS-04:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['TS-04:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['TS-04:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['TS-04:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['TS-04:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['TS-04:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['TS-04:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['TS-04:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['TS-04:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['TS-04:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['TS-04:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['TS-04:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['TS-04:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['TS-04:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['TS-04:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['TS-04:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['TS-04:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['TS-04:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['TS-04:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['TS-04:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['TS-04:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['TS-04:DI-BPM-1:PosKx-SP', 21389980, 0.0],
    ['TS-04:DI-BPM-1:PosKy-SP', 21389980, 0.0],
    ['TS-04:DI-BPM-1:PosKq-SP', 21389980, 0.0],
    ['TS-04:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['TS-04:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['TS-04:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['TS-04:DI-BPM-1:ADCSi57xFreq-SP', 220910069.0, 0.0],
    ['TS-04:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['TS-04:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['TS-04:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['TS-04:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['TS-04:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['TS-04:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['TS-04:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['TS-04:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['TS-04:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['TS-04:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['TS-04:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['TS-04:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['TS-04:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['TS-04:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['TS-04:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['TS-04:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['TS-04:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['TS-04:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['TS-04:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['TS-04:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['TS-04:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['TS-04:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['TS-04:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['TS-04:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['TS-04:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['TS-04:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['TS-04:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['TS-04:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['TS-04:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['TS-04:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['TS-04:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['TS-04:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['TS-04:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['TS-04:DI-BPM-2:PosKx-SP', 21389980, 0.0],
    ['TS-04:DI-BPM-2:PosKy-SP', 21389980, 0.0],
    ['TS-04:DI-BPM-2:PosKq-SP', 21389980, 0.0],
    ['TS-04:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['TS-04:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['TS-04:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['TS-04:DI-BPM-2:ADCSi57xFreq-SP', 220910069.0, 0.0],
    ['TS-04:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['TS-04:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['TS-04:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['TS-04:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['TS-04:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],

    # SI BPMs
    ['SI-01M2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-01M2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-01M2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-01M2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-01M2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-01M2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-01M2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-01M2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-01M2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-01M2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-01M2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-01M2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-01M2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-01M2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-01M2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-01M2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-01M2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-01M2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-01M2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-01M2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-01M2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-01M2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-01M2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-01M2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-01M2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-01M2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-01M2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-01M2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-01M2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-01M2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-01M2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-01M2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-01M2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-01M2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-01M2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-01M2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-01M2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-01M2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-01M2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-01M2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-01C1:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-01C1:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-01C1:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-01C1:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-01C1:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-01C1:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-01C1:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-01C1:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-01C1:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-01C1:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-01C1:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-01C1:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-01C1:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-01C1:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-01C1:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-01C1:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-01C1:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-01C1:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-01C1:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-01C1:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-01C1:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-01C1:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-01C1:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-01C1:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-01C1:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-01C1:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-01C1:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-01C1:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-01C1:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-01C1:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-01C1:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-01C1:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-01C1:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-01C1:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-01C1:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-01C1:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-01C1:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-01C1:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-01C1:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-01C1:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-01C1:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-01C1:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-01C1:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-01C1:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-01C1:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-01C1:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-01C1:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-01C1:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-01C1:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-01C1:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-01C1:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-01C1:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-01C1:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-01C1:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-01C1:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-01C1:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-01C1:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-01C1:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-01C1:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-01C1:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-01C1:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-01C1:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-01C1:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-01C1:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-01C1:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-01C1:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-01C1:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-01C1:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-01C1:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-01C1:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-01C2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-01C2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-01C2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-01C2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-01C2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-01C2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-01C2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-01C2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-01C2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-01C2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-01C2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-01C2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-01C2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-01C2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-01C2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-01C2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-01C2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-01C2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-01C2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-01C2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-01C2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-01C2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-01C2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-01C2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-01C2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-01C2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-01C2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-01C2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-01C2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-01C2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-01C2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-01C2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-01C2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-01C2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-01C2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-01C2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-01C2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-01C2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-01C2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-01C2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-01C3:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-01C3:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-01C3:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-01C3:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-01C3:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-01C3:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-01C3:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-01C3:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-01C3:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-01C3:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-01C3:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-01C3:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-01C3:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-01C3:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-01C3:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-01C3:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-01C3:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-01C3:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-01C3:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-01C3:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-01C3:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-01C3:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-01C3:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-01C3:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-01C3:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-01C3:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-01C3:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-01C3:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-01C3:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-01C3:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-01C3:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-01C3:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-01C3:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-01C3:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-01C3:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-01C3:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-01C3:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-01C3:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-01C3:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-01C3:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-01C3:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-01C3:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-01C3:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-01C3:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-01C3:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-01C3:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-01C3:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-01C3:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-01C3:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-01C3:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-01C3:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-01C3:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-01C3:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-01C3:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-01C3:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-01C3:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-01C3:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-01C3:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-01C3:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-01C3:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-01C3:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-01C3:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-01C3:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-01C3:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-01C3:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-01C3:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-01C3:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-01C3:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-01C3:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-01C3:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-01C4:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-01C4:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-01C4:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-01C4:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-01C4:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-01C4:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-01C4:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-01C4:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-01C4:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-01C4:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-01C4:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-01C4:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-01C4:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-01C4:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-01C4:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-01C4:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-01C4:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-01C4:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-01C4:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-01C4:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-01C4:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-01C4:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-01C4:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-01C4:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-01C4:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-01C4:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-01C4:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-01C4:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-01C4:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-01C4:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-01C4:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-01C4:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-01C4:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-01C4:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-01C4:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-01C4:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-01C4:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-01C4:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-01C4:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-01C4:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-02M1:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-02M1:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-02M1:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-02M1:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-02M1:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-02M1:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-02M1:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-02M1:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-02M1:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-02M1:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-02M1:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-02M1:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-02M1:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-02M1:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-02M1:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-02M1:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-02M1:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-02M1:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-02M1:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-02M1:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-02M1:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-02M1:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-02M1:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-02M1:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-02M1:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-02M1:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-02M1:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-02M1:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-02M1:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-02M1:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-02M1:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-02M1:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-02M1:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-02M1:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-02M1:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-02M1:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-02M1:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-02M1:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-02M1:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-02M1:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-02M2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-02M2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-02M2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-02M2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-02M2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-02M2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-02M2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-02M2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-02M2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-02M2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-02M2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-02M2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-02M2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-02M2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-02M2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-02M2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-02M2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-02M2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-02M2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-02M2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-02M2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-02M2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-02M2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-02M2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-02M2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-02M2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-02M2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-02M2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-02M2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-02M2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-02M2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-02M2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-02M2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-02M2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-02M2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-02M2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-02M2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-02M2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-02M2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-02M2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-02C1:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-02C1:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-02C1:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-02C1:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-02C1:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-02C1:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-02C1:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-02C1:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-02C1:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-02C1:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-02C1:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-02C1:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-02C1:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-02C1:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-02C1:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-02C1:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-02C1:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-02C1:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-02C1:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-02C1:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-02C1:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-02C1:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-02C1:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-02C1:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-02C1:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-02C1:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-02C1:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-02C1:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-02C1:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-02C1:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-02C1:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-02C1:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-02C1:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-02C1:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-02C1:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-02C1:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-02C1:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-02C1:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-02C1:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-02C1:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-02C1:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-02C1:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-02C1:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-02C1:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-02C1:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-02C1:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-02C1:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-02C1:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-02C1:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-02C1:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-02C1:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-02C1:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-02C1:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-02C1:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-02C1:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-02C1:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-02C1:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-02C1:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-02C1:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-02C1:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-02C1:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-02C1:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-02C1:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-02C1:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-02C1:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-02C1:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-02C1:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-02C1:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-02C1:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-02C1:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-02C2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-02C2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-02C2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-02C2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-02C2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-02C2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-02C2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-02C2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-02C2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-02C2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-02C2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-02C2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-02C2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-02C2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-02C2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-02C2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-02C2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-02C2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-02C2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-02C2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-02C2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-02C2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-02C2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-02C2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-02C2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-02C2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-02C2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-02C2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-02C2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-02C2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-02C2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-02C2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-02C2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-02C2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-02C2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-02C2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-02C2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-02C2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-02C2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-02C2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-02C3:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-02C3:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-02C3:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-02C3:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-02C3:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-02C3:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-02C3:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-02C3:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-02C3:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-02C3:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-02C3:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-02C3:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-02C3:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-02C3:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-02C3:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-02C3:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-02C3:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-02C3:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-02C3:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-02C3:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-02C3:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-02C3:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-02C3:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-02C3:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-02C3:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-02C3:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-02C3:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-02C3:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-02C3:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-02C3:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-02C3:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-02C3:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-02C3:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-02C3:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-02C3:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-02C3:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-02C3:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-02C3:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-02C3:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-02C3:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-02C3:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-02C3:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-02C3:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-02C3:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-02C3:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-02C3:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-02C3:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-02C3:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-02C3:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-02C3:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-02C3:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-02C3:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-02C3:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-02C3:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-02C3:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-02C3:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-02C3:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-02C3:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-02C3:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-02C3:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-02C3:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-02C3:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-02C3:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-02C3:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-02C3:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-02C3:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-02C3:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-02C3:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-02C3:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-02C3:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-02C4:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-02C4:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-02C4:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-02C4:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-02C4:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-02C4:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-02C4:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-02C4:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-02C4:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-02C4:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-02C4:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-02C4:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-02C4:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-02C4:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-02C4:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-02C4:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-02C4:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-02C4:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-02C4:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-02C4:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-02C4:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-02C4:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-02C4:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-02C4:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-02C4:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-02C4:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-02C4:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-02C4:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-02C4:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-02C4:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-02C4:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-02C4:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-02C4:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-02C4:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-02C4:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-02C4:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-02C4:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-02C4:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-02C4:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-02C4:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-03M1:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-03M1:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-03M1:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-03M1:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-03M1:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-03M1:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-03M1:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-03M1:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-03M1:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-03M1:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-03M1:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-03M1:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-03M1:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-03M1:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-03M1:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-03M1:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-03M1:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-03M1:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-03M1:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-03M1:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-03M1:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-03M1:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-03M1:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-03M1:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-03M1:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-03M1:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-03M1:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-03M1:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-03M1:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-03M1:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-03M1:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-03M1:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-03M1:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-03M1:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-03M1:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-03M1:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-03M1:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-03M1:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-03M1:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-03M1:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-03M2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-03M2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-03M2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-03M2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-03M2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-03M2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-03M2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-03M2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-03M2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-03M2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-03M2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-03M2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-03M2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-03M2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-03M2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-03M2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-03M2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-03M2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-03M2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-03M2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-03M2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-03M2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-03M2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-03M2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-03M2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-03M2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-03M2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-03M2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-03M2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-03M2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-03M2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-03M2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-03M2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-03M2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-03M2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-03M2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-03M2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-03M2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-03M2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-03M2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-03C1:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-03C1:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-03C1:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-03C1:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-03C1:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-03C1:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-03C1:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-03C1:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-03C1:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-03C1:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-03C1:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-03C1:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-03C1:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-03C1:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-03C1:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-03C1:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-03C1:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-03C1:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-03C1:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-03C1:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-03C1:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-03C1:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-03C1:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-03C1:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-03C1:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-03C1:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-03C1:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-03C1:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-03C1:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-03C1:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-03C1:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-03C1:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-03C1:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-03C1:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-03C1:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-03C1:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-03C1:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-03C1:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-03C1:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-03C1:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-03C1:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-03C1:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-03C1:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-03C1:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-03C1:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-03C1:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-03C1:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-03C1:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-03C1:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-03C1:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-03C1:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-03C1:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-03C1:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-03C1:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-03C1:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-03C1:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-03C1:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-03C1:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-03C1:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-03C1:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-03C1:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-03C1:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-03C1:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-03C1:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-03C1:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-03C1:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-03C1:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-03C1:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-03C1:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-03C1:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-03C2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-03C2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-03C2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-03C2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-03C2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-03C2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-03C2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-03C2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-03C2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-03C2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-03C2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-03C2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-03C2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-03C2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-03C2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-03C2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-03C2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-03C2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-03C2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-03C2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-03C2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-03C2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-03C2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-03C2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-03C2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-03C2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-03C2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-03C2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-03C2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-03C2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-03C2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-03C2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-03C2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-03C2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-03C2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-03C2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-03C2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-03C2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-03C2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-03C2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-03C3:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-03C3:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-03C3:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-03C3:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-03C3:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-03C3:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-03C3:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-03C3:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-03C3:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-03C3:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-03C3:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-03C3:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-03C3:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-03C3:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-03C3:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-03C3:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-03C3:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-03C3:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-03C3:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-03C3:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-03C3:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-03C3:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-03C3:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-03C3:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-03C3:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-03C3:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-03C3:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-03C3:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-03C3:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-03C3:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-03C3:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-03C3:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-03C3:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-03C3:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-03C3:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-03C3:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-03C3:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-03C3:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-03C3:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-03C3:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-03C3:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-03C3:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-03C3:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-03C3:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-03C3:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-03C3:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-03C3:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-03C3:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-03C3:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-03C3:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-03C3:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-03C3:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-03C3:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-03C3:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-03C3:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-03C3:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-03C3:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-03C3:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-03C3:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-03C3:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-03C3:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-03C3:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-03C3:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-03C3:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-03C3:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-03C3:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-03C3:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-03C3:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-03C3:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-03C3:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-03C4:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-03C4:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-03C4:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-03C4:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-03C4:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-03C4:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-03C4:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-03C4:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-03C4:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-03C4:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-03C4:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-03C4:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-03C4:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-03C4:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-03C4:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-03C4:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-03C4:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-03C4:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-03C4:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-03C4:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-03C4:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-03C4:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-03C4:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-03C4:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-03C4:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-03C4:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-03C4:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-03C4:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-03C4:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-03C4:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-03C4:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-03C4:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-03C4:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-03C4:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-03C4:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-03C4:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-03C4:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-03C4:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-03C4:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-03C4:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-04M1:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-04M1:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-04M1:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-04M1:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-04M1:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-04M1:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-04M1:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-04M1:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-04M1:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-04M1:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-04M1:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-04M1:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-04M1:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-04M1:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-04M1:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-04M1:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-04M1:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-04M1:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-04M1:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-04M1:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-04M1:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-04M1:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-04M1:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-04M1:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-04M1:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-04M1:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-04M1:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-04M1:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-04M1:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-04M1:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-04M1:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-04M1:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-04M1:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-04M1:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-04M1:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-04M1:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-04M1:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-04M1:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-04M1:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-04M1:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-04M2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-04M2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-04M2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-04M2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-04M2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-04M2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-04M2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-04M2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-04M2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-04M2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-04M2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-04M2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-04M2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-04M2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-04M2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-04M2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-04M2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-04M2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-04M2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-04M2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-04M2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-04M2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-04M2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-04M2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-04M2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-04M2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-04M2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-04M2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-04M2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-04M2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-04M2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-04M2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-04M2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-04M2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-04M2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-04M2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-04M2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-04M2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-04M2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-04M2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-04C1:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-04C1:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-04C1:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-04C1:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-04C1:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-04C1:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-04C1:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-04C1:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-04C1:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-04C1:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-04C1:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-04C1:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-04C1:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-04C1:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-04C1:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-04C1:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-04C1:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-04C1:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-04C1:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-04C1:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-04C1:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-04C1:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-04C1:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-04C1:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-04C1:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-04C1:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-04C1:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-04C1:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-04C1:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-04C1:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-04C1:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-04C1:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-04C1:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-04C1:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-04C1:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-04C1:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-04C1:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-04C1:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-04C1:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-04C1:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-04C1:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-04C1:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-04C1:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-04C1:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-04C1:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-04C1:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-04C1:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-04C1:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-04C1:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-04C1:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-04C1:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-04C1:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-04C1:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-04C1:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-04C1:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-04C1:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-04C1:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-04C1:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-04C1:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-04C1:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-04C1:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-04C1:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-04C1:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-04C1:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-04C1:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-04C1:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-04C1:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-04C1:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-04C1:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-04C1:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-04C2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-04C2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-04C2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-04C2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-04C2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-04C2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-04C2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-04C2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-04C2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-04C2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-04C2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-04C2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-04C2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-04C2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-04C2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-04C2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-04C2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-04C2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-04C2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-04C2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-04C2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-04C2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-04C2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-04C2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-04C2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-04C2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-04C2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-04C2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-04C2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-04C2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-04C2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-04C2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-04C2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-04C2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-04C2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-04C2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-04C2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-04C2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-04C2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-04C2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-04C3:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-04C3:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-04C3:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-04C3:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-04C3:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-04C3:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-04C3:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-04C3:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-04C3:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-04C3:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-04C3:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-04C3:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-04C3:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-04C3:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-04C3:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-04C3:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-04C3:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-04C3:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-04C3:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-04C3:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-04C3:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-04C3:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-04C3:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-04C3:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-04C3:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-04C3:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-04C3:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-04C3:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-04C3:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-04C3:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-04C3:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-04C3:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-04C3:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-04C3:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-04C3:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-04C3:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-04C3:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-04C3:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-04C3:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-04C3:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-04C3:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-04C3:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-04C3:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-04C3:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-04C3:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-04C3:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-04C3:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-04C3:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-04C3:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-04C3:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-04C3:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-04C3:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-04C3:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-04C3:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-04C3:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-04C3:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-04C3:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-04C3:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-04C3:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-04C3:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-04C3:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-04C3:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-04C3:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-04C3:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-04C3:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-04C3:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-04C3:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-04C3:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-04C3:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-04C3:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-04C4:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-04C4:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-04C4:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-04C4:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-04C4:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-04C4:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-04C4:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-04C4:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-04C4:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-04C4:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-04C4:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-04C4:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-04C4:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-04C4:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-04C4:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-04C4:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-04C4:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-04C4:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-04C4:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-04C4:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-04C4:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-04C4:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-04C4:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-04C4:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-04C4:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-04C4:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-04C4:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-04C4:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-04C4:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-04C4:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-04C4:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-04C4:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-04C4:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-04C4:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-04C4:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-04C4:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-04C4:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-04C4:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-04C4:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-04C4:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-05M1:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-05M1:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-05M1:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-05M1:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-05M1:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-05M1:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-05M1:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-05M1:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-05M1:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-05M1:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-05M1:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-05M1:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-05M1:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-05M1:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-05M1:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-05M1:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-05M1:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-05M1:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-05M1:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-05M1:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-05M1:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-05M1:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-05M1:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-05M1:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-05M1:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-05M1:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-05M1:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-05M1:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-05M1:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-05M1:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-05M1:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-05M1:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-05M1:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-05M1:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-05M1:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-05M1:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-05M1:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-05M1:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-05M1:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-05M1:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-05M2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-05M2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-05M2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-05M2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-05M2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-05M2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-05M2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-05M2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-05M2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-05M2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-05M2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-05M2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-05M2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-05M2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-05M2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-05M2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-05M2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-05M2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-05M2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-05M2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-05M2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-05M2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-05M2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-05M2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-05M2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-05M2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-05M2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-05M2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-05M2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-05M2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-05M2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-05M2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-05M2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-05M2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-05M2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-05M2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-05M2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-05M2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-05M2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-05M2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-05C1:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-05C1:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-05C1:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-05C1:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-05C1:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-05C1:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-05C1:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-05C1:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-05C1:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-05C1:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-05C1:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-05C1:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-05C1:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-05C1:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-05C1:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-05C1:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-05C1:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-05C1:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-05C1:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-05C1:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-05C1:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-05C1:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-05C1:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-05C1:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-05C1:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-05C1:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-05C1:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-05C1:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-05C1:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-05C1:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-05C1:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-05C1:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-05C1:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-05C1:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-05C1:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-05C1:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-05C1:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-05C1:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-05C1:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-05C1:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-05C1:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-05C1:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-05C1:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-05C1:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-05C1:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-05C1:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-05C1:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-05C1:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-05C1:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-05C1:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-05C1:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-05C1:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-05C1:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-05C1:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-05C1:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-05C1:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-05C1:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-05C1:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-05C1:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-05C1:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-05C1:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-05C1:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-05C1:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-05C1:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-05C1:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-05C1:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-05C1:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-05C1:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-05C1:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-05C1:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-05C2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-05C2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-05C2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-05C2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-05C2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-05C2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-05C2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-05C2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-05C2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-05C2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-05C2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-05C2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-05C2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-05C2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-05C2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-05C2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-05C2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-05C2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-05C2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-05C2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-05C2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-05C2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-05C2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-05C2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-05C2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-05C2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-05C2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-05C2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-05C2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-05C2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-05C2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-05C2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-05C2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-05C2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-05C2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-05C2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-05C2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-05C2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-05C2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-05C2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-05C3:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-05C3:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-05C3:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-05C3:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-05C3:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-05C3:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-05C3:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-05C3:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-05C3:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-05C3:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-05C3:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-05C3:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-05C3:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-05C3:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-05C3:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-05C3:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-05C3:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-05C3:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-05C3:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-05C3:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-05C3:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-05C3:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-05C3:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-05C3:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-05C3:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-05C3:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-05C3:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-05C3:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-05C3:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-05C3:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-05C3:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-05C3:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-05C3:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-05C3:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-05C3:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-05C3:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-05C3:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-05C3:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-05C3:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-05C3:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-05C3:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-05C3:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-05C3:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-05C3:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-05C3:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-05C3:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-05C3:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-05C3:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-05C3:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-05C3:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-05C3:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-05C3:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-05C3:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-05C3:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-05C3:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-05C3:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-05C3:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-05C3:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-05C3:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-05C3:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-05C3:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-05C3:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-05C3:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-05C3:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-05C3:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-05C3:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-05C3:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-05C3:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-05C3:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-05C3:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-05C4:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-05C4:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-05C4:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-05C4:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-05C4:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-05C4:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-05C4:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-05C4:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-05C4:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-05C4:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-05C4:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-05C4:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-05C4:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-05C4:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-05C4:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-05C4:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-05C4:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-05C4:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-05C4:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-05C4:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-05C4:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-05C4:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-05C4:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-05C4:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-05C4:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-05C4:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-05C4:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-05C4:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-05C4:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-05C4:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-05C4:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-05C4:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-05C4:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-05C4:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-05C4:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-05C4:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-05C4:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-05C4:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-05C4:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-05C4:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-06M1:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-06M1:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-06M1:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-06M1:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-06M1:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-06M1:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-06M1:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-06M1:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-06M1:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-06M1:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-06M1:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-06M1:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-06M1:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-06M1:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-06M1:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-06M1:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-06M1:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-06M1:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-06M1:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-06M1:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-06M1:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-06M1:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-06M1:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-06M1:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-06M1:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-06M1:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-06M1:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-06M1:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-06M1:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-06M1:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-06M1:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-06M1:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-06M1:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-06M1:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-06M1:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-06M1:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-06M1:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-06M1:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-06M1:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-06M1:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-06M2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-06M2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-06M2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-06M2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-06M2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-06M2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-06M2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-06M2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-06M2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-06M2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-06M2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-06M2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-06M2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-06M2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-06M2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-06M2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-06M2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-06M2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-06M2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-06M2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-06M2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-06M2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-06M2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-06M2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-06M2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-06M2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-06M2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-06M2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-06M2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-06M2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-06M2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-06M2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-06M2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-06M2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-06M2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-06M2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-06M2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-06M2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-06M2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-06M2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-06C1:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-06C1:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-06C1:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-06C1:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-06C1:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-06C1:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-06C1:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-06C1:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-06C1:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-06C1:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-06C1:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-06C1:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-06C1:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-06C1:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-06C1:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-06C1:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-06C1:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-06C1:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-06C1:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-06C1:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-06C1:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-06C1:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-06C1:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-06C1:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-06C1:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-06C1:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-06C1:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-06C1:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-06C1:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-06C1:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-06C1:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-06C1:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-06C1:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-06C1:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-06C1:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-06C1:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-06C1:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-06C1:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-06C1:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-06C1:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-06C1:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-06C1:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-06C1:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-06C1:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-06C1:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-06C1:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-06C1:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-06C1:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-06C1:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-06C1:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-06C1:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-06C1:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-06C1:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-06C1:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-06C1:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-06C1:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-06C1:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-06C1:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-06C1:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-06C1:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-06C1:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-06C1:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-06C1:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-06C1:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-06C1:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-06C1:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-06C1:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-06C1:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-06C1:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-06C1:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-06C2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-06C2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-06C2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-06C2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-06C2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-06C2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-06C2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-06C2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-06C2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-06C2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-06C2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-06C2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-06C2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-06C2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-06C2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-06C2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-06C2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-06C2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-06C2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-06C2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-06C2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-06C2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-06C2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-06C2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-06C2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-06C2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-06C2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-06C2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-06C2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-06C2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-06C2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-06C2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-06C2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-06C2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-06C2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-06C2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-06C2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-06C2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-06C2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-06C2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-06C3:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-06C3:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-06C3:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-06C3:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-06C3:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-06C3:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-06C3:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-06C3:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-06C3:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-06C3:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-06C3:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-06C3:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-06C3:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-06C3:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-06C3:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-06C3:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-06C3:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-06C3:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-06C3:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-06C3:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-06C3:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-06C3:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-06C3:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-06C3:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-06C3:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-06C3:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-06C3:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-06C3:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-06C3:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-06C3:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-06C3:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-06C3:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-06C3:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-06C3:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-06C3:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-06C3:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-06C3:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-06C3:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-06C3:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-06C3:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-06C3:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-06C3:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-06C3:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-06C3:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-06C3:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-06C3:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-06C3:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-06C3:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-06C3:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-06C3:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-06C3:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-06C3:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-06C3:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-06C3:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-06C3:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-06C3:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-06C3:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-06C3:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-06C3:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-06C3:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-06C3:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-06C3:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-06C3:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-06C3:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-06C3:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-06C3:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-06C3:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-06C3:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-06C3:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-06C3:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-06C4:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-06C4:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-06C4:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-06C4:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-06C4:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-06C4:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-06C4:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-06C4:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-06C4:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-06C4:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-06C4:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-06C4:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-06C4:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-06C4:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-06C4:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-06C4:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-06C4:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-06C4:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-06C4:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-06C4:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-06C4:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-06C4:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-06C4:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-06C4:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-06C4:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-06C4:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-06C4:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-06C4:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-06C4:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-06C4:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-06C4:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-06C4:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-06C4:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-06C4:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-06C4:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-06C4:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-06C4:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-06C4:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-06C4:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-06C4:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-07M1:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-07M1:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-07M1:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-07M1:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-07M1:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-07M1:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-07M1:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-07M1:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-07M1:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-07M1:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-07M1:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-07M1:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-07M1:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-07M1:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-07M1:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-07M1:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-07M1:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-07M1:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-07M1:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-07M1:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-07M1:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-07M1:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-07M1:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-07M1:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-07M1:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-07M1:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-07M1:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-07M1:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-07M1:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-07M1:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-07M1:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-07M1:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-07M1:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-07M1:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-07M1:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-07M1:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-07M1:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-07M1:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-07M1:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-07M1:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-07M2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-07M2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-07M2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-07M2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-07M2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-07M2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-07M2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-07M2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-07M2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-07M2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-07M2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-07M2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-07M2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-07M2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-07M2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-07M2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-07M2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-07M2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-07M2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-07M2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-07M2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-07M2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-07M2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-07M2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-07M2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-07M2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-07M2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-07M2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-07M2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-07M2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-07M2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-07M2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-07M2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-07M2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-07M2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-07M2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-07M2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-07M2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-07M2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-07M2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-07C1:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-07C1:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-07C1:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-07C1:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-07C1:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-07C1:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-07C1:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-07C1:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-07C1:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-07C1:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-07C1:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-07C1:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-07C1:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-07C1:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-07C1:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-07C1:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-07C1:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-07C1:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-07C1:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-07C1:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-07C1:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-07C1:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-07C1:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-07C1:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-07C1:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-07C1:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-07C1:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-07C1:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-07C1:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-07C1:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-07C1:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-07C1:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-07C1:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-07C1:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-07C1:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-07C1:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-07C1:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-07C1:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-07C1:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-07C1:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-07C1:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-07C1:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-07C1:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-07C1:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-07C1:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-07C1:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-07C1:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-07C1:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-07C1:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-07C1:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-07C1:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-07C1:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-07C1:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-07C1:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-07C1:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-07C1:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-07C1:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-07C1:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-07C1:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-07C1:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-07C1:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-07C1:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-07C1:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-07C1:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-07C1:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-07C1:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-07C1:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-07C1:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-07C1:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-07C1:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-07C2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-07C2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-07C2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-07C2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-07C2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-07C2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-07C2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-07C2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-07C2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-07C2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-07C2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-07C2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-07C2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-07C2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-07C2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-07C2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-07C2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-07C2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-07C2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-07C2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-07C2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-07C2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-07C2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-07C2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-07C2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-07C2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-07C2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-07C2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-07C2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-07C2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-07C2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-07C2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-07C2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-07C2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-07C2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-07C2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-07C2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-07C2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-07C2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-07C2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-07C3:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-07C3:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-07C3:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-07C3:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-07C3:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-07C3:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-07C3:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-07C3:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-07C3:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-07C3:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-07C3:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-07C3:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-07C3:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-07C3:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-07C3:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-07C3:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-07C3:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-07C3:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-07C3:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-07C3:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-07C3:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-07C3:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-07C3:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-07C3:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-07C3:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-07C3:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-07C3:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-07C3:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-07C3:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-07C3:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-07C3:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-07C3:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-07C3:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-07C3:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-07C3:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-07C3:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-07C3:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-07C3:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-07C3:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-07C3:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-07C3:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-07C3:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-07C3:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-07C3:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-07C3:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-07C3:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-07C3:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-07C3:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-07C3:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-07C3:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-07C3:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-07C3:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-07C3:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-07C3:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-07C3:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-07C3:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-07C3:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-07C3:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-07C3:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-07C3:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-07C3:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-07C3:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-07C3:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-07C3:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-07C3:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-07C3:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-07C3:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-07C3:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-07C3:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-07C3:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-07C4:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-07C4:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-07C4:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-07C4:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-07C4:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-07C4:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-07C4:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-07C4:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-07C4:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-07C4:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-07C4:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-07C4:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-07C4:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-07C4:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-07C4:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-07C4:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-07C4:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-07C4:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-07C4:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-07C4:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-07C4:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-07C4:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-07C4:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-07C4:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-07C4:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-07C4:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-07C4:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-07C4:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-07C4:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-07C4:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-07C4:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-07C4:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-07C4:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-07C4:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-07C4:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-07C4:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-07C4:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-07C4:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-07C4:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-07C4:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-08M1:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-08M1:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-08M1:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-08M1:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-08M1:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-08M1:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-08M1:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-08M1:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-08M1:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-08M1:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-08M1:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-08M1:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-08M1:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-08M1:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-08M1:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-08M1:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-08M1:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-08M1:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-08M1:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-08M1:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-08M1:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-08M1:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-08M1:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-08M1:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-08M1:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-08M1:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-08M1:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-08M1:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-08M1:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-08M1:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-08M1:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-08M1:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-08M1:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-08M1:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-08M1:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-08M1:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-08M1:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-08M1:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-08M1:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-08M1:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-08M2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-08M2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-08M2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-08M2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-08M2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-08M2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-08M2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-08M2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-08M2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-08M2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-08M2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-08M2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-08M2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-08M2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-08M2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-08M2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-08M2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-08M2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-08M2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-08M2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-08M2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-08M2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-08M2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-08M2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-08M2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-08M2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-08M2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-08M2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-08M2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-08M2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-08M2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-08M2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-08M2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-08M2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-08M2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-08M2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-08M2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-08M2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-08M2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-08M2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-08C1:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-08C1:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-08C1:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-08C1:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-08C1:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-08C1:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-08C1:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-08C1:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-08C1:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-08C1:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-08C1:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-08C1:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-08C1:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-08C1:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-08C1:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-08C1:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-08C1:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-08C1:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-08C1:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-08C1:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-08C1:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-08C1:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-08C1:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-08C1:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-08C1:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-08C1:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-08C1:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-08C1:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-08C1:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-08C1:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-08C1:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-08C1:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-08C1:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-08C1:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-08C1:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-08C1:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-08C1:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-08C1:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-08C1:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-08C1:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-08C1:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-08C1:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-08C1:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-08C1:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-08C1:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-08C1:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-08C1:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-08C1:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-08C1:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-08C1:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-08C1:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-08C1:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-08C1:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-08C1:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-08C1:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-08C1:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-08C1:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-08C1:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-08C1:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-08C1:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-08C1:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-08C1:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-08C1:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-08C1:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-08C1:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-08C1:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-08C1:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-08C1:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-08C1:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-08C1:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-08C2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-08C2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-08C2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-08C2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-08C2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-08C2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-08C2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-08C2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-08C2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-08C2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-08C2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-08C2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-08C2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-08C2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-08C2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-08C2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-08C2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-08C2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-08C2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-08C2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-08C2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-08C2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-08C2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-08C2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-08C2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-08C2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-08C2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-08C2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-08C2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-08C2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-08C2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-08C2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-08C2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-08C2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-08C2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-08C2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-08C2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-08C2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-08C2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-08C2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-08C3:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-08C3:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-08C3:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-08C3:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-08C3:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-08C3:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-08C3:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-08C3:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-08C3:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-08C3:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-08C3:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-08C3:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-08C3:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-08C3:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-08C3:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-08C3:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-08C3:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-08C3:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-08C3:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-08C3:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-08C3:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-08C3:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-08C3:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-08C3:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-08C3:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-08C3:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-08C3:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-08C3:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-08C3:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-08C3:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-08C3:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-08C3:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-08C3:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-08C3:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-08C3:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-08C3:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-08C3:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-08C3:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-08C3:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-08C3:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-08C3:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-08C3:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-08C3:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-08C3:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-08C3:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-08C3:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-08C3:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-08C3:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-08C3:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-08C3:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-08C3:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-08C3:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-08C3:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-08C3:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-08C3:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-08C3:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-08C3:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-08C3:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-08C3:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-08C3:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-08C3:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-08C3:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-08C3:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-08C3:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-08C3:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-08C3:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-08C3:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-08C3:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-08C3:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-08C3:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-08C4:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-08C4:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-08C4:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-08C4:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-08C4:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-08C4:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-08C4:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-08C4:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-08C4:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-08C4:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-08C4:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-08C4:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-08C4:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-08C4:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-08C4:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-08C4:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-08C4:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-08C4:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-08C4:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-08C4:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-08C4:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-08C4:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-08C4:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-08C4:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-08C4:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-08C4:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-08C4:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-08C4:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-08C4:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-08C4:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-08C4:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-08C4:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-08C4:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-08C4:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-08C4:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-08C4:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-08C4:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-08C4:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-08C4:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-08C4:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-09M1:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-09M1:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-09M1:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-09M1:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-09M1:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-09M1:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-09M1:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-09M1:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-09M1:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-09M1:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-09M1:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-09M1:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-09M1:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-09M1:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-09M1:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-09M1:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-09M1:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-09M1:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-09M1:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-09M1:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-09M1:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-09M1:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-09M1:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-09M1:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-09M1:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-09M1:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-09M1:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-09M1:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-09M1:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-09M1:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-09M1:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-09M1:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-09M1:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-09M1:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-09M1:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-09M1:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-09M1:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-09M1:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-09M1:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-09M1:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-09M2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-09M2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-09M2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-09M2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-09M2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-09M2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-09M2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-09M2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-09M2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-09M2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-09M2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-09M2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-09M2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-09M2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-09M2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-09M2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-09M2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-09M2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-09M2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-09M2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-09M2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-09M2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-09M2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-09M2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-09M2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-09M2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-09M2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-09M2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-09M2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-09M2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-09M2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-09M2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-09M2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-09M2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-09M2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-09M2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-09M2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-09M2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-09M2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-09M2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-09C1:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-09C1:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-09C1:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-09C1:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-09C1:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-09C1:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-09C1:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-09C1:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-09C1:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-09C1:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-09C1:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-09C1:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-09C1:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-09C1:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-09C1:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-09C1:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-09C1:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-09C1:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-09C1:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-09C1:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-09C1:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-09C1:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-09C1:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-09C1:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-09C1:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-09C1:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-09C1:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-09C1:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-09C1:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-09C1:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-09C1:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-09C1:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-09C1:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-09C1:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-09C1:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-09C1:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-09C1:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-09C1:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-09C1:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-09C1:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-09C1:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-09C1:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-09C1:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-09C1:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-09C1:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-09C1:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-09C1:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-09C1:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-09C1:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-09C1:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-09C1:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-09C1:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-09C1:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-09C1:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-09C1:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-09C1:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-09C1:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-09C1:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-09C1:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-09C1:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-09C1:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-09C1:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-09C1:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-09C1:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-09C1:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-09C1:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-09C1:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-09C1:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-09C1:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-09C1:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-09C2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-09C2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-09C2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-09C2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-09C2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-09C2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-09C2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-09C2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-09C2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-09C2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-09C2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-09C2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-09C2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-09C2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-09C2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-09C2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-09C2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-09C2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-09C2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-09C2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-09C2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-09C2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-09C2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-09C2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-09C2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-09C2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-09C2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-09C2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-09C2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-09C2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-09C2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-09C2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-09C2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-09C2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-09C2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-09C2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-09C2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-09C2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-09C2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-09C2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-09C3:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-09C3:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-09C3:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-09C3:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-09C3:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-09C3:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-09C3:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-09C3:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-09C3:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-09C3:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-09C3:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-09C3:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-09C3:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-09C3:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-09C3:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-09C3:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-09C3:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-09C3:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-09C3:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-09C3:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-09C3:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-09C3:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-09C3:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-09C3:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-09C3:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-09C3:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-09C3:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-09C3:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-09C3:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-09C3:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-09C3:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-09C3:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-09C3:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-09C3:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-09C3:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-09C3:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-09C3:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-09C3:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-09C3:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-09C3:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-09C3:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-09C3:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-09C3:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-09C3:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-09C3:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-09C3:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-09C3:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-09C3:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-09C3:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-09C3:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-09C3:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-09C3:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-09C3:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-09C3:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-09C3:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-09C3:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-09C3:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-09C3:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-09C3:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-09C3:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-09C3:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-09C3:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-09C3:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-09C3:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-09C3:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-09C3:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-09C3:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-09C3:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-09C3:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-09C3:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-09C4:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-09C4:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-09C4:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-09C4:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-09C4:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-09C4:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-09C4:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-09C4:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-09C4:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-09C4:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-09C4:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-09C4:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-09C4:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-09C4:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-09C4:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-09C4:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-09C4:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-09C4:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-09C4:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-09C4:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-09C4:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-09C4:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-09C4:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-09C4:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-09C4:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-09C4:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-09C4:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-09C4:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-09C4:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-09C4:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-09C4:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-09C4:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-09C4:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-09C4:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-09C4:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-09C4:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-09C4:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-09C4:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-09C4:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-09C4:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-10M1:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-10M1:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-10M1:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-10M1:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-10M1:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-10M1:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-10M1:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-10M1:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-10M1:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-10M1:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-10M1:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-10M1:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-10M1:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-10M1:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-10M1:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-10M1:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-10M1:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-10M1:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-10M1:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-10M1:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-10M1:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-10M1:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-10M1:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-10M1:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-10M1:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-10M1:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-10M1:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-10M1:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-10M1:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-10M1:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-10M1:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-10M1:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-10M1:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-10M1:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-10M1:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-10M1:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-10M1:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-10M1:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-10M1:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-10M1:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-10M2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-10M2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-10M2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-10M2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-10M2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-10M2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-10M2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-10M2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-10M2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-10M2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-10M2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-10M2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-10M2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-10M2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-10M2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-10M2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-10M2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-10M2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-10M2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-10M2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-10M2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-10M2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-10M2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-10M2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-10M2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-10M2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-10M2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-10M2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-10M2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-10M2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-10M2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-10M2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-10M2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-10M2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-10M2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-10M2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-10M2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-10M2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-10M2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-10M2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-10C1:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-10C1:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-10C1:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-10C1:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-10C1:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-10C1:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-10C1:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-10C1:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-10C1:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-10C1:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-10C1:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-10C1:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-10C1:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-10C1:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-10C1:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-10C1:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-10C1:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-10C1:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-10C1:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-10C1:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-10C1:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-10C1:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-10C1:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-10C1:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-10C1:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-10C1:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-10C1:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-10C1:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-10C1:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-10C1:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-10C1:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-10C1:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-10C1:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-10C1:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-10C1:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-10C1:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-10C1:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-10C1:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-10C1:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-10C1:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-10C1:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-10C1:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-10C1:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-10C1:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-10C1:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-10C1:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-10C1:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-10C1:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-10C1:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-10C1:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-10C1:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-10C1:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-10C1:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-10C1:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-10C1:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-10C1:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-10C1:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-10C1:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-10C1:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-10C1:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-10C1:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-10C1:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-10C1:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-10C1:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-10C1:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-10C1:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-10C1:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-10C1:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-10C1:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-10C1:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-10C2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-10C2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-10C2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-10C2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-10C2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-10C2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-10C2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-10C2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-10C2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-10C2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-10C2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-10C2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-10C2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-10C2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-10C2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-10C2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-10C2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-10C2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-10C2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-10C2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-10C2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-10C2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-10C2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-10C2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-10C2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-10C2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-10C2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-10C2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-10C2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-10C2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-10C2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-10C2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-10C2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-10C2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-10C2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-10C2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-10C2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-10C2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-10C2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-10C2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-10C3:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-10C3:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-10C3:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-10C3:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-10C3:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-10C3:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-10C3:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-10C3:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-10C3:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-10C3:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-10C3:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-10C3:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-10C3:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-10C3:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-10C3:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-10C3:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-10C3:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-10C3:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-10C3:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-10C3:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-10C3:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-10C3:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-10C3:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-10C3:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-10C3:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-10C3:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-10C3:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-10C3:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-10C3:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-10C3:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-10C3:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-10C3:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-10C3:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-10C3:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-10C3:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-10C3:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-10C3:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-10C3:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-10C3:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-10C3:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-10C3:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-10C3:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-10C3:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-10C3:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-10C3:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-10C3:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-10C3:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-10C3:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-10C3:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-10C3:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-10C3:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-10C3:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-10C3:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-10C3:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-10C3:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-10C3:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-10C3:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-10C3:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-10C3:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-10C3:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-10C3:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-10C3:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-10C3:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-10C3:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-10C3:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-10C3:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-10C3:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-10C3:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-10C3:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-10C3:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-10C4:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-10C4:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-10C4:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-10C4:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-10C4:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-10C4:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-10C4:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-10C4:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-10C4:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-10C4:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-10C4:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-10C4:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-10C4:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-10C4:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-10C4:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-10C4:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-10C4:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-10C4:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-10C4:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-10C4:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-10C4:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-10C4:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-10C4:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-10C4:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-10C4:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-10C4:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-10C4:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-10C4:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-10C4:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-10C4:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-10C4:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-10C4:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-10C4:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-10C4:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-10C4:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-10C4:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-10C4:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-10C4:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-10C4:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-10C4:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-11M1:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-11M1:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-11M1:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-11M1:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-11M1:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-11M1:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-11M1:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-11M1:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-11M1:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-11M1:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-11M1:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-11M1:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-11M1:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-11M1:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-11M1:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-11M1:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-11M1:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-11M1:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-11M1:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-11M1:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-11M1:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-11M1:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-11M1:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-11M1:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-11M1:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-11M1:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-11M1:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-11M1:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-11M1:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-11M1:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-11M1:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-11M1:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-11M1:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-11M1:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-11M1:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-11M1:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-11M1:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-11M1:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-11M1:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-11M1:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-11M2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-11M2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-11M2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-11M2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-11M2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-11M2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-11M2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-11M2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-11M2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-11M2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-11M2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-11M2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-11M2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-11M2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-11M2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-11M2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-11M2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-11M2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-11M2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-11M2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-11M2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-11M2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-11M2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-11M2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-11M2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-11M2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-11M2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-11M2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-11M2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-11M2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-11M2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-11M2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-11M2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-11M2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-11M2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-11M2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-11M2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-11M2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-11M2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-11M2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-11C1:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-11C1:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-11C1:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-11C1:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-11C1:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-11C1:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-11C1:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-11C1:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-11C1:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-11C1:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-11C1:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-11C1:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-11C1:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-11C1:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-11C1:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-11C1:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-11C1:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-11C1:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-11C1:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-11C1:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-11C1:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-11C1:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-11C1:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-11C1:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-11C1:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-11C1:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-11C1:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-11C1:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-11C1:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-11C1:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-11C1:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-11C1:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-11C1:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-11C1:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-11C1:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-11C1:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-11C1:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-11C1:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-11C1:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-11C1:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-11C1:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-11C1:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-11C1:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-11C1:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-11C1:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-11C1:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-11C1:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-11C1:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-11C1:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-11C1:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-11C1:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-11C1:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-11C1:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-11C1:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-11C1:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-11C1:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-11C1:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-11C1:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-11C1:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-11C1:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-11C1:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-11C1:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-11C1:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-11C1:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-11C1:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-11C1:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-11C1:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-11C1:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-11C1:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-11C1:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-11C2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-11C2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-11C2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-11C2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-11C2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-11C2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-11C2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-11C2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-11C2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-11C2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-11C2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-11C2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-11C2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-11C2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-11C2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-11C2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-11C2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-11C2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-11C2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-11C2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-11C2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-11C2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-11C2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-11C2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-11C2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-11C2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-11C2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-11C2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-11C2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-11C2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-11C2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-11C2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-11C2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-11C2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-11C2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-11C2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-11C2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-11C2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-11C2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-11C2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-11C3:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-11C3:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-11C3:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-11C3:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-11C3:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-11C3:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-11C3:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-11C3:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-11C3:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-11C3:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-11C3:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-11C3:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-11C3:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-11C3:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-11C3:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-11C3:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-11C3:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-11C3:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-11C3:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-11C3:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-11C3:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-11C3:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-11C3:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-11C3:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-11C3:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-11C3:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-11C3:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-11C3:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-11C3:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-11C3:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-11C3:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-11C3:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-11C3:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-11C3:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-11C3:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-11C3:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-11C3:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-11C3:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-11C3:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-11C3:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-11C3:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-11C3:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-11C3:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-11C3:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-11C3:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-11C3:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-11C3:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-11C3:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-11C3:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-11C3:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-11C3:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-11C3:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-11C3:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-11C3:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-11C3:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-11C3:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-11C3:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-11C3:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-11C3:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-11C3:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-11C3:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-11C3:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-11C3:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-11C3:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-11C3:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-11C3:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-11C3:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-11C3:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-11C3:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-11C3:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-11C4:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-11C4:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-11C4:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-11C4:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-11C4:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-11C4:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-11C4:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-11C4:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-11C4:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-11C4:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-11C4:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-11C4:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-11C4:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-11C4:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-11C4:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-11C4:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-11C4:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-11C4:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-11C4:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-11C4:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-11C4:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-11C4:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-11C4:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-11C4:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-11C4:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-11C4:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-11C4:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-11C4:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-11C4:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-11C4:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-11C4:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-11C4:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-11C4:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-11C4:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-11C4:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-11C4:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-11C4:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-11C4:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-11C4:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-11C4:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-12M1:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-12M1:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-12M1:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-12M1:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-12M1:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-12M1:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-12M1:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-12M1:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-12M1:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-12M1:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-12M1:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-12M1:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-12M1:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-12M1:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-12M1:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-12M1:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-12M1:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-12M1:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-12M1:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-12M1:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-12M1:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-12M1:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-12M1:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-12M1:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-12M1:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-12M1:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-12M1:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-12M1:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-12M1:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-12M1:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-12M1:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-12M1:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-12M1:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-12M1:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-12M1:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-12M1:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-12M1:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-12M1:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-12M1:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-12M1:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-12M2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-12M2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-12M2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-12M2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-12M2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-12M2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-12M2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-12M2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-12M2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-12M2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-12M2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-12M2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-12M2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-12M2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-12M2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-12M2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-12M2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-12M2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-12M2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-12M2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-12M2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-12M2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-12M2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-12M2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-12M2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-12M2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-12M2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-12M2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-12M2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-12M2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-12M2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-12M2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-12M2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-12M2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-12M2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-12M2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-12M2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-12M2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-12M2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-12M2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-12C1:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-12C1:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-12C1:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-12C1:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-12C1:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-12C1:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-12C1:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-12C1:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-12C1:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-12C1:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-12C1:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-12C1:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-12C1:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-12C1:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-12C1:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-12C1:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-12C1:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-12C1:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-12C1:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-12C1:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-12C1:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-12C1:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-12C1:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-12C1:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-12C1:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-12C1:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-12C1:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-12C1:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-12C1:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-12C1:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-12C1:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-12C1:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-12C1:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-12C1:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-12C1:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-12C1:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-12C1:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-12C1:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-12C1:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-12C1:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-12C1:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-12C1:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-12C1:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-12C1:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-12C1:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-12C1:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-12C1:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-12C1:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-12C1:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-12C1:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-12C1:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-12C1:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-12C1:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-12C1:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-12C1:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-12C1:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-12C1:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-12C1:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-12C1:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-12C1:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-12C1:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-12C1:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-12C1:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-12C1:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-12C1:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-12C1:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-12C1:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-12C1:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-12C1:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-12C1:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-12C2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-12C2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-12C2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-12C2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-12C2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-12C2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-12C2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-12C2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-12C2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-12C2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-12C2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-12C2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-12C2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-12C2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-12C2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-12C2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-12C2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-12C2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-12C2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-12C2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-12C2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-12C2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-12C2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-12C2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-12C2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-12C2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-12C2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-12C2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-12C2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-12C2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-12C2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-12C2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-12C2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-12C2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-12C2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-12C2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-12C2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-12C2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-12C2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-12C2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-12C3:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-12C3:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-12C3:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-12C3:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-12C3:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-12C3:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-12C3:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-12C3:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-12C3:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-12C3:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-12C3:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-12C3:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-12C3:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-12C3:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-12C3:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-12C3:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-12C3:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-12C3:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-12C3:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-12C3:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-12C3:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-12C3:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-12C3:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-12C3:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-12C3:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-12C3:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-12C3:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-12C3:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-12C3:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-12C3:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-12C3:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-12C3:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-12C3:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-12C3:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-12C3:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-12C3:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-12C3:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-12C3:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-12C3:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-12C3:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-12C3:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-12C3:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-12C3:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-12C3:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-12C3:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-12C3:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-12C3:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-12C3:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-12C3:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-12C3:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-12C3:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-12C3:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-12C3:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-12C3:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-12C3:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-12C3:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-12C3:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-12C3:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-12C3:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-12C3:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-12C3:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-12C3:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-12C3:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-12C3:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-12C3:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-12C3:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-12C3:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-12C3:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-12C3:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-12C3:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-12C4:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-12C4:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-12C4:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-12C4:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-12C4:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-12C4:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-12C4:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-12C4:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-12C4:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-12C4:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-12C4:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-12C4:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-12C4:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-12C4:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-12C4:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-12C4:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-12C4:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-12C4:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-12C4:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-12C4:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-12C4:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-12C4:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-12C4:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-12C4:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-12C4:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-12C4:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-12C4:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-12C4:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-12C4:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-12C4:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-12C4:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-12C4:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-12C4:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-12C4:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-12C4:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-12C4:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-12C4:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-12C4:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-12C4:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-12C4:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-13M1:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-13M1:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-13M1:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-13M1:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-13M1:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-13M1:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-13M1:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-13M1:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-13M1:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-13M1:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-13M1:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-13M1:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-13M1:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-13M1:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-13M1:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-13M1:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-13M1:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-13M1:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-13M1:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-13M1:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-13M1:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-13M1:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-13M1:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-13M1:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-13M1:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-13M1:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-13M1:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-13M1:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-13M1:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-13M1:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-13M1:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-13M1:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-13M1:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-13M1:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-13M1:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-13M1:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-13M1:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-13M1:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-13M1:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-13M1:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-13M2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-13M2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-13M2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-13M2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-13M2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-13M2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-13M2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-13M2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-13M2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-13M2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-13M2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-13M2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-13M2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-13M2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-13M2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-13M2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-13M2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-13M2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-13M2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-13M2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-13M2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-13M2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-13M2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-13M2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-13M2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-13M2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-13M2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-13M2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-13M2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-13M2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-13M2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-13M2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-13M2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-13M2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-13M2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-13M2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-13M2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-13M2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-13M2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-13M2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-13C1:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-13C1:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-13C1:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-13C1:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-13C1:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-13C1:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-13C1:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-13C1:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-13C1:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-13C1:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-13C1:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-13C1:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-13C1:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-13C1:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-13C1:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-13C1:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-13C1:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-13C1:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-13C1:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-13C1:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-13C1:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-13C1:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-13C1:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-13C1:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-13C1:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-13C1:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-13C1:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-13C1:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-13C1:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-13C1:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-13C1:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-13C1:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-13C1:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-13C1:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-13C1:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-13C1:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-13C1:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-13C1:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-13C1:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-13C1:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-13C1:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-13C1:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-13C1:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-13C1:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-13C1:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-13C1:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-13C1:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-13C1:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-13C1:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-13C1:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-13C1:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-13C1:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-13C1:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-13C1:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-13C1:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-13C1:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-13C1:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-13C1:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-13C1:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-13C1:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-13C1:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-13C1:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-13C1:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-13C1:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-13C1:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-13C1:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-13C1:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-13C1:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-13C1:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-13C1:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-13C2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-13C2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-13C2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-13C2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-13C2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-13C2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-13C2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-13C2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-13C2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-13C2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-13C2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-13C2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-13C2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-13C2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-13C2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-13C2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-13C2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-13C2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-13C2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-13C2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-13C2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-13C2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-13C2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-13C2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-13C2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-13C2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-13C2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-13C2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-13C2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-13C2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-13C2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-13C2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-13C2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-13C2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-13C2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-13C2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-13C2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-13C2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-13C2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-13C2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-13C3:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-13C3:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-13C3:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-13C3:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-13C3:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-13C3:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-13C3:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-13C3:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-13C3:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-13C3:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-13C3:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-13C3:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-13C3:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-13C3:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-13C3:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-13C3:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-13C3:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-13C3:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-13C3:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-13C3:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-13C3:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-13C3:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-13C3:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-13C3:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-13C3:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-13C3:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-13C3:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-13C3:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-13C3:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-13C3:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-13C3:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-13C3:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-13C3:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-13C3:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-13C3:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-13C3:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-13C3:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-13C3:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-13C3:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-13C3:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-13C3:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-13C3:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-13C3:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-13C3:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-13C3:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-13C3:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-13C3:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-13C3:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-13C3:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-13C3:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-13C3:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-13C3:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-13C3:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-13C3:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-13C3:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-13C3:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-13C3:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-13C3:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-13C3:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-13C3:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-13C3:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-13C3:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-13C3:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-13C3:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-13C3:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-13C3:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-13C3:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-13C3:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-13C3:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-13C3:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-13C4:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-13C4:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-13C4:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-13C4:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-13C4:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-13C4:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-13C4:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-13C4:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-13C4:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-13C4:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-13C4:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-13C4:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-13C4:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-13C4:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-13C4:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-13C4:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-13C4:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-13C4:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-13C4:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-13C4:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-13C4:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-13C4:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-13C4:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-13C4:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-13C4:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-13C4:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-13C4:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-13C4:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-13C4:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-13C4:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-13C4:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-13C4:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-13C4:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-13C4:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-13C4:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-13C4:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-13C4:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-13C4:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-13C4:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-13C4:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-14M1:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-14M1:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-14M1:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-14M1:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-14M1:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-14M1:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-14M1:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-14M1:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-14M1:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-14M1:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-14M1:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-14M1:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-14M1:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-14M1:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-14M1:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-14M1:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-14M1:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-14M1:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-14M1:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-14M1:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-14M1:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-14M1:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-14M1:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-14M1:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-14M1:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-14M1:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-14M1:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-14M1:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-14M1:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-14M1:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-14M1:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-14M1:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-14M1:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-14M1:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-14M1:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-14M1:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-14M1:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-14M1:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-14M1:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-14M1:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-14M2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-14M2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-14M2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-14M2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-14M2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-14M2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-14M2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-14M2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-14M2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-14M2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-14M2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-14M2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-14M2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-14M2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-14M2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-14M2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-14M2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-14M2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-14M2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-14M2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-14M2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-14M2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-14M2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-14M2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-14M2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-14M2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-14M2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-14M2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-14M2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-14M2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-14M2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-14M2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-14M2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-14M2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-14M2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-14M2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-14M2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-14M2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-14M2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-14M2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-14C1:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-14C1:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-14C1:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-14C1:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-14C1:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-14C1:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-14C1:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-14C1:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-14C1:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-14C1:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-14C1:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-14C1:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-14C1:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-14C1:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-14C1:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-14C1:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-14C1:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-14C1:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-14C1:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-14C1:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-14C1:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-14C1:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-14C1:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-14C1:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-14C1:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-14C1:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-14C1:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-14C1:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-14C1:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-14C1:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-14C1:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-14C1:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-14C1:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-14C1:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-14C1:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-14C1:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-14C1:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-14C1:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-14C1:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-14C1:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-14C1:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-14C1:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-14C1:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-14C1:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-14C1:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-14C1:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-14C1:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-14C1:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-14C1:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-14C1:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-14C1:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-14C1:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-14C1:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-14C1:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-14C1:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-14C1:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-14C1:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-14C1:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-14C1:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-14C1:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-14C1:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-14C1:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-14C1:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-14C1:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-14C1:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-14C1:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-14C1:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-14C1:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-14C1:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-14C1:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-14C2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-14C2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-14C2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-14C2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-14C2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-14C2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-14C2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-14C2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-14C2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-14C2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-14C2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-14C2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-14C2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-14C2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-14C2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-14C2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-14C2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-14C2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-14C2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-14C2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-14C2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-14C2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-14C2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-14C2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-14C2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-14C2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-14C2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-14C2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-14C2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-14C2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-14C2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-14C2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-14C2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-14C2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-14C2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-14C2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-14C2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-14C2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-14C2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-14C2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-14C3:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-14C3:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-14C3:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-14C3:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-14C3:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-14C3:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-14C3:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-14C3:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-14C3:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-14C3:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-14C3:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-14C3:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-14C3:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-14C3:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-14C3:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-14C3:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-14C3:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-14C3:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-14C3:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-14C3:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-14C3:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-14C3:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-14C3:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-14C3:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-14C3:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-14C3:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-14C3:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-14C3:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-14C3:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-14C3:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-14C3:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-14C3:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-14C3:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-14C3:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-14C3:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-14C3:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-14C3:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-14C3:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-14C3:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-14C3:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-14C3:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-14C3:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-14C3:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-14C3:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-14C3:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-14C3:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-14C3:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-14C3:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-14C3:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-14C3:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-14C3:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-14C3:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-14C3:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-14C3:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-14C3:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-14C3:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-14C3:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-14C3:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-14C3:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-14C3:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-14C3:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-14C3:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-14C3:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-14C3:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-14C3:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-14C3:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-14C3:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-14C3:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-14C3:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-14C3:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-14C4:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-14C4:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-14C4:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-14C4:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-14C4:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-14C4:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-14C4:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-14C4:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-14C4:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-14C4:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-14C4:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-14C4:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-14C4:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-14C4:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-14C4:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-14C4:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-14C4:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-14C4:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-14C4:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-14C4:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-14C4:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-14C4:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-14C4:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-14C4:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-14C4:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-14C4:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-14C4:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-14C4:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-14C4:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-14C4:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-14C4:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-14C4:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-14C4:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-14C4:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-14C4:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-14C4:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-14C4:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-14C4:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-14C4:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-14C4:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-15M1:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-15M1:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-15M1:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-15M1:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-15M1:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-15M1:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-15M1:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-15M1:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-15M1:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-15M1:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-15M1:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-15M1:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-15M1:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-15M1:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-15M1:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-15M1:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-15M1:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-15M1:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-15M1:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-15M1:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-15M1:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-15M1:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-15M1:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-15M1:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-15M1:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-15M1:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-15M1:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-15M1:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-15M1:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-15M1:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-15M1:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-15M1:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-15M1:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-15M1:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-15M1:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-15M1:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-15M1:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-15M1:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-15M1:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-15M1:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-15M2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-15M2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-15M2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-15M2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-15M2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-15M2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-15M2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-15M2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-15M2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-15M2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-15M2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-15M2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-15M2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-15M2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-15M2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-15M2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-15M2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-15M2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-15M2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-15M2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-15M2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-15M2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-15M2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-15M2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-15M2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-15M2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-15M2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-15M2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-15M2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-15M2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-15M2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-15M2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-15M2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-15M2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-15M2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-15M2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-15M2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-15M2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-15M2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-15M2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-15C1:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-15C1:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-15C1:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-15C1:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-15C1:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-15C1:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-15C1:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-15C1:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-15C1:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-15C1:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-15C1:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-15C1:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-15C1:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-15C1:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-15C1:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-15C1:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-15C1:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-15C1:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-15C1:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-15C1:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-15C1:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-15C1:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-15C1:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-15C1:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-15C1:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-15C1:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-15C1:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-15C1:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-15C1:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-15C1:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-15C1:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-15C1:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-15C1:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-15C1:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-15C1:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-15C1:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-15C1:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-15C1:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-15C1:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-15C1:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-15C1:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-15C1:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-15C1:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-15C1:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-15C1:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-15C1:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-15C1:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-15C1:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-15C1:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-15C1:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-15C1:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-15C1:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-15C1:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-15C1:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-15C1:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-15C1:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-15C1:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-15C1:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-15C1:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-15C1:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-15C1:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-15C1:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-15C1:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-15C1:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-15C1:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-15C1:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-15C1:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-15C1:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-15C1:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-15C1:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-15C2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-15C2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-15C2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-15C2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-15C2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-15C2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-15C2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-15C2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-15C2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-15C2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-15C2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-15C2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-15C2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-15C2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-15C2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-15C2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-15C2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-15C2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-15C2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-15C2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-15C2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-15C2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-15C2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-15C2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-15C2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-15C2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-15C2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-15C2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-15C2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-15C2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-15C2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-15C2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-15C2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-15C2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-15C2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-15C2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-15C2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-15C2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-15C2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-15C2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-15C3:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-15C3:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-15C3:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-15C3:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-15C3:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-15C3:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-15C3:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-15C3:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-15C3:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-15C3:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-15C3:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-15C3:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-15C3:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-15C3:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-15C3:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-15C3:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-15C3:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-15C3:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-15C3:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-15C3:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-15C3:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-15C3:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-15C3:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-15C3:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-15C3:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-15C3:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-15C3:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-15C3:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-15C3:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-15C3:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-15C3:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-15C3:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-15C3:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-15C3:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-15C3:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-15C3:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-15C3:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-15C3:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-15C3:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-15C3:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-15C3:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-15C3:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-15C3:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-15C3:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-15C3:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-15C3:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-15C3:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-15C3:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-15C3:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-15C3:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-15C3:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-15C3:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-15C3:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-15C3:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-15C3:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-15C3:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-15C3:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-15C3:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-15C3:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-15C3:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-15C3:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-15C3:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-15C3:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-15C3:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-15C3:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-15C3:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-15C3:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-15C3:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-15C3:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-15C3:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-15C4:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-15C4:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-15C4:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-15C4:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-15C4:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-15C4:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-15C4:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-15C4:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-15C4:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-15C4:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-15C4:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-15C4:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-15C4:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-15C4:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-15C4:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-15C4:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-15C4:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-15C4:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-15C4:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-15C4:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-15C4:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-15C4:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-15C4:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-15C4:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-15C4:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-15C4:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-15C4:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-15C4:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-15C4:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-15C4:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-15C4:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-15C4:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-15C4:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-15C4:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-15C4:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-15C4:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-15C4:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-15C4:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-15C4:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-15C4:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-16M1:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-16M1:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-16M1:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-16M1:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-16M1:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-16M1:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-16M1:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-16M1:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-16M1:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-16M1:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-16M1:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-16M1:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-16M1:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-16M1:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-16M1:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-16M1:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-16M1:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-16M1:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-16M1:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-16M1:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-16M1:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-16M1:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-16M1:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-16M1:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-16M1:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-16M1:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-16M1:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-16M1:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-16M1:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-16M1:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-16M1:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-16M1:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-16M1:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-16M1:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-16M1:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-16M1:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-16M1:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-16M1:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-16M1:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-16M1:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-16M2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-16M2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-16M2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-16M2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-16M2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-16M2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-16M2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-16M2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-16M2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-16M2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-16M2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-16M2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-16M2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-16M2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-16M2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-16M2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-16M2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-16M2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-16M2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-16M2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-16M2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-16M2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-16M2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-16M2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-16M2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-16M2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-16M2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-16M2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-16M2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-16M2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-16M2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-16M2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-16M2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-16M2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-16M2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-16M2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-16M2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-16M2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-16M2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-16M2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-16C1:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-16C1:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-16C1:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-16C1:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-16C1:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-16C1:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-16C1:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-16C1:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-16C1:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-16C1:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-16C1:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-16C1:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-16C1:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-16C1:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-16C1:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-16C1:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-16C1:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-16C1:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-16C1:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-16C1:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-16C1:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-16C1:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-16C1:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-16C1:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-16C1:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-16C1:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-16C1:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-16C1:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-16C1:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-16C1:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-16C1:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-16C1:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-16C1:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-16C1:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-16C1:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-16C1:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-16C1:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-16C1:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-16C1:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-16C1:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-16C1:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-16C1:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-16C1:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-16C1:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-16C1:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-16C1:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-16C1:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-16C1:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-16C1:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-16C1:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-16C1:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-16C1:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-16C1:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-16C1:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-16C1:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-16C1:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-16C1:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-16C1:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-16C1:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-16C1:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-16C1:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-16C1:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-16C1:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-16C1:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-16C1:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-16C1:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-16C1:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-16C1:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-16C1:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-16C1:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-16C2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-16C2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-16C2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-16C2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-16C2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-16C2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-16C2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-16C2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-16C2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-16C2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-16C2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-16C2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-16C2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-16C2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-16C2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-16C2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-16C2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-16C2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-16C2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-16C2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-16C2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-16C2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-16C2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-16C2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-16C2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-16C2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-16C2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-16C2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-16C2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-16C2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-16C2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-16C2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-16C2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-16C2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-16C2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-16C2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-16C2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-16C2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-16C2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-16C2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-16C3:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-16C3:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-16C3:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-16C3:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-16C3:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-16C3:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-16C3:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-16C3:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-16C3:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-16C3:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-16C3:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-16C3:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-16C3:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-16C3:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-16C3:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-16C3:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-16C3:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-16C3:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-16C3:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-16C3:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-16C3:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-16C3:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-16C3:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-16C3:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-16C3:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-16C3:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-16C3:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-16C3:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-16C3:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-16C3:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-16C3:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-16C3:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-16C3:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-16C3:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-16C3:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-16C3:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-16C3:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-16C3:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-16C3:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-16C3:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-16C3:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-16C3:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-16C3:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-16C3:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-16C3:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-16C3:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-16C3:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-16C3:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-16C3:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-16C3:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-16C3:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-16C3:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-16C3:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-16C3:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-16C3:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-16C3:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-16C3:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-16C3:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-16C3:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-16C3:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-16C3:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-16C3:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-16C3:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-16C3:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-16C3:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-16C3:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-16C3:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-16C3:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-16C3:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-16C3:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-16C4:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-16C4:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-16C4:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-16C4:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-16C4:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-16C4:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-16C4:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-16C4:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-16C4:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-16C4:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-16C4:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-16C4:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-16C4:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-16C4:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-16C4:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-16C4:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-16C4:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-16C4:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-16C4:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-16C4:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-16C4:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-16C4:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-16C4:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-16C4:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-16C4:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-16C4:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-16C4:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-16C4:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-16C4:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-16C4:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-16C4:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-16C4:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-16C4:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-16C4:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-16C4:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-16C4:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-16C4:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-16C4:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-16C4:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-16C4:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-17M1:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-17M1:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-17M1:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-17M1:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-17M1:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-17M1:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-17M1:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-17M1:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-17M1:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-17M1:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-17M1:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-17M1:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-17M1:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-17M1:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-17M1:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-17M1:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-17M1:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-17M1:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-17M1:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-17M1:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-17M1:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-17M1:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-17M1:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-17M1:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-17M1:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-17M1:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-17M1:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-17M1:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-17M1:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-17M1:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-17M1:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-17M1:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-17M1:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-17M1:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-17M1:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-17M1:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-17M1:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-17M1:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-17M1:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-17M1:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-17M2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-17M2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-17M2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-17M2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-17M2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-17M2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-17M2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-17M2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-17M2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-17M2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-17M2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-17M2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-17M2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-17M2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-17M2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-17M2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-17M2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-17M2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-17M2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-17M2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-17M2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-17M2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-17M2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-17M2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-17M2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-17M2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-17M2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-17M2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-17M2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-17M2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-17M2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-17M2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-17M2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-17M2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-17M2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-17M2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-17M2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-17M2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-17M2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-17M2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-17C1:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-17C1:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-17C1:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-17C1:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-17C1:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-17C1:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-17C1:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-17C1:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-17C1:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-17C1:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-17C1:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-17C1:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-17C1:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-17C1:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-17C1:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-17C1:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-17C1:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-17C1:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-17C1:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-17C1:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-17C1:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-17C1:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-17C1:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-17C1:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-17C1:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-17C1:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-17C1:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-17C1:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-17C1:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-17C1:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-17C1:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-17C1:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-17C1:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-17C1:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-17C1:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-17C1:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-17C1:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-17C1:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-17C1:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-17C1:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-17C1:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-17C1:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-17C1:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-17C1:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-17C1:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-17C1:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-17C1:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-17C1:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-17C1:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-17C1:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-17C1:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-17C1:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-17C1:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-17C1:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-17C1:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-17C1:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-17C1:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-17C1:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-17C1:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-17C1:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-17C1:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-17C1:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-17C1:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-17C1:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-17C1:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-17C1:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-17C1:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-17C1:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-17C1:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-17C1:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-17C2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-17C2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-17C2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-17C2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-17C2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-17C2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-17C2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-17C2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-17C2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-17C2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-17C2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-17C2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-17C2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-17C2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-17C2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-17C2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-17C2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-17C2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-17C2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-17C2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-17C2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-17C2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-17C2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-17C2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-17C2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-17C2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-17C2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-17C2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-17C2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-17C2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-17C2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-17C2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-17C2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-17C2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-17C2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-17C2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-17C2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-17C2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-17C2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-17C2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-17C3:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-17C3:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-17C3:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-17C3:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-17C3:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-17C3:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-17C3:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-17C3:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-17C3:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-17C3:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-17C3:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-17C3:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-17C3:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-17C3:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-17C3:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-17C3:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-17C3:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-17C3:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-17C3:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-17C3:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-17C3:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-17C3:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-17C3:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-17C3:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-17C3:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-17C3:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-17C3:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-17C3:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-17C3:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-17C3:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-17C3:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-17C3:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-17C3:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-17C3:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-17C3:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-17C3:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-17C3:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-17C3:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-17C3:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-17C3:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-17C3:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-17C3:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-17C3:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-17C3:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-17C3:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-17C3:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-17C3:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-17C3:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-17C3:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-17C3:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-17C3:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-17C3:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-17C3:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-17C3:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-17C3:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-17C3:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-17C3:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-17C3:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-17C3:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-17C3:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-17C3:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-17C3:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-17C3:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-17C3:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-17C3:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-17C3:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-17C3:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-17C3:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-17C3:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-17C3:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-17C4:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-17C4:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-17C4:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-17C4:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-17C4:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-17C4:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-17C4:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-17C4:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-17C4:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-17C4:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-17C4:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-17C4:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-17C4:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-17C4:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-17C4:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-17C4:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-17C4:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-17C4:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-17C4:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-17C4:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-17C4:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-17C4:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-17C4:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-17C4:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-17C4:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-17C4:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-17C4:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-17C4:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-17C4:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-17C4:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-17C4:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-17C4:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-17C4:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-17C4:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-17C4:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-17C4:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-17C4:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-17C4:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-17C4:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-17C4:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-18M1:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-18M1:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-18M1:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-18M1:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-18M1:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-18M1:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-18M1:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-18M1:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-18M1:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-18M1:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-18M1:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-18M1:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-18M1:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-18M1:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-18M1:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-18M1:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-18M1:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-18M1:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-18M1:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-18M1:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-18M1:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-18M1:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-18M1:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-18M1:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-18M1:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-18M1:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-18M1:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-18M1:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-18M1:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-18M1:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-18M1:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-18M1:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-18M1:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-18M1:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-18M1:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-18M1:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-18M1:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-18M1:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-18M1:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-18M1:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-18M2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-18M2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-18M2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-18M2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-18M2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-18M2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-18M2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-18M2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-18M2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-18M2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-18M2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-18M2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-18M2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-18M2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-18M2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-18M2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-18M2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-18M2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-18M2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-18M2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-18M2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-18M2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-18M2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-18M2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-18M2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-18M2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-18M2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-18M2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-18M2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-18M2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-18M2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-18M2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-18M2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-18M2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-18M2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-18M2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-18M2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-18M2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-18M2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-18M2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-18C1:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-18C1:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-18C1:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-18C1:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-18C1:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-18C1:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-18C1:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-18C1:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-18C1:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-18C1:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-18C1:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-18C1:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-18C1:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-18C1:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-18C1:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-18C1:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-18C1:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-18C1:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-18C1:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-18C1:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-18C1:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-18C1:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-18C1:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-18C1:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-18C1:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-18C1:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-18C1:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-18C1:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-18C1:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-18C1:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-18C1:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-18C1:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-18C1:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-18C1:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-18C1:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-18C1:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-18C1:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-18C1:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-18C1:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-18C1:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-18C1:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-18C1:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-18C1:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-18C1:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-18C1:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-18C1:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-18C1:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-18C1:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-18C1:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-18C1:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-18C1:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-18C1:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-18C1:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-18C1:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-18C1:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-18C1:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-18C1:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-18C1:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-18C1:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-18C1:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-18C1:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-18C1:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-18C1:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-18C1:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-18C1:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-18C1:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-18C1:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-18C1:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-18C1:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-18C1:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-18C2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-18C2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-18C2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-18C2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-18C2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-18C2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-18C2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-18C2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-18C2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-18C2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-18C2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-18C2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-18C2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-18C2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-18C2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-18C2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-18C2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-18C2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-18C2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-18C2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-18C2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-18C2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-18C2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-18C2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-18C2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-18C2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-18C2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-18C2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-18C2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-18C2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-18C2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-18C2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-18C2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-18C2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-18C2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-18C2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-18C2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-18C2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-18C2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-18C2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-18C3:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-18C3:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-18C3:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-18C3:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-18C3:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-18C3:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-18C3:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-18C3:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-18C3:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-18C3:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-18C3:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-18C3:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-18C3:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-18C3:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-18C3:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-18C3:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-18C3:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-18C3:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-18C3:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-18C3:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-18C3:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-18C3:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-18C3:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-18C3:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-18C3:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-18C3:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-18C3:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-18C3:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-18C3:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-18C3:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-18C3:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-18C3:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-18C3:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-18C3:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-18C3:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-18C3:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-18C3:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-18C3:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-18C3:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-18C3:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-18C3:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-18C3:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-18C3:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-18C3:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-18C3:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-18C3:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-18C3:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-18C3:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-18C3:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-18C3:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-18C3:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-18C3:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-18C3:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-18C3:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-18C3:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-18C3:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-18C3:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-18C3:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-18C3:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-18C3:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-18C3:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-18C3:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-18C3:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-18C3:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-18C3:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-18C3:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-18C3:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-18C3:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-18C3:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-18C3:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-18C4:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-18C4:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-18C4:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-18C4:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-18C4:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-18C4:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-18C4:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-18C4:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-18C4:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-18C4:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-18C4:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-18C4:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-18C4:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-18C4:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-18C4:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-18C4:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-18C4:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-18C4:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-18C4:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-18C4:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-18C4:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-18C4:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-18C4:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-18C4:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-18C4:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-18C4:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-18C4:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-18C4:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-18C4:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-18C4:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-18C4:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-18C4:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-18C4:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-18C4:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-18C4:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-18C4:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-18C4:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-18C4:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-18C4:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-18C4:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-19M1:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-19M1:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-19M1:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-19M1:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-19M1:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-19M1:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-19M1:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-19M1:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-19M1:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-19M1:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-19M1:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-19M1:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-19M1:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-19M1:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-19M1:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-19M1:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-19M1:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-19M1:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-19M1:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-19M1:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-19M1:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-19M1:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-19M1:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-19M1:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-19M1:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-19M1:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-19M1:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-19M1:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-19M1:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-19M1:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-19M1:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-19M1:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-19M1:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-19M1:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-19M1:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-19M1:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-19M1:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-19M1:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-19M1:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-19M1:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-19M2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-19M2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-19M2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-19M2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-19M2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-19M2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-19M2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-19M2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-19M2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-19M2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-19M2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-19M2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-19M2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-19M2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-19M2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-19M2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-19M2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-19M2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-19M2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-19M2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-19M2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-19M2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-19M2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-19M2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-19M2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-19M2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-19M2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-19M2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-19M2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-19M2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-19M2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-19M2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-19M2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-19M2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-19M2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-19M2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-19M2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-19M2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-19M2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-19M2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-19C1:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-19C1:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-19C1:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-19C1:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-19C1:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-19C1:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-19C1:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-19C1:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-19C1:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-19C1:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-19C1:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-19C1:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-19C1:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-19C1:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-19C1:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-19C1:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-19C1:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-19C1:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-19C1:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-19C1:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-19C1:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-19C1:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-19C1:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-19C1:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-19C1:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-19C1:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-19C1:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-19C1:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-19C1:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-19C1:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-19C1:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-19C1:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-19C1:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-19C1:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-19C1:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-19C1:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-19C1:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-19C1:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-19C1:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-19C1:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-19C1:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-19C1:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-19C1:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-19C1:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-19C1:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-19C1:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-19C1:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-19C1:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-19C1:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-19C1:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-19C1:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-19C1:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-19C1:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-19C1:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-19C1:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-19C1:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-19C1:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-19C1:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-19C1:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-19C1:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-19C1:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-19C1:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-19C1:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-19C1:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-19C1:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-19C1:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-19C1:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-19C1:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-19C1:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-19C1:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-19C2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-19C2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-19C2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-19C2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-19C2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-19C2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-19C2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-19C2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-19C2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-19C2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-19C2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-19C2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-19C2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-19C2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-19C2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-19C2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-19C2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-19C2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-19C2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-19C2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-19C2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-19C2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-19C2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-19C2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-19C2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-19C2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-19C2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-19C2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-19C2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-19C2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-19C2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-19C2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-19C2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-19C2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-19C2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-19C2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-19C2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-19C2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-19C2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-19C2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-19C3:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-19C3:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-19C3:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-19C3:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-19C3:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-19C3:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-19C3:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-19C3:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-19C3:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-19C3:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-19C3:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-19C3:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-19C3:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-19C3:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-19C3:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-19C3:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-19C3:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-19C3:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-19C3:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-19C3:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-19C3:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-19C3:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-19C3:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-19C3:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-19C3:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-19C3:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-19C3:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-19C3:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-19C3:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-19C3:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-19C3:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-19C3:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-19C3:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-19C3:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-19C3:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-19C3:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-19C3:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-19C3:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-19C3:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-19C3:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-19C3:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-19C3:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-19C3:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-19C3:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-19C3:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-19C3:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-19C3:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-19C3:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-19C3:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-19C3:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-19C3:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-19C3:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-19C3:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-19C3:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-19C3:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-19C3:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-19C3:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-19C3:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-19C3:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-19C3:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-19C3:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-19C3:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-19C3:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-19C3:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-19C3:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-19C3:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-19C3:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-19C3:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-19C3:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-19C3:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-19C4:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-19C4:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-19C4:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-19C4:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-19C4:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-19C4:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-19C4:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-19C4:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-19C4:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-19C4:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-19C4:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-19C4:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-19C4:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-19C4:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-19C4:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-19C4:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-19C4:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-19C4:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-19C4:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-19C4:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-19C4:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-19C4:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-19C4:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-19C4:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-19C4:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-19C4:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-19C4:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-19C4:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-19C4:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-19C4:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-19C4:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-19C4:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-19C4:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-19C4:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-19C4:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-19C4:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-19C4:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-19C4:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-19C4:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-19C4:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-20M1:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-20M1:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-20M1:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-20M1:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-20M1:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-20M1:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-20M1:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-20M1:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-20M1:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-20M1:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-20M1:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-20M1:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-20M1:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-20M1:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-20M1:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-20M1:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-20M1:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-20M1:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-20M1:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-20M1:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-20M1:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-20M1:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-20M1:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-20M1:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-20M1:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-20M1:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-20M1:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-20M1:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-20M1:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-20M1:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-20M1:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-20M1:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-20M1:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-20M1:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-20M1:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-20M1:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-20M1:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-20M1:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-20M1:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-20M1:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-20M2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-20M2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-20M2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-20M2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-20M2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-20M2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-20M2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-20M2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-20M2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-20M2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-20M2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-20M2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-20M2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-20M2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-20M2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-20M2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-20M2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-20M2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-20M2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-20M2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-20M2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-20M2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-20M2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-20M2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-20M2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-20M2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-20M2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-20M2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-20M2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-20M2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-20M2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-20M2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-20M2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-20M2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-20M2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-20M2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-20M2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-20M2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-20M2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-20M2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-20C1:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-20C1:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-20C1:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-20C1:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-20C1:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-20C1:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-20C1:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-20C1:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-20C1:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-20C1:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-20C1:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-20C1:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-20C1:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-20C1:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-20C1:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-20C1:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-20C1:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-20C1:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-20C1:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-20C1:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-20C1:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-20C1:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-20C1:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-20C1:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-20C1:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-20C1:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-20C1:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-20C1:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-20C1:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-20C1:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-20C1:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-20C1:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-20C1:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-20C1:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-20C1:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-20C1:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-20C1:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-20C1:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-20C1:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-20C1:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-20C1:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-20C1:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-20C1:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-20C1:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-20C1:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-20C1:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-20C1:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-20C1:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-20C1:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-20C1:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-20C1:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-20C1:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-20C1:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-20C1:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-20C1:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-20C1:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-20C1:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-20C1:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-20C1:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-20C1:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-20C1:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-20C1:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-20C1:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-20C1:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-20C1:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-20C1:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-20C1:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-20C1:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-20C1:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-20C1:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-20C2:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-20C2:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-20C2:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-20C2:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-20C2:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-20C2:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-20C2:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-20C2:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-20C2:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-20C2:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-20C2:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-20C2:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-20C2:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-20C2:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-20C2:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-20C2:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-20C2:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-20C2:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-20C2:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-20C2:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-20C2:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-20C2:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-20C2:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-20C2:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-20C2:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-20C2:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-20C2:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-20C2:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-20C2:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-20C2:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-20C2:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-20C2:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-20C2:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-20C2:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-20C2:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-20C2:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-20C2:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-20C2:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-20C2:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-20C2:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-20C3:DI-BPM-1:INFOClkProp-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:ADCClkSel-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:INFOADCRate-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-1:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-1:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-20C3:DI-BPM-1:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-20C3:DI-BPM-1:ADCTrigDir-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-20C3:DI-BPM-1:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-20C3:DI-BPM-1:RFFETempCtl-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-20C3:DI-BPM-1:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-20C3:DI-BPM-1:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-20C3:DI-BPM-1:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-20C3:DI-BPM-1:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-20C3:DI-BPM-1:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-20C3:DI-BPM-1:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-20C3:DI-BPM-1:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-20C3:DI-BPM-1:ADC0RstModes-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:ADC1RstModes-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:ADC2RstModes-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:ADC3RstModes-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:ACQChannel-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:ACQSamplesPre-SP', 100, 0.0],
    ['SI-20C3:DI-BPM-1:ACQSamplesPost-SP', 50, 0.0],
    ['SI-20C3:DI-BPM-1:ACQTrigger-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:ACQShots-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-1:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:ACQBPMMode-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TbtTagEn-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TbtTagDly-SP', 0.0, 0.0],
    ['SI-20C3:DI-BPM-1:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-20C3:DI-BPM-1:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-20C3:DI-BPM-1:RFFEAtt-SP', 31.5, 0.0],
    ['SI-20C3:DI-BPM-1:PosKsum-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-1:PosXOffset-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:PosYOffset-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:PosQOffset-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-20C3:DI-BPM-1:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-20C3:DI-BPM-1:INFOTBTRate-SP', 382, 0.0],
    ['SI-20C3:DI-BPM-1:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-20C3:DI-BPM-1:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-20C3:DI-BPM-1:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-20C3:DI-BPM-1:PosKx-SP', 8485281, 0.0],
    ['SI-20C3:DI-BPM-1:PosKy-SP', 8485281, 0.0],
    ['SI-20C3:DI-BPM-1:PosKq-SP', 8485281, 0.0],
    ['SI-20C3:DI-BPM-1:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-20C3:DI-BPM-1:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-1:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-20C3:DI-BPM-1:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-20C3:DI-BPM-1:SwMode-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-1:SwDivClk-SP', 8786, 0.0],
    ['SI-20C3:DI-BPM-1:SwDly-SP', 29, 0.0],
    ['SI-20C3:DI-BPM-1:SwTagEn-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-1:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-20C3:DI-BPM-2:INFOClkProp-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:ADCClkSel-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:INFOADCRate-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-2:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-2:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-20C3:DI-BPM-2:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-20C3:DI-BPM-2:ADCTrigDir-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-20C3:DI-BPM-2:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-20C3:DI-BPM-2:RFFETempCtl-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-20C3:DI-BPM-2:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-20C3:DI-BPM-2:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-20C3:DI-BPM-2:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-20C3:DI-BPM-2:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-20C3:DI-BPM-2:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-20C3:DI-BPM-2:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-20C3:DI-BPM-2:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-20C3:DI-BPM-2:ADC0RstModes-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:ADC1RstModes-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:ADC2RstModes-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:ADC3RstModes-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:ACQChannel-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:ACQSamplesPre-SP', 100, 0.0],
    ['SI-20C3:DI-BPM-2:ACQSamplesPost-SP', 50, 0.0],
    ['SI-20C3:DI-BPM-2:ACQTrigger-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:ACQShots-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-2:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:ACQBPMMode-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TbtTagEn-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TbtTagDly-SP', 0.0, 0.0],
    ['SI-20C3:DI-BPM-2:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-20C3:DI-BPM-2:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-20C3:DI-BPM-2:RFFEAtt-SP', 31.5, 0.0],
    ['SI-20C3:DI-BPM-2:PosKsum-SP', 1, 0.0],
    ['SI-20C3:DI-BPM-2:PosXOffset-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:PosYOffset-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:PosQOffset-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-20C3:DI-BPM-2:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-20C3:DI-BPM-2:INFOTBTRate-SP', 382, 0.0],
    ['SI-20C3:DI-BPM-2:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-20C3:DI-BPM-2:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-20C3:DI-BPM-2:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-20C3:DI-BPM-2:PosKx-SP', 8485281, 0.0],
    ['SI-20C3:DI-BPM-2:PosKy-SP', 8485281, 0.0],
    ['SI-20C3:DI-BPM-2:PosKq-SP', 8485281, 0.0],
    ['SI-20C3:DI-BPM-2:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-20C3:DI-BPM-2:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-20C3:DI-BPM-2:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-20C3:DI-BPM-2:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-20C3:DI-BPM-2:SwMode-Sel', 1, 0.0],
    ['SI-20C3:DI-BPM-2:SwDivClk-SP', 8786, 0.0],
    ['SI-20C3:DI-BPM-2:SwDly-SP', 29, 0.0],
    ['SI-20C3:DI-BPM-2:SwTagEn-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-20C3:DI-BPM-2:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-20C4:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-20C4:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-20C4:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-20C4:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-20C4:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-20C4:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-20C4:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-20C4:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-20C4:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-20C4:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-20C4:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-20C4:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-20C4:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-20C4:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-20C4:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-20C4:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-20C4:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-20C4:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-20C4:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-20C4:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-20C4:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-20C4:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-20C4:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-20C4:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-20C4:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-20C4:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-20C4:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-20C4:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-20C4:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-20C4:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-20C4:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-20C4:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-20C4:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-20C4:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-20C4:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-20C4:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-20C4:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-20C4:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-20C4:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-20C4:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
    ['SI-01M1:DI-BPM:INFOClkProp-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:ADCSi57xOe-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:ADCClkSel-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:INFOADCRate-SP', 1, 0.0],
    ['SI-01M1:DI-BPM:ADCAD9510PllFunc-SP', 1, 0.0],
    ['SI-01M1:DI-BPM:ADCAD9510Outputs-SP', 31, 0.0],
    ['SI-01M1:DI-BPM:ADCAD9510ClkSel-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:ADCAD9510CpCurrent-Sel', 7, 0.0],
    ['SI-01M1:DI-BPM:ADCTrigDir-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:ADCTrigTerm-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:RFFEPidSpAC-SP', 45.0, 0.0],
    ['SI-01M1:DI-BPM:RFFEPidSpBD-SP', 45.0, 0.0],
    ['SI-01M1:DI-BPM:RFFETempCtl-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:RFFEPidACKp-SP', 10.5, 0.0],
    ['SI-01M1:DI-BPM:RFFEPidACTi-SP', 12.0, 0.0],
    ['SI-01M1:DI-BPM:RFFEPidACTd-SP', 2.0, 0.0],
    ['SI-01M1:DI-BPM:RFFEPidBDKp-SP', 10.5, 0.0],
    ['SI-01M1:DI-BPM:RFFEPidBDTi-SP', 12.0, 0.0],
    ['SI-01M1:DI-BPM:RFFEPidBDTd-SP', 2.0, 0.0],
    ['SI-01M1:DI-BPM:RFFEHeaterAC-SP', 0.0, 0.0],
    ['SI-01M1:DI-BPM:RFFEHeaterBD-SP', 0.0, 0.0],
    ['SI-01M1:DI-BPM:ADC0RstModes-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:ADC1RstModes-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:ADC2RstModes-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:ADC3RstModes-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER0Dir-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER0DirPol-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER0RcvLen-SP', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER0TrnLen-SP', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER1Dir-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER1DirPol-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER1RcvLen-SP', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER1TrnLen-SP', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER2Dir-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER2DirPol-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER2RcvLen-SP', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER2TrnLen-SP', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER3Dir-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER3DirPol-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER3RcvLen-SP', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER3TrnLen-SP', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER4Dir-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER4DirPol-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER4RcvLen-SP', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER4TrnLen-SP', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER5Dir-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER5DirPol-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER5RcvLen-SP', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER5TrnLen-SP', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER6Dir-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER6DirPol-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER6RcvLen-SP', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER6TrnLen-SP', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER7Dir-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER7DirPol-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER7RcvLen-SP', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER7TrnLen-SP', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER0RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER0RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER0TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER0TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER1RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER1RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER1TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER1TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER2RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER2RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER2TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER2TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER3RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER3RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER3TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER3TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER4RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER4RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER4TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER4TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER5RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER5RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER5TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER5TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER6RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER6RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER6TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER6TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER7RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER7RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER7TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER7TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER8RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER8RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER8TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER8TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER9RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER9RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER9TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER9TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER10RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER10RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER10TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER10TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER11RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER11RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER11TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER11TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER12RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER12RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER12TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER12TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER13RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER13RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER13TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER13TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER14RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER14RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER14TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER14TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER15RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER15RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER15TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER15TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER16RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER16RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER16TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER16TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER17RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER17RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER17TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER17TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER18RcvInSel-SP', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER18RcvSrc-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER18TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER18TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER19RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER19RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER19TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER19TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER20RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER20RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER20TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER20TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER21RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER21RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER21TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER21TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER22RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER22RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER22TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER22TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER23RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER23RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER23TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER23TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM0RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM0RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM0TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM0TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM1RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM1RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM1TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM1TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM2RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM2RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM2TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM2TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM3RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM3RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM3TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM3TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM4RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM4RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM4TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM4TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM5RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM5RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM5TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM5TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM6RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM6RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM6TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM6TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM7RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM7RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM7TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM7TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM8RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM8RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM8TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM8TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM9RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM9RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM9TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM9TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM10RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM10RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM10TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM10TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM11RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM11RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM11TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM11TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM12RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM12RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM12TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM12TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM13RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM13RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM13TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM13TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM14RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM14RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM14TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM14TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM15RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM15RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM15TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM15TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM16RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM16RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM16TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM16TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM17RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM17RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM17TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM17TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM18RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM18RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM18TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM18TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM19RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM19RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM19TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM19TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM20RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM20RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM20TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM20TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM21RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM21RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM21TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM21TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM22RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM22RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM22TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM22TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM23RcvInSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM23RcvSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM23TrnOutSel-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:TRIGGER_PM23TrnSrc-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:ACQChannel-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:ACQSamplesPre-SP', 100, 0.0],
    ['SI-01M1:DI-BPM:ACQSamplesPost-SP', 50, 0.0],
    ['SI-01M1:DI-BPM:ACQTrigger-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:ACQShots-SP', 1, 0.0],
    ['SI-01M1:DI-BPM:ACQTriggerRep-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:ACQBPMMode-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:TbtTagEn-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:TbtTagDly-SP', 0.0, 0.0],
    ['SI-01M1:DI-BPM:TbtDataMaskEn-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
    ['SI-01M1:DI-BPM:TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
    ['SI-01M1:DI-BPM:RFFEAtt-SP', 31.5, 0.0],
    ['SI-01M1:DI-BPM:PosKsum-SP', 1, 0.0],
    ['SI-01M1:DI-BPM:PosXOffset-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:PosYOffset-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:PosQOffset-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:ACQTriggerHwDly-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:INFOClkFreq-SP', 220910069.0, 0.0],
    ['SI-01M1:DI-BPM:INFOHarmonicNumber-SP', 864, 0.0],
    ['SI-01M1:DI-BPM:INFOTBTRate-SP', 382, 0.0],
    ['SI-01M1:DI-BPM:INFOFOFBRate-SP', 8786, 0.0],
    ['SI-01M1:DI-BPM:INFOMONITRate-SP', 21929856, 0.0],
    ['SI-01M1:DI-BPM:INFOMONIT1Rate-SP', 230346, 0.0],
    ['SI-01M1:DI-BPM:PosKx-SP', 8485281, 0.0],
    ['SI-01M1:DI-BPM:PosKy-SP', 8485281, 0.0],
    ['SI-01M1:DI-BPM:PosKq-SP', 8485281, 0.0],
    ['SI-01M1:DI-BPM:ADCAD9510ADiv-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:ADCAD9510BDiv-SP', 382, 0.0],
    ['SI-01M1:DI-BPM:ADCAD9510Prescaler-SP', 0, 0.0],
    ['SI-01M1:DI-BPM:ADCAD9510RDiv-SP', 120, 0.0],
    ['SI-01M1:DI-BPM:ADCSi57xFreq-SP', 220870069.0, 0.0],
    ['SI-01M1:DI-BPM:SwMode-Sel', 1, 0.0],
    ['SI-01M1:DI-BPM:SwDivClk-SP', 8786, 0.0],
    ['SI-01M1:DI-BPM:SwDly-SP', 29, 0.0],
    ['SI-01M1:DI-BPM:SwTagEn-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:SwDataMaskEn-Sel', 0, 0.0],
    ['SI-01M1:DI-BPM:SwDataMaskSamples-SP', 1910, 0.0],
]

_scrn_pvs = [
    ['TB-01:DI-ScrnCam-1:ScaleFactorX-SP', -1, 0.0],
    ['TB-01:DI-ScrnCam-1:ScaleFactorY-SP', -1, 0.0],
    ['TB-01:DI-ScrnCam-1:CenterOffsetX-SP', 0, 0.0],
    ['TB-01:DI-ScrnCam-1:CenterOffsetY-SP', 0, 0.0],
    ['TB-01:DI-ScrnCam-1:ThetaOffset-SP', 0, 0.0],
    ['TB-01:DI-ScrnCam-1:Enbl-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCam-1:AcqMode-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCam-1:AcqPeriod-SP', 0.4, 0.0],
    ['TB-01:DI-ScrnCam-1:AcqPeriodLowLim-SP', 0.083, 0.0],
    ['TB-01:DI-ScrnCam-1:ExposureMode-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCam-1:ExposureTime-SP', 5000, 0.0],
    ['TB-01:DI-ScrnCam-1:Gain-SP', 0, 0.0],
    ['TB-01:DI-ScrnCam-1:BlackLevel-SP', 0, 0.0],
    ['TB-01:DI-ScrnCam-1:DebouncerPeriod-SP', 0, 0.0],
    ['TB-01:DI-ScrnCam-1:DataType-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCam-1:TransformType-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCam-1:AOIOffsetX-SP', 0, 0.0],
    ['TB-01:DI-ScrnCam-1:AOIOffsetY-SP', 0, 0.0],
    ['TB-01:DI-ScrnCam-1:AOIWidth-SP', 1280, 0.0],
    ['TB-01:DI-ScrnCam-1:AOIHeight-SP', 1024, 0.0],
    ['TB-01:DI-ScrnCam-1:AOIAutoCenterX-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCam-1:AOIAutoCenterY-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCam-1:PacketSize-SP', 1500, 0.0],
    ['TB-01:DI-ScrnCam-1:InterPacketDelay-SP', 1000, 0.0],
    ['TB-01:DI-ScrnCam-1:TransmDelay-SP', 0, 0.0],
    ['TB-01:DI-ScrnCam-1:BwReserve-SP', 10, 0.0],
    ['TB-01:DI-ScrnCam-1:BwReserveAccum-SP', 1, 0.0],
    ['TB-01:DI-ScrnCam-1:EnblBGSubtraction-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCam-1:EnblOffsetScale-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCam-1:PixelScale-SP', 1, 0.0],
    ['TB-01:DI-ScrnCam-1:PixelOffset-SP', 0, 0.0],
    ['TB-01:DI-ScrnCam-1:EnblHighClip-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCam-1:EnblLowClip-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCam-1:HighClip-SP', 65535, 0.0],
    ['TB-01:DI-ScrnCam-1:LowClip-SP', 0, 0.0],
    ['TB-01:DI-ScrnCam-2:ScaleFactorX-SP', -1, 0.0],
    ['TB-01:DI-ScrnCam-2:ScaleFactorY-SP', -1, 0.0],
    ['TB-01:DI-ScrnCam-2:CenterOffsetX-SP', 0, 0.0],
    ['TB-01:DI-ScrnCam-2:CenterOffsetY-SP', 0, 0.0],
    ['TB-01:DI-ScrnCam-2:ThetaOffset-SP', 0, 0.0],
    ['TB-01:DI-ScrnCam-2:Enbl-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCam-2:AcqMode-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCam-2:AcqPeriod-SP', 0.4, 0.0],
    ['TB-01:DI-ScrnCam-2:AcqPeriodLowLim-SP', 0.083, 0.0],
    ['TB-01:DI-ScrnCam-2:ExposureMode-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCam-2:ExposureTime-SP', 5000, 0.0],
    ['TB-01:DI-ScrnCam-2:Gain-SP', 0, 0.0],
    ['TB-01:DI-ScrnCam-2:BlackLevel-SP', 0, 0.0],
    ['TB-01:DI-ScrnCam-2:DebouncerPeriod-SP', 0, 0.0],
    ['TB-01:DI-ScrnCam-2:DataType-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCam-2:TransformType-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCam-2:AOIOffsetX-SP', 0, 0.0],
    ['TB-01:DI-ScrnCam-2:AOIOffsetY-SP', 0, 0.0],
    ['TB-01:DI-ScrnCam-2:AOIWidth-SP', 1280, 0.0],
    ['TB-01:DI-ScrnCam-2:AOIHeight-SP', 1024, 0.0],
    ['TB-01:DI-ScrnCam-2:AOIAutoCenterX-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCam-2:AOIAutoCenterY-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCam-2:PacketSize-SP', 1500, 0.0],
    ['TB-01:DI-ScrnCam-2:InterPacketDelay-SP', 1000, 0.0],
    ['TB-01:DI-ScrnCam-2:TransmDelay-SP', 0, 0.0],
    ['TB-01:DI-ScrnCam-2:BwReserve-SP', 10, 0.0],
    ['TB-01:DI-ScrnCam-2:BwReserveAccum-SP', 1, 0.0],
    ['TB-01:DI-ScrnCam-2:EnblBGSubtraction-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCam-2:EnblOffsetScale-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCam-2:PixelScale-SP', 1, 0.0],
    ['TB-01:DI-ScrnCam-2:PixelOffset-SP', 0, 0.0],
    ['TB-01:DI-ScrnCam-2:EnblHighClip-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCam-2:EnblLowClip-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCam-2:HighClip-SP', 65535, 0.0],
    ['TB-01:DI-ScrnCam-2:LowClip-SP', 0, 0.0],
    ['TB-02:DI-ScrnCam-1:ScaleFactorX-SP', -1, 0.0],
    ['TB-02:DI-ScrnCam-1:ScaleFactorY-SP', -1, 0.0],
    ['TB-02:DI-ScrnCam-1:CenterOffsetX-SP', 0, 0.0],
    ['TB-02:DI-ScrnCam-1:CenterOffsetY-SP', 0, 0.0],
    ['TB-02:DI-ScrnCam-1:ThetaOffset-SP', 0, 0.0],
    ['TB-02:DI-ScrnCam-1:Enbl-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCam-1:AcqMode-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCam-1:AcqPeriod-SP', 0.4, 0.0],
    ['TB-02:DI-ScrnCam-1:AcqPeriodLowLim-SP', 0.083, 0.0],
    ['TB-02:DI-ScrnCam-1:ExposureMode-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCam-1:ExposureTime-SP', 5000, 0.0],
    ['TB-02:DI-ScrnCam-1:Gain-SP', 0, 0.0],
    ['TB-02:DI-ScrnCam-1:BlackLevel-SP', 0, 0.0],
    ['TB-02:DI-ScrnCam-1:DebouncerPeriod-SP', 0, 0.0],
    ['TB-02:DI-ScrnCam-1:DataType-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCam-1:TransformType-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCam-1:AOIOffsetX-SP', 0, 0.0],
    ['TB-02:DI-ScrnCam-1:AOIOffsetY-SP', 0, 0.0],
    ['TB-02:DI-ScrnCam-1:AOIWidth-SP', 1280, 0.0],
    ['TB-02:DI-ScrnCam-1:AOIHeight-SP', 1024, 0.0],
    ['TB-02:DI-ScrnCam-1:AOIAutoCenterX-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCam-1:AOIAutoCenterY-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCam-1:PacketSize-SP', 1500, 0.0],
    ['TB-02:DI-ScrnCam-1:InterPacketDelay-SP', 1000, 0.0],
    ['TB-02:DI-ScrnCam-1:TransmDelay-SP', 0, 0.0],
    ['TB-02:DI-ScrnCam-1:BwReserve-SP', 10, 0.0],
    ['TB-02:DI-ScrnCam-1:BwReserveAccum-SP', 1, 0.0],
    ['TB-02:DI-ScrnCam-1:EnblBGSubtraction-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCam-1:EnblOffsetScale-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCam-1:PixelScale-SP', 1, 0.0],
    ['TB-02:DI-ScrnCam-1:PixelOffset-SP', 0, 0.0],
    ['TB-02:DI-ScrnCam-1:EnblHighClip-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCam-1:EnblLowClip-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCam-1:HighClip-SP', 65535, 0.0],
    ['TB-02:DI-ScrnCam-1:LowClip-SP', 0, 0.0],
    ['TB-02:DI-ScrnCam-2:ScaleFactorX-SP', -1, 0.0],
    ['TB-02:DI-ScrnCam-2:ScaleFactorY-SP', -1, 0.0],
    ['TB-02:DI-ScrnCam-2:CenterOffsetX-SP', 0, 0.0],
    ['TB-02:DI-ScrnCam-2:CenterOffsetY-SP', 0, 0.0],
    ['TB-02:DI-ScrnCam-2:ThetaOffset-SP', 0, 0.0],
    ['TB-02:DI-ScrnCam-2:Enbl-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCam-2:AcqMode-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCam-2:AcqPeriod-SP', 0.4, 0.0],
    ['TB-02:DI-ScrnCam-2:AcqPeriodLowLim-SP', 0.083, 0.0],
    ['TB-02:DI-ScrnCam-2:ExposureMode-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCam-2:ExposureTime-SP', 5000, 0.0],
    ['TB-02:DI-ScrnCam-2:Gain-SP', 0, 0.0],
    ['TB-02:DI-ScrnCam-2:BlackLevel-SP', 0, 0.0],
    ['TB-02:DI-ScrnCam-2:DebouncerPeriod-SP', 0, 0.0],
    ['TB-02:DI-ScrnCam-2:DataType-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCam-2:TransformType-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCam-2:AOIOffsetX-SP', 0, 0.0],
    ['TB-02:DI-ScrnCam-2:AOIOffsetY-SP', 0, 0.0],
    ['TB-02:DI-ScrnCam-2:AOIWidth-SP', 1280, 0.0],
    ['TB-02:DI-ScrnCam-2:AOIHeight-SP', 1024, 0.0],
    ['TB-02:DI-ScrnCam-2:AOIAutoCenterX-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCam-2:AOIAutoCenterY-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCam-2:PacketSize-SP', 1500, 0.0],
    ['TB-02:DI-ScrnCam-2:InterPacketDelay-SP', 1000, 0.0],
    ['TB-02:DI-ScrnCam-2:TransmDelay-SP', 0, 0.0],
    ['TB-02:DI-ScrnCam-2:BwReserve-SP', 10, 0.0],
    ['TB-02:DI-ScrnCam-2:BwReserveAccum-SP', 1, 0.0],
    ['TB-02:DI-ScrnCam-2:EnblBGSubtraction-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCam-2:EnblOffsetScale-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCam-2:PixelScale-SP', 1, 0.0],
    ['TB-02:DI-ScrnCam-2:PixelOffset-SP', 0, 0.0],
    ['TB-02:DI-ScrnCam-2:EnblHighClip-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCam-2:EnblLowClip-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCam-2:HighClip-SP', 65535, 0.0],
    ['TB-02:DI-ScrnCam-2:LowClip-SP', 0, 0.0],
    ['TB-03:DI-ScrnCam:ScaleFactorX-SP', -1, 0.0],
    ['TB-03:DI-ScrnCam:ScaleFactorY-SP', -1, 0.0],
    ['TB-03:DI-ScrnCam:CenterOffsetX-SP', 0, 0.0],
    ['TB-03:DI-ScrnCam:CenterOffsetY-SP', 0, 0.0],
    ['TB-03:DI-ScrnCam:ThetaOffset-SP', 0, 0.0],
    ['TB-03:DI-ScrnCam:Enbl-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCam:AcqMode-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCam:AcqPeriod-SP', 0.4, 0.0],
    ['TB-03:DI-ScrnCam:AcqPeriodLowLim-SP', 0.083, 0.0],
    ['TB-03:DI-ScrnCam:ExposureMode-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCam:ExposureTime-SP', 5000, 0.0],
    ['TB-03:DI-ScrnCam:Gain-SP', 0, 0.0],
    ['TB-03:DI-ScrnCam:BlackLevel-SP', 0, 0.0],
    ['TB-03:DI-ScrnCam:DebouncerPeriod-SP', 0, 0.0],
    ['TB-03:DI-ScrnCam:DataType-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCam:TransformType-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCam:AOIOffsetX-SP', 0, 0.0],
    ['TB-03:DI-ScrnCam:AOIOffsetY-SP', 0, 0.0],
    ['TB-03:DI-ScrnCam:AOIWidth-SP', 1280, 0.0],
    ['TB-03:DI-ScrnCam:AOIHeight-SP', 1024, 0.0],
    ['TB-03:DI-ScrnCam:AOIAutoCenterX-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCam:AOIAutoCenterY-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCam:PacketSize-SP', 1500, 0.0],
    ['TB-03:DI-ScrnCam:InterPacketDelay-SP', 1000, 0.0],
    ['TB-03:DI-ScrnCam:TransmDelay-SP', 0, 0.0],
    ['TB-03:DI-ScrnCam:BwReserve-SP', 10, 0.0],
    ['TB-03:DI-ScrnCam:BwReserveAccum-SP', 1, 0.0],
    ['TB-03:DI-ScrnCam:EnblBGSubtraction-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCam:EnblOffsetScale-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCam:PixelScale-SP', 1, 0.0],
    ['TB-03:DI-ScrnCam:PixelOffset-SP', 0, 0.0],
    ['TB-03:DI-ScrnCam:EnblHighClip-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCam:EnblLowClip-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCam:HighClip-SP', 65535, 0.0],
    ['TB-03:DI-ScrnCam:LowClip-SP', 0, 0.0],
    ['TB-04:DI-ScrnCam:ScaleFactorX-SP', -1, 0.0],
    ['TB-04:DI-ScrnCam:ScaleFactorY-SP', -1, 0.0],
    ['TB-04:DI-ScrnCam:CenterOffsetX-SP', 0, 0.0],
    ['TB-04:DI-ScrnCam:CenterOffsetY-SP', 0, 0.0],
    ['TB-04:DI-ScrnCam:ThetaOffset-SP', 0, 0.0],
    ['TB-04:DI-ScrnCam:Enbl-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCam:AcqMode-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCam:AcqPeriod-SP', 0.4, 0.0],
    ['TB-04:DI-ScrnCam:AcqPeriodLowLim-SP', 0.083, 0.0],
    ['TB-04:DI-ScrnCam:ExposureMode-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCam:ExposureTime-SP', 5000, 0.0],
    ['TB-04:DI-ScrnCam:Gain-SP', 0, 0.0],
    ['TB-04:DI-ScrnCam:BlackLevel-SP', 0, 0.0],
    ['TB-04:DI-ScrnCam:DebouncerPeriod-SP', 0, 0.0],
    ['TB-04:DI-ScrnCam:DataType-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCam:TransformType-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCam:AOIOffsetX-SP', 0, 0.0],
    ['TB-04:DI-ScrnCam:AOIOffsetY-SP', 0, 0.0],
    ['TB-04:DI-ScrnCam:AOIWidth-SP', 1280, 0.0],
    ['TB-04:DI-ScrnCam:AOIHeight-SP', 1024, 0.0],
    ['TB-04:DI-ScrnCam:AOIAutoCenterX-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCam:AOIAutoCenterY-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCam:PacketSize-SP', 1500, 0.0],
    ['TB-04:DI-ScrnCam:InterPacketDelay-SP', 1000, 0.0],
    ['TB-04:DI-ScrnCam:TransmDelay-SP', 0, 0.0],
    ['TB-04:DI-ScrnCam:BwReserve-SP', 10, 0.0],
    ['TB-04:DI-ScrnCam:BwReserveAccum-SP', 1, 0.0],
    ['TB-04:DI-ScrnCam:EnblBGSubtraction-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCam:EnblOffsetScale-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCam:PixelScale-SP', 1, 0.0],
    ['TB-04:DI-ScrnCam:PixelOffset-SP', 0, 0.0],
    ['TB-04:DI-ScrnCam:EnblHighClip-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCam:EnblLowClip-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCam:HighClip-SP', 65535, 0.0],
    ['TB-04:DI-ScrnCam:LowClip-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCam-1:ScaleFactorX-SP', -1, 0.0],
    ['BO-01D:DI-ScrnCam-1:ScaleFactorY-SP', -1, 0.0],
    ['BO-01D:DI-ScrnCam-1:CenterOffsetX-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCam-1:CenterOffsetY-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCam-1:ThetaOffset-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCam-1:Enbl-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCam-1:AcqMode-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCam-1:AcqPeriod-SP', 0.4, 0.0],
    ['BO-01D:DI-ScrnCam-1:AcqPeriodLowLim-SP', 0.083, 0.0],
    ['BO-01D:DI-ScrnCam-1:ExposureMode-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCam-1:ExposureTime-SP', 5000, 0.0],
    ['BO-01D:DI-ScrnCam-1:Gain-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCam-1:BlackLevel-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCam-1:DebouncerPeriod-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCam-1:DataType-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCam-1:TransformType-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCam-1:AOIOffsetX-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCam-1:AOIOffsetY-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCam-1:AOIWidth-SP', 1280, 0.0],
    ['BO-01D:DI-ScrnCam-1:AOIHeight-SP', 1024, 0.0],
    ['BO-01D:DI-ScrnCam-1:AOIAutoCenterX-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCam-1:AOIAutoCenterY-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCam-1:PacketSize-SP', 1500, 0.0],
    ['BO-01D:DI-ScrnCam-1:InterPacketDelay-SP', 1000, 0.0],
    ['BO-01D:DI-ScrnCam-1:TransmDelay-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCam-1:BwReserve-SP', 10, 0.0],
    ['BO-01D:DI-ScrnCam-1:BwReserveAccum-SP', 1, 0.0],
    ['BO-01D:DI-ScrnCam-1:EnblBGSubtraction-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCam-1:EnblOffsetScale-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCam-1:PixelScale-SP', 1, 0.0],
    ['BO-01D:DI-ScrnCam-1:PixelOffset-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCam-1:EnblHighClip-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCam-1:EnblLowClip-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCam-1:HighClip-SP', 65535, 0.0],
    ['BO-01D:DI-ScrnCam-1:LowClip-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCam-2:ScaleFactorX-SP', -1, 0.0],
    ['BO-01D:DI-ScrnCam-2:ScaleFactorY-SP', -1, 0.0],
    ['BO-01D:DI-ScrnCam-2:CenterOffsetX-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCam-2:CenterOffsetY-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCam-2:ThetaOffset-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCam-2:Enbl-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCam-2:AcqMode-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCam-2:AcqPeriod-SP', 0.4, 0.0],
    ['BO-01D:DI-ScrnCam-2:AcqPeriodLowLim-SP', 0.083, 0.0],
    ['BO-01D:DI-ScrnCam-2:ExposureMode-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCam-2:ExposureTime-SP', 5000, 0.0],
    ['BO-01D:DI-ScrnCam-2:Gain-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCam-2:BlackLevel-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCam-2:DebouncerPeriod-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCam-2:DataType-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCam-2:TransformType-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCam-2:AOIOffsetX-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCam-2:AOIOffsetY-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCam-2:AOIWidth-SP', 1280, 0.0],
    ['BO-01D:DI-ScrnCam-2:AOIHeight-SP', 1024, 0.0],
    ['BO-01D:DI-ScrnCam-2:AOIAutoCenterX-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCam-2:AOIAutoCenterY-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCam-2:PacketSize-SP', 1500, 0.0],
    ['BO-01D:DI-ScrnCam-2:InterPacketDelay-SP', 1000, 0.0],
    ['BO-01D:DI-ScrnCam-2:TransmDelay-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCam-2:BwReserve-SP', 10, 0.0],
    ['BO-01D:DI-ScrnCam-2:BwReserveAccum-SP', 1, 0.0],
    ['BO-01D:DI-ScrnCam-2:EnblBGSubtraction-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCam-2:EnblOffsetScale-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCam-2:PixelScale-SP', 1, 0.0],
    ['BO-01D:DI-ScrnCam-2:PixelOffset-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCam-2:EnblHighClip-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCam-2:EnblLowClip-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCam-2:HighClip-SP', 65535, 0.0],
    ['BO-01D:DI-ScrnCam-2:LowClip-SP', 0, 0.0],
    ['BO-02U:DI-ScrnCam:ScaleFactorX-SP', -1, 0.0],
    ['BO-02U:DI-ScrnCam:ScaleFactorY-SP', -1, 0.0],
    ['BO-02U:DI-ScrnCam:CenterOffsetX-SP', 0, 0.0],
    ['BO-02U:DI-ScrnCam:CenterOffsetY-SP', 0, 0.0],
    ['BO-02U:DI-ScrnCam:ThetaOffset-SP', 0, 0.0],
    ['BO-02U:DI-ScrnCam:Enbl-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCam:AcqMode-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCam:AcqPeriod-SP', 0.4, 0.0],
    ['BO-02U:DI-ScrnCam:AcqPeriodLowLim-SP', 0.083, 0.0],
    ['BO-02U:DI-ScrnCam:ExposureMode-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCam:ExposureTime-SP', 5000, 0.0],
    ['BO-02U:DI-ScrnCam:Gain-SP', 0, 0.0],
    ['BO-02U:DI-ScrnCam:BlackLevel-SP', 0, 0.0],
    ['BO-02U:DI-ScrnCam:DebouncerPeriod-SP', 0, 0.0],
    ['BO-02U:DI-ScrnCam:DataType-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCam:TransformType-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCam:AOIOffsetX-SP', 0, 0.0],
    ['BO-02U:DI-ScrnCam:AOIOffsetY-SP', 0, 0.0],
    ['BO-02U:DI-ScrnCam:AOIWidth-SP', 1280, 0.0],
    ['BO-02U:DI-ScrnCam:AOIHeight-SP', 1024, 0.0],
    ['BO-02U:DI-ScrnCam:AOIAutoCenterX-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCam:AOIAutoCenterY-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCam:PacketSize-SP', 1500, 0.0],
    ['BO-02U:DI-ScrnCam:InterPacketDelay-SP', 1000, 0.0],
    ['BO-02U:DI-ScrnCam:TransmDelay-SP', 0, 0.0],
    ['BO-02U:DI-ScrnCam:BwReserve-SP', 10, 0.0],
    ['BO-02U:DI-ScrnCam:BwReserveAccum-SP', 1, 0.0],
    ['BO-02U:DI-ScrnCam:EnblBGSubtraction-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCam:EnblOffsetScale-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCam:PixelScale-SP', 1, 0.0],
    ['BO-02U:DI-ScrnCam:PixelOffset-SP', 0, 0.0],
    ['BO-02U:DI-ScrnCam:EnblHighClip-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCam:EnblLowClip-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCam:HighClip-SP', 65535, 0.0],
    ['BO-02U:DI-ScrnCam:LowClip-SP', 0, 0.0],

    ['TB-01:DI-Scrn-1:CalScrnPos-SP', 1, 0.0],
    ['TB-01:DI-Scrn-1:FluorScrnPos-SP', 2, 0.0],
    ['TB-01:DI-Scrn-1:NoneScrnPos-SP', 0, 0.0],
    ['TB-01:DI-Scrn-1:AcceptedErr-SP', 1, 0.0],
    ['TB-01:DI-Scrn-1:LEDPwrLvl-SP', 0, 0.0],
    ['TB-01:DI-Scrn-1:LEDThold-SP', 2.5, 0.0],
    ['TB-01:DI-Scrn-1:LEDPwrScaleFactor-SP', 0.011, 0.0],
    ['TB-01:DI-Scrn-2:CalScrnPos-SP', 1, 0.0],
    ['TB-01:DI-Scrn-2:FluorScrnPos-SP', 2, 0.0],
    ['TB-01:DI-Scrn-2:NoneScrnPos-SP', 0, 0.0],
    ['TB-01:DI-Scrn-2:AcceptedErr-SP', 1, 0.0],
    ['TB-01:DI-Scrn-2:LEDPwrLvl-SP', 0, 0.0],
    ['TB-01:DI-Scrn-2:LEDThold-SP', 2.5, 0.0],
    ['TB-01:DI-Scrn-2:LEDPwrScaleFactor-SP', 0.011, 0.0],
    ['TB-02:DI-Scrn-1:CalScrnPos-SP', 1, 0.0],
    ['TB-02:DI-Scrn-1:FluorScrnPos-SP', 2, 0.0],
    ['TB-02:DI-Scrn-1:NoneScrnPos-SP', 0, 0.0],
    ['TB-02:DI-Scrn-1:AcceptedErr-SP', 1, 0.0],
    ['TB-02:DI-Scrn-1:LEDPwrLvl-SP', 0, 0.0],
    ['TB-02:DI-Scrn-1:LEDThold-SP', 2.5, 0.0],
    ['TB-02:DI-Scrn-1:LEDPwrScaleFactor-SP', 0.011, 0.0],
    ['TB-02:DI-Scrn-2:CalScrnPos-SP', 1, 0.0],
    ['TB-02:DI-Scrn-2:FluorScrnPos-SP', 2, 0.0],
    ['TB-02:DI-Scrn-2:NoneScrnPos-SP', 0, 0.0],
    ['TB-02:DI-Scrn-2:AcceptedErr-SP', 1, 0.0],
    ['TB-02:DI-Scrn-2:LEDPwrLvl-SP', 0, 0.0],
    ['TB-02:DI-Scrn-2:LEDThold-SP', 2.5, 0.0],
    ['TB-02:DI-Scrn-2:LEDPwrScaleFactor-SP', 0.011, 0.0],
    ['TB-03:DI-Scrn:CalScrnPos-SP', 1, 0.0],
    ['TB-03:DI-Scrn:FluorScrnPos-SP', 2, 0.0],
    ['TB-03:DI-Scrn:NoneScrnPos-SP', 0, 0.0],
    ['TB-03:DI-Scrn:AcceptedErr-SP', 1, 0.0],
    ['TB-03:DI-Scrn:LEDPwrLvl-SP', 0, 0.0],
    ['TB-03:DI-Scrn:LEDThold-SP', 2.5, 0.0],
    ['TB-03:DI-Scrn:LEDPwrScaleFactor-SP', 0.011, 0.0],
    ['TB-04:DI-Scrn:CalScrnPos-SP', 1, 0.0],
    ['TB-04:DI-Scrn:FluorScrnPos-SP', 2, 0.0],
    ['TB-04:DI-Scrn:NoneScrnPos-SP', 0, 0.0],
    ['TB-04:DI-Scrn:AcceptedErr-SP', 1, 0.0],
    ['TB-04:DI-Scrn:LEDPwrLvl-SP', 0, 0.0],
    ['TB-04:DI-Scrn:LEDThold-SP', 2.5, 0.0],
    ['TB-04:DI-Scrn:LEDPwrScaleFactor-SP', 0.011, 0.0],
    ['BO-01D:DI-Scrn-1:CalScrnPos-SP', 1, 0.0],
    ['BO-01D:DI-Scrn-1:FluorScrnPos-SP', 2, 0.0],
    ['BO-01D:DI-Scrn-1:NoneScrnPos-SP', 0, 0.0],
    ['BO-01D:DI-Scrn-1:AcceptedErr-SP', 1, 0.0],
    ['BO-01D:DI-Scrn-1:LEDPwrLvl-SP', 0, 0.0],
    ['BO-01D:DI-Scrn-1:LEDThold-SP', 2.5, 0.0],
    ['BO-01D:DI-Scrn-1:LEDPwrScaleFactor-SP', 0.011, 0.0],
    ['BO-01D:DI-Scrn-2:CalScrnPos-SP', 1, 0.0],
    ['BO-01D:DI-Scrn-2:FluorScrnPos-SP', 2, 0.0],
    ['BO-01D:DI-Scrn-2:NoneScrnPos-SP', 0, 0.0],
    ['BO-01D:DI-Scrn-2:AcceptedErr-SP', 1, 0.0],
    ['BO-01D:DI-Scrn-2:LEDPwrLvl-SP', 0, 0.0],
    ['BO-01D:DI-Scrn-2:LEDThold-SP', 2.5, 0.0],
    ['BO-01D:DI-Scrn-2:LEDPwrScaleFactor-SP', 0.011, 0.0],
    ['BO-02U:DI-Scrn:CalScrnPos-SP', 1, 0.0],
    ['BO-02U:DI-Scrn:FluorScrnPos-SP', 2, 0.0],
    ['BO-02U:DI-Scrn:NoneScrnPos-SP', 0, 0.0],
    ['BO-02U:DI-Scrn:AcceptedErr-SP', 1, 0.0],
    ['BO-02U:DI-Scrn:LEDPwrLvl-SP', 0, 0.0],
    ['BO-02U:DI-Scrn:LEDThold-SP', 2.5, 0.0],
    ['BO-02U:DI-Scrn:LEDPwrScaleFactor-SP', 0.011, 0.0],

    ['TB-01:DI-ScrnCtrl-1:AmpEnbl-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:AmpGain-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:AmpCurrLoopGain-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:LowCurrMode-SP', 1, 0.0],
    ['TB-01:DI-ScrnCtrl-1:Mtr.SET', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:Mtr.MRES', 1, 0.0],
    ['TB-01:DI-ScrnCtrl-1:Mtr.SREV', 51200, 0.0],
    ['TB-01:DI-ScrnCtrl-1:Mtr.VMAX', 1.4, 0.0],
    ['TB-01:DI-ScrnCtrl-1:Mtr.VELO', 1.3, 0.0],
    ['TB-01:DI-ScrnCtrl-1:Mtr.ACCL', 2, 0.0],
    ['TB-01:DI-ScrnCtrl-1:Mtr.HLM', 100, 0.0],
    ['TB-01:DI-ScrnCtrl-1:Mtr.LLM', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:Mtr.DIR', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:Mtr.OFF', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:Mtr.BDST', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:Mtr.BVEL', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:Mtr.BACC', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:Mtr.EGU', 'mm', 0.0],
    ['TB-01:DI-ScrnCtrl-1:Mtr.NTM', 1, 0.0],
    ['TB-01:DI-ScrnCtrl-1:Mtr.RTRY', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:Mtr.RDBD', 1, 0.0],
    ['TB-01:DI-ScrnCtrl-1:Mtr.RMOD', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:MtrType-Sel', 2, 0.0],
    ['TB-01:DI-ScrnCtrl-1:LimSwType-Sel', 1, 0.0],
    ['TB-01:DI-ScrnCtrl-1:MainEncType-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:Mtr.ERES', 1, 0.0],
    ['TB-01:DI-ScrnCtrl-1:EstallTime-SP', 0.2, 0.0],
    ['TB-01:DI-ScrnCtrl-1:PollPeriod-SP', 1, 0.0],
    ['TB-01:DI-ScrnCtrl-1:Mtr.UEIP', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:RefHomePos-SP', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:RstPosAfterHome-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:JogAfterHome-SP', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:HomeEnblDir-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:Mtr.HVEL', 1.4, 0.0],
    ['TB-01:DI-ScrnCtrl-1:DigOut0-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:DigOut1-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:DigOut2-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:DigOut3-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:AnalogOut0DeadBand-SP', 0.002, 0.0],
    ['TB-01:DI-ScrnCtrl-1:AnalogOut1DeadBand-SP', 0.002, 0.0],
    ['TB-01:DI-ScrnCtrl-1:BiSSIn-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:BiSSLvl-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:BiSSPoll-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:BiSSClkDiv-SP', 9, 0.0],
    ['TB-01:DI-ScrnCtrl-1:BiSSNumBits1-SP', 33, 0.0],
    ['TB-01:DI-ScrnCtrl-1:BiSSNumBits2-SP', 33, 0.0],
    ['TB-01:DI-ScrnCtrl-1:BiSSNumZeroPad-SP', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:LimSwDsbl-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:LimProtectEnbl-Sel', 1, 0.0],
    ['TB-01:DI-ScrnCtrl-1:AuxEncType-Sel', 1, 0.0],
    ['TB-01:DI-ScrnCtrl-1:ErrLimType-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:PosErrLim-SP', 16384, 0.0],
    ['TB-01:DI-ScrnCtrl-1:StopDelay-SP', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-1:UseIdx-Sel', 1, 0.0],
    ['TB-01:DI-ScrnCtrl-1:UseSw-Sel', 1, 0.0],
    ['TB-01:DI-ScrnCtrl-2:AmpEnbl-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:AmpGain-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:AmpCurrLoopGain-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:LowCurrMode-SP', 1, 0.0],
    ['TB-01:DI-ScrnCtrl-2:Mtr.SET', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:Mtr.MRES', 1, 0.0],
    ['TB-01:DI-ScrnCtrl-2:Mtr.SREV', 51200, 0.0],
    ['TB-01:DI-ScrnCtrl-2:Mtr.VMAX', 1.4, 0.0],
    ['TB-01:DI-ScrnCtrl-2:Mtr.VELO', 1.3, 0.0],
    ['TB-01:DI-ScrnCtrl-2:Mtr.ACCL', 2, 0.0],
    ['TB-01:DI-ScrnCtrl-2:Mtr.HLM', 100, 0.0],
    ['TB-01:DI-ScrnCtrl-2:Mtr.LLM', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:Mtr.DIR', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:Mtr.OFF', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:Mtr.BDST', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:Mtr.BVEL', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:Mtr.BACC', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:Mtr.EGU', 'mm', 0.0],
    ['TB-01:DI-ScrnCtrl-2:Mtr.NTM', 1, 0.0],
    ['TB-01:DI-ScrnCtrl-2:Mtr.RTRY', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:Mtr.RDBD', 1, 0.0],
    ['TB-01:DI-ScrnCtrl-2:Mtr.RMOD', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:MtrType-Sel', 2, 0.0],
    ['TB-01:DI-ScrnCtrl-2:LimSwType-Sel', 1, 0.0],
    ['TB-01:DI-ScrnCtrl-2:MainEncType-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:Mtr.ERES', 1, 0.0],
    ['TB-01:DI-ScrnCtrl-2:EstallTime-SP', 0.2, 0.0],
    ['TB-01:DI-ScrnCtrl-2:PollPeriod-SP', 1, 0.0],
    ['TB-01:DI-ScrnCtrl-2:Mtr.UEIP', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:RefHomePos-SP', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:RstPosAfterHome-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:JogAfterHome-SP', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:HomeEnblDir-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:Mtr.HVEL', 1.4, 0.0],
    ['TB-01:DI-ScrnCtrl-2:DigOut0-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:DigOut1-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:DigOut2-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:DigOut3-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:AnalogOut0DeadBand-SP', 0.002, 0.0],
    ['TB-01:DI-ScrnCtrl-2:AnalogOut1DeadBand-SP', 0.002, 0.0],
    ['TB-01:DI-ScrnCtrl-2:BiSSIn-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:BiSSLvl-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:BiSSPoll-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:BiSSClkDiv-SP', 9, 0.0],
    ['TB-01:DI-ScrnCtrl-2:BiSSNumBits1-SP', 33, 0.0],
    ['TB-01:DI-ScrnCtrl-2:BiSSNumBits2-SP', 33, 0.0],
    ['TB-01:DI-ScrnCtrl-2:BiSSNumZeroPad-SP', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:LimSwDsbl-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:LimProtectEnbl-Sel', 1, 0.0],
    ['TB-01:DI-ScrnCtrl-2:AuxEncType-Sel', 1, 0.0],
    ['TB-01:DI-ScrnCtrl-2:ErrLimType-Sel', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:PosErrLim-SP', 16384, 0.0],
    ['TB-01:DI-ScrnCtrl-2:StopDelay-SP', 0, 0.0],
    ['TB-01:DI-ScrnCtrl-2:UseIdx-Sel', 1, 0.0],
    ['TB-01:DI-ScrnCtrl-2:UseSw-Sel', 1, 0.0],
    ['TB-02:DI-ScrnCtrl-1:AmpEnbl-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:AmpGain-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:AmpCurrLoopGain-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:LowCurrMode-SP', 1, 0.0],
    ['TB-02:DI-ScrnCtrl-1:Mtr.SET', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:Mtr.MRES', 1, 0.0],
    ['TB-02:DI-ScrnCtrl-1:Mtr.SREV', 51200, 0.0],
    ['TB-02:DI-ScrnCtrl-1:Mtr.VMAX', 1.4, 0.0],
    ['TB-02:DI-ScrnCtrl-1:Mtr.VELO', 1.3, 0.0],
    ['TB-02:DI-ScrnCtrl-1:Mtr.ACCL', 2, 0.0],
    ['TB-02:DI-ScrnCtrl-1:Mtr.HLM', 100, 0.0],
    ['TB-02:DI-ScrnCtrl-1:Mtr.LLM', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:Mtr.DIR', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:Mtr.OFF', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:Mtr.BDST', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:Mtr.BVEL', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:Mtr.BACC', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:Mtr.EGU', 'mm', 0.0],
    ['TB-02:DI-ScrnCtrl-1:Mtr.NTM', 1, 0.0],
    ['TB-02:DI-ScrnCtrl-1:Mtr.RTRY', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:Mtr.RDBD', 1, 0.0],
    ['TB-02:DI-ScrnCtrl-1:Mtr.RMOD', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:MtrType-Sel', 2, 0.0],
    ['TB-02:DI-ScrnCtrl-1:LimSwType-Sel', 1, 0.0],
    ['TB-02:DI-ScrnCtrl-1:MainEncType-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:Mtr.ERES', 1, 0.0],
    ['TB-02:DI-ScrnCtrl-1:EstallTime-SP', 0.2, 0.0],
    ['TB-02:DI-ScrnCtrl-1:PollPeriod-SP', 1, 0.0],
    ['TB-02:DI-ScrnCtrl-1:Mtr.UEIP', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:RefHomePos-SP', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:RstPosAfterHome-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:JogAfterHome-SP', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:HomeEnblDir-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:Mtr.HVEL', 1.4, 0.0],
    ['TB-02:DI-ScrnCtrl-1:DigOut0-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:DigOut1-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:DigOut2-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:DigOut3-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:AnalogOut0DeadBand-SP', 0.002, 0.0],
    ['TB-02:DI-ScrnCtrl-1:AnalogOut1DeadBand-SP', 0.002, 0.0],
    ['TB-02:DI-ScrnCtrl-1:BiSSIn-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:BiSSLvl-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:BiSSPoll-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:BiSSClkDiv-SP', 9, 0.0],
    ['TB-02:DI-ScrnCtrl-1:BiSSNumBits1-SP', 33, 0.0],
    ['TB-02:DI-ScrnCtrl-1:BiSSNumBits2-SP', 33, 0.0],
    ['TB-02:DI-ScrnCtrl-1:BiSSNumZeroPad-SP', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:LimSwDsbl-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:LimProtectEnbl-Sel', 1, 0.0],
    ['TB-02:DI-ScrnCtrl-1:AuxEncType-Sel', 1, 0.0],
    ['TB-02:DI-ScrnCtrl-1:ErrLimType-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:PosErrLim-SP', 16384, 0.0],
    ['TB-02:DI-ScrnCtrl-1:StopDelay-SP', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-1:UseIdx-Sel', 1, 0.0],
    ['TB-02:DI-ScrnCtrl-1:UseSw-Sel', 1, 0.0],
    ['TB-02:DI-ScrnCtrl-2:AmpEnbl-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:AmpGain-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:AmpCurrLoopGain-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:LowCurrMode-SP', 1, 0.0],
    ['TB-02:DI-ScrnCtrl-2:Mtr.SET', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:Mtr.MRES', 1, 0.0],
    ['TB-02:DI-ScrnCtrl-2:Mtr.SREV', 51200, 0.0],
    ['TB-02:DI-ScrnCtrl-2:Mtr.VMAX', 1.4, 0.0],
    ['TB-02:DI-ScrnCtrl-2:Mtr.VELO', 1.3, 0.0],
    ['TB-02:DI-ScrnCtrl-2:Mtr.ACCL', 2, 0.0],
    ['TB-02:DI-ScrnCtrl-2:Mtr.HLM', 100, 0.0],
    ['TB-02:DI-ScrnCtrl-2:Mtr.LLM', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:Mtr.DIR', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:Mtr.OFF', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:Mtr.BDST', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:Mtr.BVEL', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:Mtr.BACC', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:Mtr.EGU', 'mm', 0.0],
    ['TB-02:DI-ScrnCtrl-2:Mtr.NTM', 1, 0.0],
    ['TB-02:DI-ScrnCtrl-2:Mtr.RTRY', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:Mtr.RDBD', 1, 0.0],
    ['TB-02:DI-ScrnCtrl-2:Mtr.RMOD', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:MtrType-Sel', 2, 0.0],
    ['TB-02:DI-ScrnCtrl-2:LimSwType-Sel', 1, 0.0],
    ['TB-02:DI-ScrnCtrl-2:MainEncType-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:Mtr.ERES', 1, 0.0],
    ['TB-02:DI-ScrnCtrl-2:EstallTime-SP', 0.2, 0.0],
    ['TB-02:DI-ScrnCtrl-2:PollPeriod-SP', 1, 0.0],
    ['TB-02:DI-ScrnCtrl-2:Mtr.UEIP', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:RefHomePos-SP', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:RstPosAfterHome-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:JogAfterHome-SP', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:HomeEnblDir-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:Mtr.HVEL', 1.4, 0.0],
    ['TB-02:DI-ScrnCtrl-2:DigOut0-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:DigOut1-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:DigOut2-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:DigOut3-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:AnalogOut0DeadBand-SP', 0.002, 0.0],
    ['TB-02:DI-ScrnCtrl-2:AnalogOut1DeadBand-SP', 0.002, 0.0],
    ['TB-02:DI-ScrnCtrl-2:BiSSIn-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:BiSSLvl-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:BiSSPoll-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:BiSSClkDiv-SP', 9, 0.0],
    ['TB-02:DI-ScrnCtrl-2:BiSSNumBits1-SP', 33, 0.0],
    ['TB-02:DI-ScrnCtrl-2:BiSSNumBits2-SP', 33, 0.0],
    ['TB-02:DI-ScrnCtrl-2:BiSSNumZeroPad-SP', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:LimSwDsbl-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:LimProtectEnbl-Sel', 1, 0.0],
    ['TB-02:DI-ScrnCtrl-2:AuxEncType-Sel', 1, 0.0],
    ['TB-02:DI-ScrnCtrl-2:ErrLimType-Sel', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:PosErrLim-SP', 16384, 0.0],
    ['TB-02:DI-ScrnCtrl-2:StopDelay-SP', 0, 0.0],
    ['TB-02:DI-ScrnCtrl-2:UseIdx-Sel', 1, 0.0],
    ['TB-02:DI-ScrnCtrl-2:UseSw-Sel', 1, 0.0],
    ['TB-03:DI-ScrnCtrl:AmpEnbl-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:AmpGain-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:AmpCurrLoopGain-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:LowCurrMode-SP', 1, 0.0],
    ['TB-03:DI-ScrnCtrl:Mtr.SET', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:Mtr.MRES', 1, 0.0],
    ['TB-03:DI-ScrnCtrl:Mtr.SREV', 51200, 0.0],
    ['TB-03:DI-ScrnCtrl:Mtr.VMAX', 1.4, 0.0],
    ['TB-03:DI-ScrnCtrl:Mtr.VELO', 1.3, 0.0],
    ['TB-03:DI-ScrnCtrl:Mtr.ACCL', 2, 0.0],
    ['TB-03:DI-ScrnCtrl:Mtr.HLM', 100, 0.0],
    ['TB-03:DI-ScrnCtrl:Mtr.LLM', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:Mtr.DIR', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:Mtr.OFF', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:Mtr.BDST', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:Mtr.BVEL', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:Mtr.BACC', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:Mtr.EGU', 'mm', 0.0],
    ['TB-03:DI-ScrnCtrl:Mtr.NTM', 1, 0.0],
    ['TB-03:DI-ScrnCtrl:Mtr.RTRY', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:Mtr.RDBD', 1, 0.0],
    ['TB-03:DI-ScrnCtrl:Mtr.RMOD', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:MtrType-Sel', 2, 0.0],
    ['TB-03:DI-ScrnCtrl:LimSwType-Sel', 1, 0.0],
    ['TB-03:DI-ScrnCtrl:MainEncType-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:Mtr.ERES', 1, 0.0],
    ['TB-03:DI-ScrnCtrl:EstallTime-SP', 0.2, 0.0],
    ['TB-03:DI-ScrnCtrl:PollPeriod-SP', 1, 0.0],
    ['TB-03:DI-ScrnCtrl:Mtr.UEIP', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:RefHomePos-SP', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:RstPosAfterHome-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:JogAfterHome-SP', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:HomeEnblDir-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:Mtr.HVEL', 1.4, 0.0],
    ['TB-03:DI-ScrnCtrl:DigOut0-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:DigOut1-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:DigOut2-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:DigOut3-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:AnalogOut0DeadBand-SP', 0.002, 0.0],
    ['TB-03:DI-ScrnCtrl:AnalogOut1DeadBand-SP', 0.002, 0.0],
    ['TB-03:DI-ScrnCtrl:BiSSIn-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:BiSSLvl-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:BiSSPoll-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:BiSSClkDiv-SP', 9, 0.0],
    ['TB-03:DI-ScrnCtrl:BiSSNumBits1-SP', 33, 0.0],
    ['TB-03:DI-ScrnCtrl:BiSSNumBits2-SP', 33, 0.0],
    ['TB-03:DI-ScrnCtrl:BiSSNumZeroPad-SP', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:LimSwDsbl-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:LimProtectEnbl-Sel', 1, 0.0],
    ['TB-03:DI-ScrnCtrl:AuxEncType-Sel', 1, 0.0],
    ['TB-03:DI-ScrnCtrl:ErrLimType-Sel', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:PosErrLim-SP', 16384, 0.0],
    ['TB-03:DI-ScrnCtrl:StopDelay-SP', 0, 0.0],
    ['TB-03:DI-ScrnCtrl:UseIdx-Sel', 1, 0.0],
    ['TB-03:DI-ScrnCtrl:UseSw-Sel', 1, 0.0],
    ['TB-04:DI-ScrnCtrl:AmpEnbl-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:AmpGain-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:AmpCurrLoopGain-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:LowCurrMode-SP', 1, 0.0],
    ['TB-04:DI-ScrnCtrl:Mtr.SET', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:Mtr.MRES', 1, 0.0],
    ['TB-04:DI-ScrnCtrl:Mtr.SREV', 51200, 0.0],
    ['TB-04:DI-ScrnCtrl:Mtr.VMAX', 1.4, 0.0],
    ['TB-04:DI-ScrnCtrl:Mtr.VELO', 1.3, 0.0],
    ['TB-04:DI-ScrnCtrl:Mtr.ACCL', 2, 0.0],
    ['TB-04:DI-ScrnCtrl:Mtr.HLM', 100, 0.0],
    ['TB-04:DI-ScrnCtrl:Mtr.LLM', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:Mtr.DIR', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:Mtr.OFF', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:Mtr.BDST', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:Mtr.BVEL', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:Mtr.BACC', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:Mtr.EGU', 'mm', 0.0],
    ['TB-04:DI-ScrnCtrl:Mtr.NTM', 1, 0.0],
    ['TB-04:DI-ScrnCtrl:Mtr.RTRY', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:Mtr.RDBD', 1, 0.0],
    ['TB-04:DI-ScrnCtrl:Mtr.RMOD', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:MtrType-Sel', 2, 0.0],
    ['TB-04:DI-ScrnCtrl:LimSwType-Sel', 1, 0.0],
    ['TB-04:DI-ScrnCtrl:MainEncType-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:Mtr.ERES', 1, 0.0],
    ['TB-04:DI-ScrnCtrl:EstallTime-SP', 0.2, 0.0],
    ['TB-04:DI-ScrnCtrl:PollPeriod-SP', 1, 0.0],
    ['TB-04:DI-ScrnCtrl:Mtr.UEIP', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:RefHomePos-SP', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:RstPosAfterHome-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:JogAfterHome-SP', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:HomeEnblDir-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:Mtr.HVEL', 1.4, 0.0],
    ['TB-04:DI-ScrnCtrl:DigOut0-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:DigOut1-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:DigOut2-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:DigOut3-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:AnalogOut0DeadBand-SP', 0.002, 0.0],
    ['TB-04:DI-ScrnCtrl:AnalogOut1DeadBand-SP', 0.002, 0.0],
    ['TB-04:DI-ScrnCtrl:BiSSIn-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:BiSSLvl-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:BiSSPoll-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:BiSSClkDiv-SP', 9, 0.0],
    ['TB-04:DI-ScrnCtrl:BiSSNumBits1-SP', 33, 0.0],
    ['TB-04:DI-ScrnCtrl:BiSSNumBits2-SP', 33, 0.0],
    ['TB-04:DI-ScrnCtrl:BiSSNumZeroPad-SP', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:LimSwDsbl-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:LimProtectEnbl-Sel', 1, 0.0],
    ['TB-04:DI-ScrnCtrl:AuxEncType-Sel', 1, 0.0],
    ['TB-04:DI-ScrnCtrl:ErrLimType-Sel', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:PosErrLim-SP', 16384, 0.0],
    ['TB-04:DI-ScrnCtrl:StopDelay-SP', 0, 0.0],
    ['TB-04:DI-ScrnCtrl:UseIdx-Sel', 1, 0.0],
    ['TB-04:DI-ScrnCtrl:UseSw-Sel', 1, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:AmpEnbl-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:AmpGain-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:AmpCurrLoopGain-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:LowCurrMode-SP', 1, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:Mtr.SET', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:Mtr.MRES', 1, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:Mtr.SREV', 51200, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:Mtr.VMAX', 1.4, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:Mtr.VELO', 1.3, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:Mtr.ACCL', 2, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:Mtr.HLM', 100, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:Mtr.LLM', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:Mtr.DIR', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:Mtr.OFF', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:Mtr.BDST', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:Mtr.BVEL', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:Mtr.BACC', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:Mtr.EGU', 'mm', 0.0],
    ['BO-01D:DI-ScrnCtrl-1:Mtr.NTM', 1, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:Mtr.RTRY', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:Mtr.RDBD', 1, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:Mtr.RMOD', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:MtrType-Sel', 2, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:LimSwType-Sel', 1, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:MainEncType-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:Mtr.ERES', 1, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:EstallTime-SP', 0.2, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:PollPeriod-SP', 1, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:Mtr.UEIP', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:RefHomePos-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:RstPosAfterHome-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:JogAfterHome-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:HomeEnblDir-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:Mtr.HVEL', 1.4, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:DigOut0-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:DigOut1-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:DigOut2-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:DigOut3-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:AnalogOut0DeadBand-SP', 0.002, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:AnalogOut1DeadBand-SP', 0.002, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:BiSSIn-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:BiSSLvl-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:BiSSPoll-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:BiSSClkDiv-SP', 9, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:BiSSNumBits1-SP', 33, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:BiSSNumBits2-SP', 33, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:BiSSNumZeroPad-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:LimSwDsbl-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:LimProtectEnbl-Sel', 1, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:AuxEncType-Sel', 1, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:ErrLimType-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:PosErrLim-SP', 16384, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:StopDelay-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:UseIdx-Sel', 1, 0.0],
    ['BO-01D:DI-ScrnCtrl-1:UseSw-Sel', 1, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:AmpEnbl-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:AmpGain-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:AmpCurrLoopGain-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:LowCurrMode-SP', 1, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:Mtr.SET', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:Mtr.MRES', 1, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:Mtr.SREV', 51200, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:Mtr.VMAX', 1.4, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:Mtr.VELO', 1.3, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:Mtr.ACCL', 2, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:Mtr.HLM', 100, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:Mtr.LLM', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:Mtr.DIR', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:Mtr.OFF', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:Mtr.BDST', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:Mtr.BVEL', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:Mtr.BACC', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:Mtr.EGU', 'mm', 0.0],
    ['BO-01D:DI-ScrnCtrl-2:Mtr.NTM', 1, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:Mtr.RTRY', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:Mtr.RDBD', 1, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:Mtr.RMOD', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:MtrType-Sel', 2, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:LimSwType-Sel', 1, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:MainEncType-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:Mtr.ERES', 1, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:EstallTime-SP', 0.2, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:PollPeriod-SP', 1, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:Mtr.UEIP', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:RefHomePos-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:RstPosAfterHome-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:JogAfterHome-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:HomeEnblDir-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:Mtr.HVEL', 1.4, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:DigOut0-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:DigOut1-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:DigOut2-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:DigOut3-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:AnalogOut0DeadBand-SP', 0.002, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:AnalogOut1DeadBand-SP', 0.002, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:BiSSIn-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:BiSSLvl-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:BiSSPoll-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:BiSSClkDiv-SP', 9, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:BiSSNumBits1-SP', 33, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:BiSSNumBits2-SP', 33, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:BiSSNumZeroPad-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:LimSwDsbl-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:LimProtectEnbl-Sel', 1, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:AuxEncType-Sel', 1, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:ErrLimType-Sel', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:PosErrLim-SP', 16384, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:StopDelay-SP', 0, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:UseIdx-Sel', 1, 0.0],
    ['BO-01D:DI-ScrnCtrl-2:UseSw-Sel', 1, 0.0],
    ['BO-02U:DI-ScrnCtrl:AmpEnbl-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:AmpGain-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:AmpCurrLoopGain-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:LowCurrMode-SP', 1, 0.0],
    ['BO-02U:DI-ScrnCtrl:Mtr.SET', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:Mtr.MRES', 1, 0.0],
    ['BO-02U:DI-ScrnCtrl:Mtr.SREV', 51200, 0.0],
    ['BO-02U:DI-ScrnCtrl:Mtr.VMAX', 1.4, 0.0],
    ['BO-02U:DI-ScrnCtrl:Mtr.VELO', 1.3, 0.0],
    ['BO-02U:DI-ScrnCtrl:Mtr.ACCL', 2, 0.0],
    ['BO-02U:DI-ScrnCtrl:Mtr.HLM', 100, 0.0],
    ['BO-02U:DI-ScrnCtrl:Mtr.LLM', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:Mtr.DIR', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:Mtr.OFF', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:Mtr.BDST', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:Mtr.BVEL', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:Mtr.BACC', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:Mtr.EGU', 'mm', 0.0],
    ['BO-02U:DI-ScrnCtrl:Mtr.NTM', 1, 0.0],
    ['BO-02U:DI-ScrnCtrl:Mtr.RTRY', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:Mtr.RDBD', 1, 0.0],
    ['BO-02U:DI-ScrnCtrl:Mtr.RMOD', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:MtrType-Sel', 2, 0.0],
    ['BO-02U:DI-ScrnCtrl:LimSwType-Sel', 1, 0.0],
    ['BO-02U:DI-ScrnCtrl:MainEncType-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:Mtr.ERES', 1, 0.0],
    ['BO-02U:DI-ScrnCtrl:EstallTime-SP', 0.2, 0.0],
    ['BO-02U:DI-ScrnCtrl:PollPeriod-SP', 1, 0.0],
    ['BO-02U:DI-ScrnCtrl:Mtr.UEIP', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:RefHomePos-SP', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:RstPosAfterHome-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:JogAfterHome-SP', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:HomeEnblDir-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:Mtr.HVEL', 1.4, 0.0],
    ['BO-02U:DI-ScrnCtrl:DigOut0-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:DigOut1-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:DigOut2-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:DigOut3-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:AnalogOut0DeadBand-SP', 0.002, 0.0],
    ['BO-02U:DI-ScrnCtrl:AnalogOut1DeadBand-SP', 0.002, 0.0],
    ['BO-02U:DI-ScrnCtrl:BiSSIn-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:BiSSLvl-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:BiSSPoll-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:BiSSClkDiv-SP', 9, 0.0],
    ['BO-02U:DI-ScrnCtrl:BiSSNumBits1-SP', 33, 0.0],
    ['BO-02U:DI-ScrnCtrl:BiSSNumBits2-SP', 33, 0.0],
    ['BO-02U:DI-ScrnCtrl:BiSSNumZeroPad-SP', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:LimSwDsbl-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:LimProtectEnbl-Sel', 1, 0.0],
    ['BO-02U:DI-ScrnCtrl:AuxEncType-Sel', 1, 0.0],
    ['BO-02U:DI-ScrnCtrl:ErrLimType-Sel', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:PosErrLim-SP', 16384, 0.0],
    ['BO-02U:DI-ScrnCtrl:StopDelay-SP', 0, 0.0],
    ['BO-02U:DI-ScrnCtrl:UseIdx-Sel', 1, 0.0],
    ['BO-02U:DI-ScrnCtrl:UseSw-Sel', 1, 0.0],

    ['TS-01:DI-ScrnCam:Enbl-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCam:Gain-SP', 0, 0.0],
    ['TS-01:DI-ScrnCam:AcqMode-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCam:AcqPeriod-SP', 0.4, 0.0],
    ['TS-01:DI-ScrnCam:AcqPeriodLowLim-SP', 0.083, 0.0],
    ['TS-01:DI-ScrnCam:ExposureMode-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCam:ExposureTime-SP', 5000, 0.0],
    ['TS-01:DI-ScrnCam:DataType-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCam:BlackLevel-SP', 0, 0.0],
    ['TS-01:DI-ScrnCam:TransformType-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCam:DebouncerPeriod-SP', 0, 0.0],
    ['TS-01:DI-ScrnCam:BwReserve-SP', 10, 0.0],
    ['TS-01:DI-ScrnCam:BwReserveAccum-SP', 1, 0.0],
    ['TS-01:DI-ScrnCam:TransmDelay-SP', 0, 0.0],
    ['TS-01:DI-ScrnCam:PacketSize-SP', 1500, 0.0],
    ['TS-01:DI-ScrnCam:InterPacketDelay-SP', 1000, 0.0],
    ['TS-01:DI-ScrnCam:SoftROIAutoCenterX-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCam:SoftROIAutoCenterY-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCam:SoftROIHeight-SP', 1024, 0.0],
    ['TS-01:DI-ScrnCam:SoftROIOffsetX-SP', 0, 0.0],
    ['TS-01:DI-ScrnCam:SoftROIOffsetY-SP', 0, 0.0],
    ['TS-01:DI-ScrnCam:SoftROIWidth-SP', 1280, 0.0],
    ['TS-01:DI-ScrnCam:AOIAutoCenterX-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCam:AOIAutoCenterY-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCam:AOIHeight-SP', 1024, 0.0],
    ['TS-01:DI-ScrnCam:AOIOffsetX-SP', 0, 0.0],
    ['TS-01:DI-ScrnCam:AOIOffsetY-SP', 0, 0.0],
    ['TS-01:DI-ScrnCam:AOIWidth-SP', 1280, 0.0],
    ['TS-01:DI-ScrnCam:CalPosCenterX-SP', 0, 0.0],
    ['TS-01:DI-ScrnCam:CalPosCenterY-SP', 0, 0.0],
    ['TS-01:DI-ScrnCam:CenterOffsetX-SP', 0, 0.0],
    ['TS-01:DI-ScrnCam:CenterOffsetY-SP', 0, 0.0],
    ['TS-01:DI-ScrnCam:ThetaOffset-SP', 0, 0.0],
    ['TS-01:DI-ScrnCam:ScaleFactorX-SP', 1, 0.0],
    ['TS-01:DI-ScrnCam:ScaleFactorY-SP', 1, 0.0],
    ['TS-01:DI-ScrnCam:EnblBGSubtraction-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCam:EnblOffsetScale-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCam:PixelOffset-SP', 0, 0.0],
    ['TS-01:DI-ScrnCam:PixelScale-SP', 1, 0.0],
    ['TS-01:DI-ScrnCam:HighClip-SP', 65535, 0.0],
    ['TS-01:DI-ScrnCam:LowClip-SP', 0, 0.0],
    ['TS-01:DI-ScrnCam:EnblHighClip-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCam:EnblLowClip-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCam:DimFeiMarkEnbl-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCam:NDStatsMarkEnbl-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCam:CalCenterMarkEnbl-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCam:RealCenterMarkEnbl-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCam:EnblMJPEG-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCam:ColorConv-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCam:FastAcq-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCam:DimFeiMarkColor-SP', 255, 0.0],
    ['TS-01:DI-ScrnCam:DimFeiMarkSize-SP', 10, 0.0],
    ['TS-01:DI-ScrnCam:NDStatsMarkColor-SP', 255, 0.0],
    ['TS-01:DI-ScrnCam:NDStatsMarkSize-SP', 10, 0.0],
    ['TS-01:DI-ScrnCam:CalCenterMarkColor-SP', 255, 0.0],
    ['TS-01:DI-ScrnCam:CalCenterMarkSize-SP', 10, 0.0],
    ['TS-01:DI-ScrnCam:RealCenterMarkColor-SP', 255, 0.0],
    ['TS-01:DI-ScrnCam:RealCenterMarkSize-SP', 10, 0.0],
    ['TS-02:DI-ScrnCam:Enbl-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCam:Gain-SP', 0, 0.0],
    ['TS-02:DI-ScrnCam:AcqMode-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCam:AcqPeriod-SP', 0.4, 0.0],
    ['TS-02:DI-ScrnCam:AcqPeriodLowLim-SP', 0.083, 0.0],
    ['TS-02:DI-ScrnCam:ExposureMode-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCam:ExposureTime-SP', 5000, 0.0],
    ['TS-02:DI-ScrnCam:DataType-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCam:BlackLevel-SP', 0, 0.0],
    ['TS-02:DI-ScrnCam:TransformType-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCam:DebouncerPeriod-SP', 0, 0.0],
    ['TS-02:DI-ScrnCam:BwReserve-SP', 10, 0.0],
    ['TS-02:DI-ScrnCam:BwReserveAccum-SP', 1, 0.0],
    ['TS-02:DI-ScrnCam:TransmDelay-SP', 0, 0.0],
    ['TS-02:DI-ScrnCam:PacketSize-SP', 1500, 0.0],
    ['TS-02:DI-ScrnCam:InterPacketDelay-SP', 1000, 0.0],
    ['TS-02:DI-ScrnCam:SoftROIAutoCenterX-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCam:SoftROIAutoCenterY-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCam:SoftROIHeight-SP', 1024, 0.0],
    ['TS-02:DI-ScrnCam:SoftROIOffsetX-SP', 0, 0.0],
    ['TS-02:DI-ScrnCam:SoftROIOffsetY-SP', 0, 0.0],
    ['TS-02:DI-ScrnCam:SoftROIWidth-SP', 1280, 0.0],
    ['TS-02:DI-ScrnCam:AOIAutoCenterX-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCam:AOIAutoCenterY-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCam:AOIHeight-SP', 1024, 0.0],
    ['TS-02:DI-ScrnCam:AOIOffsetX-SP', 0, 0.0],
    ['TS-02:DI-ScrnCam:AOIOffsetY-SP', 0, 0.0],
    ['TS-02:DI-ScrnCam:AOIWidth-SP', 1280, 0.0],
    ['TS-02:DI-ScrnCam:CalPosCenterX-SP', 0, 0.0],
    ['TS-02:DI-ScrnCam:CalPosCenterY-SP', 0, 0.0],
    ['TS-02:DI-ScrnCam:CenterOffsetX-SP', 0, 0.0],
    ['TS-02:DI-ScrnCam:CenterOffsetY-SP', 0, 0.0],
    ['TS-02:DI-ScrnCam:ThetaOffset-SP', 0, 0.0],
    ['TS-02:DI-ScrnCam:ScaleFactorX-SP', 1, 0.0],
    ['TS-02:DI-ScrnCam:ScaleFactorY-SP', 1, 0.0],
    ['TS-02:DI-ScrnCam:EnblBGSubtraction-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCam:EnblOffsetScale-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCam:PixelOffset-SP', 0, 0.0],
    ['TS-02:DI-ScrnCam:PixelScale-SP', 1, 0.0],
    ['TS-02:DI-ScrnCam:HighClip-SP', 65535, 0.0],
    ['TS-02:DI-ScrnCam:LowClip-SP', 0, 0.0],
    ['TS-02:DI-ScrnCam:EnblHighClip-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCam:EnblLowClip-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCam:DimFeiMarkEnbl-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCam:NDStatsMarkEnbl-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCam:CalCenterMarkEnbl-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCam:RealCenterMarkEnbl-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCam:EnblMJPEG-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCam:ColorConv-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCam:FastAcq-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCam:DimFeiMarkColor-SP', 255, 0.0],
    ['TS-02:DI-ScrnCam:DimFeiMarkSize-SP', 10, 0.0],
    ['TS-02:DI-ScrnCam:NDStatsMarkColor-SP', 255, 0.0],
    ['TS-02:DI-ScrnCam:NDStatsMarkSize-SP', 10, 0.0],
    ['TS-02:DI-ScrnCam:CalCenterMarkColor-SP', 255, 0.0],
    ['TS-02:DI-ScrnCam:CalCenterMarkSize-SP', 10, 0.0],
    ['TS-02:DI-ScrnCam:RealCenterMarkColor-SP', 255, 0.0],
    ['TS-02:DI-ScrnCam:RealCenterMarkSize-SP', 10, 0.0],
    ['TS-03:DI-ScrnCam:Enbl-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCam:Gain-SP', 0, 0.0],
    ['TS-03:DI-ScrnCam:AcqMode-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCam:AcqPeriod-SP', 0.4, 0.0],
    ['TS-03:DI-ScrnCam:AcqPeriodLowLim-SP', 0.083, 0.0],
    ['TS-03:DI-ScrnCam:ExposureMode-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCam:ExposureTime-SP', 5000, 0.0],
    ['TS-03:DI-ScrnCam:DataType-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCam:BlackLevel-SP', 0, 0.0],
    ['TS-03:DI-ScrnCam:TransformType-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCam:DebouncerPeriod-SP', 0, 0.0],
    ['TS-03:DI-ScrnCam:BwReserve-SP', 10, 0.0],
    ['TS-03:DI-ScrnCam:BwReserveAccum-SP', 1, 0.0],
    ['TS-03:DI-ScrnCam:TransmDelay-SP', 0, 0.0],
    ['TS-03:DI-ScrnCam:PacketSize-SP', 1500, 0.0],
    ['TS-03:DI-ScrnCam:InterPacketDelay-SP', 1000, 0.0],
    ['TS-03:DI-ScrnCam:SoftROIAutoCenterX-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCam:SoftROIAutoCenterY-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCam:SoftROIHeight-SP', 1024, 0.0],
    ['TS-03:DI-ScrnCam:SoftROIOffsetX-SP', 0, 0.0],
    ['TS-03:DI-ScrnCam:SoftROIOffsetY-SP', 0, 0.0],
    ['TS-03:DI-ScrnCam:SoftROIWidth-SP', 1280, 0.0],
    ['TS-03:DI-ScrnCam:AOIAutoCenterX-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCam:AOIAutoCenterY-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCam:AOIHeight-SP', 1024, 0.0],
    ['TS-03:DI-ScrnCam:AOIOffsetX-SP', 0, 0.0],
    ['TS-03:DI-ScrnCam:AOIOffsetY-SP', 0, 0.0],
    ['TS-03:DI-ScrnCam:AOIWidth-SP', 1280, 0.0],
    ['TS-03:DI-ScrnCam:CalPosCenterX-SP', 0, 0.0],
    ['TS-03:DI-ScrnCam:CalPosCenterY-SP', 0, 0.0],
    ['TS-03:DI-ScrnCam:CenterOffsetX-SP', 0, 0.0],
    ['TS-03:DI-ScrnCam:CenterOffsetY-SP', 0, 0.0],
    ['TS-03:DI-ScrnCam:ThetaOffset-SP', 0, 0.0],
    ['TS-03:DI-ScrnCam:ScaleFactorX-SP', 1, 0.0],
    ['TS-03:DI-ScrnCam:ScaleFactorY-SP', 1, 0.0],
    ['TS-03:DI-ScrnCam:EnblBGSubtraction-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCam:EnblOffsetScale-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCam:PixelOffset-SP', 0, 0.0],
    ['TS-03:DI-ScrnCam:PixelScale-SP', 1, 0.0],
    ['TS-03:DI-ScrnCam:HighClip-SP', 65535, 0.0],
    ['TS-03:DI-ScrnCam:LowClip-SP', 0, 0.0],
    ['TS-03:DI-ScrnCam:EnblHighClip-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCam:EnblLowClip-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCam:DimFeiMarkEnbl-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCam:NDStatsMarkEnbl-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCam:CalCenterMarkEnbl-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCam:RealCenterMarkEnbl-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCam:EnblMJPEG-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCam:ColorConv-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCam:FastAcq-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCam:DimFeiMarkColor-SP', 255, 0.0],
    ['TS-03:DI-ScrnCam:DimFeiMarkSize-SP', 10, 0.0],
    ['TS-03:DI-ScrnCam:NDStatsMarkColor-SP', 255, 0.0],
    ['TS-03:DI-ScrnCam:NDStatsMarkSize-SP', 10, 0.0],
    ['TS-03:DI-ScrnCam:CalCenterMarkColor-SP', 255, 0.0],
    ['TS-03:DI-ScrnCam:CalCenterMarkSize-SP', 10, 0.0],
    ['TS-03:DI-ScrnCam:RealCenterMarkColor-SP', 255, 0.0],
    ['TS-03:DI-ScrnCam:RealCenterMarkSize-SP', 10, 0.0],
    ['TS-04:DI-ScrnCam-1:Enbl-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:Gain-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:AcqMode-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:AcqPeriod-SP', 0.4, 0.0],
    ['TS-04:DI-ScrnCam-1:AcqPeriodLowLim-SP', 0.083, 0.0],
    ['TS-04:DI-ScrnCam-1:ExposureMode-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:ExposureTime-SP', 5000, 0.0],
    ['TS-04:DI-ScrnCam-1:DataType-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:BlackLevel-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:TransformType-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:DebouncerPeriod-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:BwReserve-SP', 10, 0.0],
    ['TS-04:DI-ScrnCam-1:BwReserveAccum-SP', 1, 0.0],
    ['TS-04:DI-ScrnCam-1:TransmDelay-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:PacketSize-SP', 1500, 0.0],
    ['TS-04:DI-ScrnCam-1:InterPacketDelay-SP', 1000, 0.0],
    ['TS-04:DI-ScrnCam-1:SoftROIAutoCenterX-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:SoftROIAutoCenterY-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:SoftROIHeight-SP', 1024, 0.0],
    ['TS-04:DI-ScrnCam-1:SoftROIOffsetX-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:SoftROIOffsetY-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:SoftROIWidth-SP', 1280, 0.0],
    ['TS-04:DI-ScrnCam-1:AOIAutoCenterX-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:AOIAutoCenterY-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:AOIHeight-SP', 1024, 0.0],
    ['TS-04:DI-ScrnCam-1:AOIOffsetX-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:AOIOffsetY-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:AOIWidth-SP', 1280, 0.0],
    ['TS-04:DI-ScrnCam-1:CalPosCenterX-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:CalPosCenterY-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:CenterOffsetX-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:CenterOffsetY-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:ThetaOffset-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:ScaleFactorX-SP', 1, 0.0],
    ['TS-04:DI-ScrnCam-1:ScaleFactorY-SP', 1, 0.0],
    ['TS-04:DI-ScrnCam-1:EnblBGSubtraction-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:EnblOffsetScale-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:PixelOffset-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:PixelScale-SP', 1, 0.0],
    ['TS-04:DI-ScrnCam-1:HighClip-SP', 65535, 0.0],
    ['TS-04:DI-ScrnCam-1:LowClip-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:EnblHighClip-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:EnblLowClip-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:DimFeiMarkEnbl-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:NDStatsMarkEnbl-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:CalCenterMarkEnbl-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:RealCenterMarkEnbl-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:EnblMJPEG-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:ColorConv-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:FastAcq-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-1:DimFeiMarkColor-SP', 255, 0.0],
    ['TS-04:DI-ScrnCam-1:DimFeiMarkSize-SP', 10, 0.0],
    ['TS-04:DI-ScrnCam-1:NDStatsMarkColor-SP', 255, 0.0],
    ['TS-04:DI-ScrnCam-1:NDStatsMarkSize-SP', 10, 0.0],
    ['TS-04:DI-ScrnCam-1:CalCenterMarkColor-SP', 255, 0.0],
    ['TS-04:DI-ScrnCam-1:CalCenterMarkSize-SP', 10, 0.0],
    ['TS-04:DI-ScrnCam-1:RealCenterMarkColor-SP', 255, 0.0],
    ['TS-04:DI-ScrnCam-1:RealCenterMarkSize-SP', 10, 0.0],
    ['TS-04:DI-ScrnCam-2:Enbl-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:Gain-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:AcqMode-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:AcqPeriod-SP', 0.4, 0.0],
    ['TS-04:DI-ScrnCam-2:AcqPeriodLowLim-SP', 0.083, 0.0],
    ['TS-04:DI-ScrnCam-2:ExposureMode-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:ExposureTime-SP', 5000, 0.0],
    ['TS-04:DI-ScrnCam-2:DataType-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:BlackLevel-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:TransformType-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:DebouncerPeriod-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:BwReserve-SP', 10, 0.0],
    ['TS-04:DI-ScrnCam-2:BwReserveAccum-SP', 1, 0.0],
    ['TS-04:DI-ScrnCam-2:TransmDelay-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:PacketSize-SP', 1500, 0.0],
    ['TS-04:DI-ScrnCam-2:InterPacketDelay-SP', 1000, 0.0],
    ['TS-04:DI-ScrnCam-2:SoftROIAutoCenterX-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:SoftROIAutoCenterY-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:SoftROIHeight-SP', 1024, 0.0],
    ['TS-04:DI-ScrnCam-2:SoftROIOffsetX-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:SoftROIOffsetY-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:SoftROIWidth-SP', 1280, 0.0],
    ['TS-04:DI-ScrnCam-2:AOIAutoCenterX-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:AOIAutoCenterY-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:AOIHeight-SP', 1024, 0.0],
    ['TS-04:DI-ScrnCam-2:AOIOffsetX-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:AOIOffsetY-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:AOIWidth-SP', 1280, 0.0],
    ['TS-04:DI-ScrnCam-2:CalPosCenterX-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:CalPosCenterY-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:CenterOffsetX-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:CenterOffsetY-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:ThetaOffset-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:ScaleFactorX-SP', 1, 0.0],
    ['TS-04:DI-ScrnCam-2:ScaleFactorY-SP', 1, 0.0],
    ['TS-04:DI-ScrnCam-2:EnblBGSubtraction-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:EnblOffsetScale-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:PixelOffset-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:PixelScale-SP', 1, 0.0],
    ['TS-04:DI-ScrnCam-2:HighClip-SP', 65535, 0.0],
    ['TS-04:DI-ScrnCam-2:LowClip-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:EnblHighClip-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:EnblLowClip-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:DimFeiMarkEnbl-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:NDStatsMarkEnbl-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:CalCenterMarkEnbl-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:RealCenterMarkEnbl-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:EnblMJPEG-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:ColorConv-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:FastAcq-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-2:DimFeiMarkColor-SP', 255, 0.0],
    ['TS-04:DI-ScrnCam-2:DimFeiMarkSize-SP', 10, 0.0],
    ['TS-04:DI-ScrnCam-2:NDStatsMarkColor-SP', 255, 0.0],
    ['TS-04:DI-ScrnCam-2:NDStatsMarkSize-SP', 10, 0.0],
    ['TS-04:DI-ScrnCam-2:CalCenterMarkColor-SP', 255, 0.0],
    ['TS-04:DI-ScrnCam-2:CalCenterMarkSize-SP', 10, 0.0],
    ['TS-04:DI-ScrnCam-2:RealCenterMarkColor-SP', 255, 0.0],
    ['TS-04:DI-ScrnCam-2:RealCenterMarkSize-SP', 10, 0.0],
    ['TS-04:DI-ScrnCam-3:Enbl-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:Gain-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:AcqMode-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:AcqPeriod-SP', 0.4, 0.0],
    ['TS-04:DI-ScrnCam-3:AcqPeriodLowLim-SP', 0.083, 0.0],
    ['TS-04:DI-ScrnCam-3:ExposureMode-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:ExposureTime-SP', 5000, 0.0],
    ['TS-04:DI-ScrnCam-3:DataType-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:BlackLevel-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:TransformType-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:DebouncerPeriod-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:BwReserve-SP', 10, 0.0],
    ['TS-04:DI-ScrnCam-3:BwReserveAccum-SP', 1, 0.0],
    ['TS-04:DI-ScrnCam-3:TransmDelay-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:PacketSize-SP', 1500, 0.0],
    ['TS-04:DI-ScrnCam-3:InterPacketDelay-SP', 1000, 0.0],
    ['TS-04:DI-ScrnCam-3:SoftROIAutoCenterX-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:SoftROIAutoCenterY-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:SoftROIHeight-SP', 1024, 0.0],
    ['TS-04:DI-ScrnCam-3:SoftROIOffsetX-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:SoftROIOffsetY-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:SoftROIWidth-SP', 1280, 0.0],
    ['TS-04:DI-ScrnCam-3:AOIAutoCenterX-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:AOIAutoCenterY-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:AOIHeight-SP', 1024, 0.0],
    ['TS-04:DI-ScrnCam-3:AOIOffsetX-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:AOIOffsetY-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:AOIWidth-SP', 1280, 0.0],
    ['TS-04:DI-ScrnCam-3:CalPosCenterX-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:CalPosCenterY-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:CenterOffsetX-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:CenterOffsetY-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:ThetaOffset-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:ScaleFactorX-SP', 1, 0.0],
    ['TS-04:DI-ScrnCam-3:ScaleFactorY-SP', 1, 0.0],
    ['TS-04:DI-ScrnCam-3:EnblBGSubtraction-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:EnblOffsetScale-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:PixelOffset-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:PixelScale-SP', 1, 0.0],
    ['TS-04:DI-ScrnCam-3:HighClip-SP', 65535, 0.0],
    ['TS-04:DI-ScrnCam-3:LowClip-SP', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:EnblHighClip-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:EnblLowClip-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:DimFeiMarkEnbl-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:NDStatsMarkEnbl-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:CalCenterMarkEnbl-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:RealCenterMarkEnbl-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:EnblMJPEG-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:ColorConv-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:FastAcq-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCam-3:DimFeiMarkColor-SP', 255, 0.0],
    ['TS-04:DI-ScrnCam-3:DimFeiMarkSize-SP', 10, 0.0],
    ['TS-04:DI-ScrnCam-3:NDStatsMarkColor-SP', 255, 0.0],
    ['TS-04:DI-ScrnCam-3:NDStatsMarkSize-SP', 10, 0.0],
    ['TS-04:DI-ScrnCam-3:CalCenterMarkColor-SP', 255, 0.0],
    ['TS-04:DI-ScrnCam-3:CalCenterMarkSize-SP', 10, 0.0],
    ['TS-04:DI-ScrnCam-3:RealCenterMarkColor-SP', 255, 0.0],
    ['TS-04:DI-ScrnCam-3:RealCenterMarkSize-SP', 10, 0.0],

    ['TS-01:DI-ScrnCtrl:AmpEnbl-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:AmpGain-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:AmpCurrLoopGain-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:LowCurrMode-SP', 1, 0.0],
    ['TS-01:DI-ScrnCtrl:Mtr.SET', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:Mtr.MRES', 1, 0.0],
    ['TS-01:DI-ScrnCtrl:Mtr.SREV', 51200, 0.0],
    ['TS-01:DI-ScrnCtrl:Mtr.VMAX', 1.4, 0.0],
    ['TS-01:DI-ScrnCtrl:Mtr.VELO', 1.3, 0.0],
    ['TS-01:DI-ScrnCtrl:Mtr.ACCL', 2, 0.0],
    ['TS-01:DI-ScrnCtrl:Mtr.HLM', 100, 0.0],
    ['TS-01:DI-ScrnCtrl:Mtr.LLM', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:Mtr.DIR', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:Mtr.OFF', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:Mtr.BDST', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:Mtr.BVEL', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:Mtr.BACC', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:Mtr.EGU', 'mm', 0.0],
    ['TS-01:DI-ScrnCtrl:Mtr.NTM', 1, 0.0],
    ['TS-01:DI-ScrnCtrl:Mtr.RTRY', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:Mtr.RDBD', 1, 0.0],
    ['TS-01:DI-ScrnCtrl:Mtr.RMOD', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:MtrType-Sel', 2, 0.0],
    ['TS-01:DI-ScrnCtrl:LimSwType-Sel', 1, 0.0],
    ['TS-01:DI-ScrnCtrl:MainEncType-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:Mtr.ERES', 1, 0.0],
    ['TS-01:DI-ScrnCtrl:EstallTime-SP', 0.2, 0.0],
    ['TS-01:DI-ScrnCtrl:PollPeriod-SP', 1, 0.0],
    ['TS-01:DI-ScrnCtrl:Mtr.UEIP', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:RefHomePos-SP', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:RstPosAfterHome-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:JogAfterHome-SP', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:HomeEnblDir-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:Mtr.HVEL', 1.4, 0.0],
    ['TS-01:DI-ScrnCtrl:DigOut0-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:DigOut1-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:DigOut2-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:DigOut3-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:AnalogOut0DeadBand-SP', 0.002, 0.0],
    ['TS-01:DI-ScrnCtrl:AnalogOut1DeadBand-SP', 0.002, 0.0],
    ['TS-01:DI-ScrnCtrl:BiSSIn-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:BiSSLvl-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:BiSSPoll-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:BiSSClkDiv-SP', 9, 0.0],
    ['TS-01:DI-ScrnCtrl:BiSSNumBits1-SP', 33, 0.0],
    ['TS-01:DI-ScrnCtrl:BiSSNumBits2-SP', 33, 0.0],
    ['TS-01:DI-ScrnCtrl:BiSSNumZeroPad-SP', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:LimSwDsbl-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:LimProtectEnbl-Sel', 1, 0.0],
    ['TS-01:DI-ScrnCtrl:AuxEncType-Sel', 1, 0.0],
    ['TS-01:DI-ScrnCtrl:ErrLimType-Sel', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:PosErrLim-SP', 16384, 0.0],
    ['TS-01:DI-ScrnCtrl:StopDelay-SP', 0, 0.0],
    ['TS-01:DI-ScrnCtrl:UseIdx-Sel', 1, 0.0],
    ['TS-01:DI-ScrnCtrl:UseSw-Sel', 1, 0.0],
    ['TS-02:DI-ScrnCtrl:AmpEnbl-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:AmpGain-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:AmpCurrLoopGain-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:LowCurrMode-SP', 1, 0.0],
    ['TS-02:DI-ScrnCtrl:Mtr.SET', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:Mtr.MRES', 1, 0.0],
    ['TS-02:DI-ScrnCtrl:Mtr.SREV', 51200, 0.0],
    ['TS-02:DI-ScrnCtrl:Mtr.VMAX', 1.4, 0.0],
    ['TS-02:DI-ScrnCtrl:Mtr.VELO', 1.3, 0.0],
    ['TS-02:DI-ScrnCtrl:Mtr.ACCL', 2, 0.0],
    ['TS-02:DI-ScrnCtrl:Mtr.HLM', 100, 0.0],
    ['TS-02:DI-ScrnCtrl:Mtr.LLM', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:Mtr.DIR', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:Mtr.OFF', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:Mtr.BDST', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:Mtr.BVEL', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:Mtr.BACC', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:Mtr.EGU', 'mm', 0.0],
    ['TS-02:DI-ScrnCtrl:Mtr.NTM', 1, 0.0],
    ['TS-02:DI-ScrnCtrl:Mtr.RTRY', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:Mtr.RDBD', 1, 0.0],
    ['TS-02:DI-ScrnCtrl:Mtr.RMOD', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:MtrType-Sel', 2, 0.0],
    ['TS-02:DI-ScrnCtrl:LimSwType-Sel', 1, 0.0],
    ['TS-02:DI-ScrnCtrl:MainEncType-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:Mtr.ERES', 1, 0.0],
    ['TS-02:DI-ScrnCtrl:EstallTime-SP', 0.2, 0.0],
    ['TS-02:DI-ScrnCtrl:PollPeriod-SP', 1, 0.0],
    ['TS-02:DI-ScrnCtrl:Mtr.UEIP', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:RefHomePos-SP', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:RstPosAfterHome-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:JogAfterHome-SP', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:HomeEnblDir-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:Mtr.HVEL', 1.4, 0.0],
    ['TS-02:DI-ScrnCtrl:DigOut0-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:DigOut1-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:DigOut2-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:DigOut3-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:AnalogOut0DeadBand-SP', 0.002, 0.0],
    ['TS-02:DI-ScrnCtrl:AnalogOut1DeadBand-SP', 0.002, 0.0],
    ['TS-02:DI-ScrnCtrl:BiSSIn-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:BiSSLvl-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:BiSSPoll-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:BiSSClkDiv-SP', 9, 0.0],
    ['TS-02:DI-ScrnCtrl:BiSSNumBits1-SP', 33, 0.0],
    ['TS-02:DI-ScrnCtrl:BiSSNumBits2-SP', 33, 0.0],
    ['TS-02:DI-ScrnCtrl:BiSSNumZeroPad-SP', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:LimSwDsbl-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:LimProtectEnbl-Sel', 1, 0.0],
    ['TS-02:DI-ScrnCtrl:AuxEncType-Sel', 1, 0.0],
    ['TS-02:DI-ScrnCtrl:ErrLimType-Sel', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:PosErrLim-SP', 16384, 0.0],
    ['TS-02:DI-ScrnCtrl:StopDelay-SP', 0, 0.0],
    ['TS-02:DI-ScrnCtrl:UseIdx-Sel', 1, 0.0],
    ['TS-02:DI-ScrnCtrl:UseSw-Sel', 1, 0.0],
    ['TS-03:DI-ScrnCtrl:AmpEnbl-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:AmpGain-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:AmpCurrLoopGain-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:LowCurrMode-SP', 1, 0.0],
    ['TS-03:DI-ScrnCtrl:Mtr.SET', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:Mtr.MRES', 1, 0.0],
    ['TS-03:DI-ScrnCtrl:Mtr.SREV', 51200, 0.0],
    ['TS-03:DI-ScrnCtrl:Mtr.VMAX', 1.4, 0.0],
    ['TS-03:DI-ScrnCtrl:Mtr.VELO', 1.3, 0.0],
    ['TS-03:DI-ScrnCtrl:Mtr.ACCL', 2, 0.0],
    ['TS-03:DI-ScrnCtrl:Mtr.HLM', 100, 0.0],
    ['TS-03:DI-ScrnCtrl:Mtr.LLM', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:Mtr.DIR', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:Mtr.OFF', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:Mtr.BDST', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:Mtr.BVEL', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:Mtr.BACC', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:Mtr.EGU', 'mm', 0.0],
    ['TS-03:DI-ScrnCtrl:Mtr.NTM', 1, 0.0],
    ['TS-03:DI-ScrnCtrl:Mtr.RTRY', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:Mtr.RDBD', 1, 0.0],
    ['TS-03:DI-ScrnCtrl:Mtr.RMOD', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:MtrType-Sel', 2, 0.0],
    ['TS-03:DI-ScrnCtrl:LimSwType-Sel', 1, 0.0],
    ['TS-03:DI-ScrnCtrl:MainEncType-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:Mtr.ERES', 1, 0.0],
    ['TS-03:DI-ScrnCtrl:EstallTime-SP', 0.2, 0.0],
    ['TS-03:DI-ScrnCtrl:PollPeriod-SP', 1, 0.0],
    ['TS-03:DI-ScrnCtrl:Mtr.UEIP', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:RefHomePos-SP', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:RstPosAfterHome-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:JogAfterHome-SP', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:HomeEnblDir-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:Mtr.HVEL', 1.4, 0.0],
    ['TS-03:DI-ScrnCtrl:DigOut0-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:DigOut1-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:DigOut2-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:DigOut3-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:AnalogOut0DeadBand-SP', 0.002, 0.0],
    ['TS-03:DI-ScrnCtrl:AnalogOut1DeadBand-SP', 0.002, 0.0],
    ['TS-03:DI-ScrnCtrl:BiSSIn-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:BiSSLvl-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:BiSSPoll-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:BiSSClkDiv-SP', 9, 0.0],
    ['TS-03:DI-ScrnCtrl:BiSSNumBits1-SP', 33, 0.0],
    ['TS-03:DI-ScrnCtrl:BiSSNumBits2-SP', 33, 0.0],
    ['TS-03:DI-ScrnCtrl:BiSSNumZeroPad-SP', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:LimSwDsbl-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:LimProtectEnbl-Sel', 1, 0.0],
    ['TS-03:DI-ScrnCtrl:AuxEncType-Sel', 1, 0.0],
    ['TS-03:DI-ScrnCtrl:ErrLimType-Sel', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:PosErrLim-SP', 16384, 0.0],
    ['TS-03:DI-ScrnCtrl:StopDelay-SP', 0, 0.0],
    ['TS-03:DI-ScrnCtrl:UseIdx-Sel', 1, 0.0],
    ['TS-03:DI-ScrnCtrl:UseSw-Sel', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-1:AmpEnbl-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:AmpGain-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:AmpCurrLoopGain-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:LowCurrMode-SP', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-1:Mtr.SET', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:Mtr.MRES', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-1:Mtr.SREV', 51200, 0.0],
    ['TS-04:DI-ScrnCtrl-1:Mtr.VMAX', 1.4, 0.0],
    ['TS-04:DI-ScrnCtrl-1:Mtr.VELO', 1.3, 0.0],
    ['TS-04:DI-ScrnCtrl-1:Mtr.ACCL', 2, 0.0],
    ['TS-04:DI-ScrnCtrl-1:Mtr.HLM', 100, 0.0],
    ['TS-04:DI-ScrnCtrl-1:Mtr.LLM', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:Mtr.DIR', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:Mtr.OFF', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:Mtr.BDST', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:Mtr.BVEL', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:Mtr.BACC', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:Mtr.EGU', 'mm', 0.0],
    ['TS-04:DI-ScrnCtrl-1:Mtr.NTM', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-1:Mtr.RTRY', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:Mtr.RDBD', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-1:Mtr.RMOD', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:MtrType-Sel', 2, 0.0],
    ['TS-04:DI-ScrnCtrl-1:LimSwType-Sel', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-1:MainEncType-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:Mtr.ERES', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-1:EstallTime-SP', 0.2, 0.0],
    ['TS-04:DI-ScrnCtrl-1:PollPeriod-SP', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-1:Mtr.UEIP', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:RefHomePos-SP', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:RstPosAfterHome-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:JogAfterHome-SP', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:HomeEnblDir-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:Mtr.HVEL', 1.4, 0.0],
    ['TS-04:DI-ScrnCtrl-1:DigOut0-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:DigOut1-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:DigOut2-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:DigOut3-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:AnalogOut0DeadBand-SP', 0.002, 0.0],
    ['TS-04:DI-ScrnCtrl-1:AnalogOut1DeadBand-SP', 0.002, 0.0],
    ['TS-04:DI-ScrnCtrl-1:BiSSIn-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:BiSSLvl-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:BiSSPoll-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:BiSSClkDiv-SP', 9, 0.0],
    ['TS-04:DI-ScrnCtrl-1:BiSSNumBits1-SP', 33, 0.0],
    ['TS-04:DI-ScrnCtrl-1:BiSSNumBits2-SP', 33, 0.0],
    ['TS-04:DI-ScrnCtrl-1:BiSSNumZeroPad-SP', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:LimSwDsbl-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:LimProtectEnbl-Sel', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-1:AuxEncType-Sel', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-1:ErrLimType-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:PosErrLim-SP', 16384, 0.0],
    ['TS-04:DI-ScrnCtrl-1:StopDelay-SP', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-1:UseIdx-Sel', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-1:UseSw-Sel', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-2:AmpEnbl-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:AmpGain-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:AmpCurrLoopGain-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:LowCurrMode-SP', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-2:Mtr.SET', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:Mtr.MRES', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-2:Mtr.SREV', 51200, 0.0],
    ['TS-04:DI-ScrnCtrl-2:Mtr.VMAX', 1.4, 0.0],
    ['TS-04:DI-ScrnCtrl-2:Mtr.VELO', 1.3, 0.0],
    ['TS-04:DI-ScrnCtrl-2:Mtr.ACCL', 2, 0.0],
    ['TS-04:DI-ScrnCtrl-2:Mtr.HLM', 100, 0.0],
    ['TS-04:DI-ScrnCtrl-2:Mtr.LLM', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:Mtr.DIR', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:Mtr.OFF', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:Mtr.BDST', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:Mtr.BVEL', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:Mtr.BACC', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:Mtr.EGU', 'mm', 0.0],
    ['TS-04:DI-ScrnCtrl-2:Mtr.NTM', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-2:Mtr.RTRY', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:Mtr.RDBD', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-2:Mtr.RMOD', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:MtrType-Sel', 2, 0.0],
    ['TS-04:DI-ScrnCtrl-2:LimSwType-Sel', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-2:MainEncType-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:Mtr.ERES', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-2:EstallTime-SP', 0.2, 0.0],
    ['TS-04:DI-ScrnCtrl-2:PollPeriod-SP', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-2:Mtr.UEIP', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:RefHomePos-SP', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:RstPosAfterHome-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:JogAfterHome-SP', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:HomeEnblDir-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:Mtr.HVEL', 1.4, 0.0],
    ['TS-04:DI-ScrnCtrl-2:DigOut0-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:DigOut1-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:DigOut2-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:DigOut3-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:AnalogOut0DeadBand-SP', 0.002, 0.0],
    ['TS-04:DI-ScrnCtrl-2:AnalogOut1DeadBand-SP', 0.002, 0.0],
    ['TS-04:DI-ScrnCtrl-2:BiSSIn-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:BiSSLvl-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:BiSSPoll-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:BiSSClkDiv-SP', 9, 0.0],
    ['TS-04:DI-ScrnCtrl-2:BiSSNumBits1-SP', 33, 0.0],
    ['TS-04:DI-ScrnCtrl-2:BiSSNumBits2-SP', 33, 0.0],
    ['TS-04:DI-ScrnCtrl-2:BiSSNumZeroPad-SP', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:LimSwDsbl-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:LimProtectEnbl-Sel', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-2:AuxEncType-Sel', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-2:ErrLimType-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:PosErrLim-SP', 16384, 0.0],
    ['TS-04:DI-ScrnCtrl-2:StopDelay-SP', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-2:UseIdx-Sel', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-2:UseSw-Sel', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-3:AmpEnbl-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:AmpGain-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:AmpCurrLoopGain-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:LowCurrMode-SP', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-3:Mtr.SET', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:Mtr.MRES', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-3:Mtr.SREV', 51200, 0.0],
    ['TS-04:DI-ScrnCtrl-3:Mtr.VMAX', 1.4, 0.0],
    ['TS-04:DI-ScrnCtrl-3:Mtr.VELO', 1.3, 0.0],
    ['TS-04:DI-ScrnCtrl-3:Mtr.ACCL', 2, 0.0],
    ['TS-04:DI-ScrnCtrl-3:Mtr.HLM', 100, 0.0],
    ['TS-04:DI-ScrnCtrl-3:Mtr.LLM', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:Mtr.DIR', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:Mtr.OFF', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:Mtr.BDST', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:Mtr.BVEL', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:Mtr.BACC', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:Mtr.EGU', 'mm', 0.0],
    ['TS-04:DI-ScrnCtrl-3:Mtr.NTM', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-3:Mtr.RTRY', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:Mtr.RDBD', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-3:Mtr.RMOD', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:MtrType-Sel', 2, 0.0],
    ['TS-04:DI-ScrnCtrl-3:LimSwType-Sel', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-3:MainEncType-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:Mtr.ERES', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-3:EstallTime-SP', 0.2, 0.0],
    ['TS-04:DI-ScrnCtrl-3:PollPeriod-SP', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-3:Mtr.UEIP', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:RefHomePos-SP', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:RstPosAfterHome-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:JogAfterHome-SP', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:HomeEnblDir-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:Mtr.HVEL', 1.4, 0.0],
    ['TS-04:DI-ScrnCtrl-3:DigOut0-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:DigOut1-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:DigOut2-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:DigOut3-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:AnalogOut0DeadBand-SP', 0.002, 0.0],
    ['TS-04:DI-ScrnCtrl-3:AnalogOut1DeadBand-SP', 0.002, 0.0],
    ['TS-04:DI-ScrnCtrl-3:BiSSIn-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:BiSSLvl-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:BiSSPoll-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:BiSSClkDiv-SP', 9, 0.0],
    ['TS-04:DI-ScrnCtrl-3:BiSSNumBits1-SP', 33, 0.0],
    ['TS-04:DI-ScrnCtrl-3:BiSSNumBits2-SP', 33, 0.0],
    ['TS-04:DI-ScrnCtrl-3:BiSSNumZeroPad-SP', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:LimSwDsbl-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:LimProtectEnbl-Sel', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-3:AuxEncType-Sel', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-3:ErrLimType-Sel', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:PosErrLim-SP', 16384, 0.0],
    ['TS-04:DI-ScrnCtrl-3:StopDelay-SP', 0, 0.0],
    ['TS-04:DI-ScrnCtrl-3:UseIdx-Sel', 1, 0.0],
    ['TS-04:DI-ScrnCtrl-3:UseSw-Sel', 1, 0.0],

    ['TS-01:DI-Scrn:CalScrnPos-SP', 1, 0.0],
    ['TS-01:DI-Scrn:FluorScrnPos-SP', 2, 0.0],
    ['TS-01:DI-Scrn:NoneScrnPos-SP', 0, 0.0],
    ['TS-01:DI-Scrn:AcceptedErr-SP', 1, 0.0],
    ['TS-01:DI-Scrn:LEDPwrLvl-SP', 0, 0.0],
    ['TS-01:DI-Scrn:LEDThold-SP', 2.5, 0.0],
    ['TS-01:DI-Scrn:LEDPwrScaleFactor-SP', 0.011, 0.0],
    ['TS-02:DI-Scrn:CalScrnPos-SP', 1, 0.0],
    ['TS-02:DI-Scrn:FluorScrnPos-SP', 2, 0.0],
    ['TS-02:DI-Scrn:NoneScrnPos-SP', 0, 0.0],
    ['TS-02:DI-Scrn:AcceptedErr-SP', 1, 0.0],
    ['TS-02:DI-Scrn:LEDPwrLvl-SP', 0, 0.0],
    ['TS-02:DI-Scrn:LEDThold-SP', 2.5, 0.0],
    ['TS-02:DI-Scrn:LEDPwrScaleFactor-SP', 0.011, 0.0],
    ['TS-03:DI-Scrn:CalScrnPos-SP', 1, 0.0],
    ['TS-03:DI-Scrn:FluorScrnPos-SP', 2, 0.0],
    ['TS-03:DI-Scrn:NoneScrnPos-SP', 0, 0.0],
    ['TS-03:DI-Scrn:AcceptedErr-SP', 1, 0.0],
    ['TS-03:DI-Scrn:LEDPwrLvl-SP', 0, 0.0],
    ['TS-03:DI-Scrn:LEDThold-SP', 2.5, 0.0],
    ['TS-03:DI-Scrn:LEDPwrScaleFactor-SP', 0.011, 0.0],
    ['TS-04:DI-Scrn-1:CalScrnPos-SP', 1, 0.0],
    ['TS-04:DI-Scrn-1:FluorScrnPos-SP', 2, 0.0],
    ['TS-04:DI-Scrn-1:NoneScrnPos-SP', 0, 0.0],
    ['TS-04:DI-Scrn-1:AcceptedErr-SP', 1, 0.0],
    ['TS-04:DI-Scrn-1:LEDPwrLvl-SP', 0, 0.0],
    ['TS-04:DI-Scrn-1:LEDThold-SP', 2.5, 0.0],
    ['TS-04:DI-Scrn-1:LEDPwrScaleFactor-SP', 0.011, 0.0],
    ['TS-04:DI-Scrn-2:CalScrnPos-SP', 1, 0.0],
    ['TS-04:DI-Scrn-2:FluorScrnPos-SP', 2, 0.0],
    ['TS-04:DI-Scrn-2:NoneScrnPos-SP', 0, 0.0],
    ['TS-04:DI-Scrn-2:AcceptedErr-SP', 1, 0.0],
    ['TS-04:DI-Scrn-2:LEDPwrLvl-SP', 0, 0.0],
    ['TS-04:DI-Scrn-2:LEDThold-SP', 2.5, 0.0],
    ['TS-04:DI-Scrn-2:LEDPwrScaleFactor-SP', 0.011, 0.0],
    ['TS-04:DI-Scrn-3:CalScrnPos-SP', 1, 0.0],
    ['TS-04:DI-Scrn-3:FluorScrnPos-SP', 2, 0.0],
    ['TS-04:DI-Scrn-3:NoneScrnPos-SP', 0, 0.0],
    ['TS-04:DI-Scrn-3:AcceptedErr-SP', 1, 0.0],
    ['TS-04:DI-Scrn-3:LEDPwrLvl-SP', 0, 0.0],
    ['TS-04:DI-Scrn-3:LEDThold-SP', 2.5, 0.0],
    ['TS-04:DI-Scrn-3:LEDPwrScaleFactor-SP', 0.011, 0.0],
]

_vlightcam_pvs = [
    ['BO-50U:DI-VLightCam:Enbl-Sel', 0, 0.0],
    ['BO-50U:DI-VLightCam:Gain-SP', 0, 0.0],
    ['BO-50U:DI-VLightCam:AcqMode-Sel', 0, 0.0],
    ['BO-50U:DI-VLightCam:AcqPeriod-SP', 0.4, 0.0],
    ['BO-50U:DI-VLightCam:AcqPeriodLowLim-SP', 0.083, 0.0],
    ['BO-50U:DI-VLightCam:ExposureMode-Sel', 0, 0.0],
    ['BO-50U:DI-VLightCam:ExposureTime-SP', 5000, 0.0],
    ['BO-50U:DI-VLightCam:DataType-Sel', 0, 0.0],
    ['BO-50U:DI-VLightCam:BlackLevel-SP', 0, 0.0],
    ['BO-50U:DI-VLightCam:TransformType-Sel', 0, 0.0],
    ['BO-50U:DI-VLightCam:DebouncerPeriod-SP', 0, 0.0],
    ['BO-50U:DI-VLightCam:BwReserve-SP', 10, 0.0],
    ['BO-50U:DI-VLightCam:BwReserveAccum-SP', 1, 0.0],
    ['BO-50U:DI-VLightCam:TransmDelay-SP', 0, 0.0],
    ['BO-50U:DI-VLightCam:PacketSize-SP', 1500, 0.0],
    ['BO-50U:DI-VLightCam:InterPacketDelay-SP', 1000, 0.0],
    ['BO-50U:DI-VLightCam:SoftROIAutoCenterX-Sel', 0, 0.0],
    ['BO-50U:DI-VLightCam:SoftROIAutoCenterY-Sel', 0, 0.0],
    ['BO-50U:DI-VLightCam:SoftROIHeight-SP', 1024, 0.0],
    ['BO-50U:DI-VLightCam:SoftROIOffsetX-SP', 0, 0.0],
    ['BO-50U:DI-VLightCam:SoftROIOffsetY-SP', 0, 0.0],
    ['BO-50U:DI-VLightCam:SoftROIWidth-SP', 1280, 0.0],
    ['BO-50U:DI-VLightCam:AOIAutoCenterX-Sel', 0, 0.0],
    ['BO-50U:DI-VLightCam:AOIAutoCenterY-Sel', 0, 0.0],
    ['BO-50U:DI-VLightCam:AOIHeight-SP', 1024, 0.0],
    ['BO-50U:DI-VLightCam:AOIOffsetX-SP', 0, 0.0],
    ['BO-50U:DI-VLightCam:AOIOffsetY-SP', 0, 0.0],
    ['BO-50U:DI-VLightCam:AOIWidth-SP', 1280, 0.0],
    ['BO-50U:DI-VLightCam:CalPosCenterX-SP', 0, 0.0],
    ['BO-50U:DI-VLightCam:CalPosCenterY-SP', 0, 0.0],
    ['BO-50U:DI-VLightCam:CenterOffsetX-SP', 0, 0.0],
    ['BO-50U:DI-VLightCam:CenterOffsetY-SP', 0, 0.0],
    ['BO-50U:DI-VLightCam:ThetaOffset-SP', 0, 0.0],
    ['BO-50U:DI-VLightCam:ScaleFactorX-SP', 1, 0.0],
    ['BO-50U:DI-VLightCam:ScaleFactorY-SP', 1, 0.0],
    ['BO-50U:DI-VLightCam:EnblBGSubtraction-Sel', 0, 0.0],
    ['BO-50U:DI-VLightCam:EnblOffsetScale-Sel', 0, 0.0],
    ['BO-50U:DI-VLightCam:PixelOffset-SP', 0, 0.0],
    ['BO-50U:DI-VLightCam:PixelScale-SP', 1, 0.0],
    ['BO-50U:DI-VLightCam:HighClip-SP', 65535, 0.0],
    ['BO-50U:DI-VLightCam:LowClip-SP', 0, 0.0],
    ['BO-50U:DI-VLightCam:EnblHighClip-Sel', 0, 0.0],
    ['BO-50U:DI-VLightCam:EnblLowClip-Sel', 0, 0.0],
    ['BO-50U:DI-VLightCam:DimFeiMarkEnbl-Sel', 0, 0.0],
    ['BO-50U:DI-VLightCam:NDStatsMarkEnbl-Sel', 0, 0.0],
    ['BO-50U:DI-VLightCam:CalCenterMarkEnbl-Sel', 0, 0.0],
    ['BO-50U:DI-VLightCam:RealCenterMarkEnbl-Sel', 0, 0.0],
    ['BO-50U:DI-VLightCam:EnblMJPEG-Sel', 0, 0.0],
    ['BO-50U:DI-VLightCam:ColorConv-Sel', 0, 0.0],
    ['BO-50U:DI-VLightCam:FastAcq-Sel', 0, 0.0],
    ['BO-50U:DI-VLightCam:DimFeiMarkColor-SP', 255, 0.0],
    ['BO-50U:DI-VLightCam:DimFeiMarkSize-SP', 10, 0.0],
    ['BO-50U:DI-VLightCam:NDStatsMarkColor-SP', 255, 0.0],
    ['BO-50U:DI-VLightCam:NDStatsMarkSize-SP', 10, 0.0],
    ['BO-50U:DI-VLightCam:CalCenterMarkColor-SP', 255, 0.0],
    ['BO-50U:DI-VLightCam:CalCenterMarkSize-SP', 10, 0.0],
    ['BO-50U:DI-VLightCam:RealCenterMarkColor-SP', 255, 0.0],
    ['BO-50U:DI-VLightCam:RealCenterMarkSize-SP', 10, 0.0],

    ['SI-01C2FE:DI-VLightCam:Enbl-Sel', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:Gain-SP', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:AcqMode-Sel', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:AcqPeriod-SP', 0.4, 0.0],
    ['SI-01C2FE:DI-VLightCam:AcqPeriodLowLim-SP', 0.083, 0.0],
    ['SI-01C2FE:DI-VLightCam:ExposureMode-Sel', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:ExposureTime-SP', 5000, 0.0],
    ['SI-01C2FE:DI-VLightCam:DataType-Sel', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:BlackLevel-SP', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:TransformType-Sel', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:DebouncerPeriod-SP', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:BwReserve-SP', 10, 0.0],
    ['SI-01C2FE:DI-VLightCam:BwReserveAccum-SP', 1, 0.0],
    ['SI-01C2FE:DI-VLightCam:TransmDelay-SP', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:PacketSize-SP', 1500, 0.0],
    ['SI-01C2FE:DI-VLightCam:InterPacketDelay-SP', 1000, 0.0],
    ['SI-01C2FE:DI-VLightCam:SoftROIAutoCenterX-Sel', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:SoftROIAutoCenterY-Sel', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:SoftROIHeight-SP', 1024, 0.0],
    ['SI-01C2FE:DI-VLightCam:SoftROIOffsetX-SP', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:SoftROIOffsetY-SP', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:SoftROIWidth-SP', 1280, 0.0],
    ['SI-01C2FE:DI-VLightCam:AOIAutoCenterX-Sel', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:AOIAutoCenterY-Sel', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:AOIHeight-SP', 1024, 0.0],
    ['SI-01C2FE:DI-VLightCam:AOIOffsetX-SP', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:AOIOffsetY-SP', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:AOIWidth-SP', 1280, 0.0],
    ['SI-01C2FE:DI-VLightCam:CalPosCenterX-SP', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:CalPosCenterY-SP', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:CenterOffsetX-SP', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:CenterOffsetY-SP', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:ThetaOffset-SP', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:ScaleFactorX-SP', 1, 0.0],
    ['SI-01C2FE:DI-VLightCam:ScaleFactorY-SP', 1, 0.0],
    ['SI-01C2FE:DI-VLightCam:EnblBGSubtraction-Sel', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:EnblOffsetScale-Sel', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:PixelOffset-SP', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:PixelScale-SP', 1, 0.0],
    ['SI-01C2FE:DI-VLightCam:HighClip-SP', 65535, 0.0],
    ['SI-01C2FE:DI-VLightCam:LowClip-SP', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:EnblHighClip-Sel', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:EnblLowClip-Sel', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:DimFeiMarkEnbl-Sel', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:NDStatsMarkEnbl-Sel', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:CalCenterMarkEnbl-Sel', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:RealCenterMarkEnbl-Sel', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:EnblMJPEG-Sel', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:ColorConv-Sel', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:FastAcq-Sel', 0, 0.0],
    ['SI-01C2FE:DI-VLightCam:DimFeiMarkColor-SP', 255, 0.0],
    ['SI-01C2FE:DI-VLightCam:DimFeiMarkSize-SP', 10, 0.0],
    ['SI-01C2FE:DI-VLightCam:NDStatsMarkColor-SP', 255, 0.0],
    ['SI-01C2FE:DI-VLightCam:NDStatsMarkSize-SP', 10, 0.0],
    ['SI-01C2FE:DI-VLightCam:CalCenterMarkColor-SP', 255, 0.0],
    ['SI-01C2FE:DI-VLightCam:CalCenterMarkSize-SP', 10, 0.0],
    ['SI-01C2FE:DI-VLightCam:RealCenterMarkColor-SP', 255, 0.0],
    ['SI-01C2FE:DI-VLightCam:RealCenterMarkSize-SP', 10, 0.0],
]

_dcct_pvs = [
    ['BO-35D:DI-DCCT:Abort-Cmd', 1, 0.0],
    ['SI-13C4:DI-DCCT:Abort-Cmd', 1, 0.0],
    ['SI-14C4:DI-DCCT:Abort-Cmd', 1, 2.0],
    ['BO-35D:DI-DCCT:MeasMode-Sel', 0, 0.0],
    ['BO-35D:DI-DCCT:MeasTrg-Sel', 0, 0.0],
    ['BO-35D:DI-DCCT:SampleCnt-SP', 1, 0.0],
    ['BO-35D:DI-DCCT:MeasPeriod-SP', 0.016667, 0.0],
    ['BO-35D:DI-DCCT:Imped-Sel', 0, 0.0],
    ['BO-35D:DI-DCCT:LineSync-Sel', 0, 0.0],
    ['BO-35D:DI-DCCT:RelEnbl-Sel', 0, 0.0],
    ['BO-35D:DI-DCCT:RelLvl-SP', 0, 0.0],
    ['BO-35D:DI-DCCT:FastSampleCnt-SP', 100, 0.0],
    ['BO-35D:DI-DCCT:FastMeasPeriod-SP', 0.016667, 0.0],
    ['BO-35D:DI-DCCT:FastImped-Sel', 0, 0.0],
    ['BO-35D:DI-DCCT:FastRelEnbl-Sel', 0, 0.0],
    ['BO-35D:DI-DCCT:FastRelLvl-SP', 0, 0.0],
    ['BO-35D:DI-DCCT:AvgFilterCnt-SP', 1, 0.0],
    ['BO-35D:DI-DCCT:AvgFilterEnbl-Sel', 0, 0.0],
    ['BO-35D:DI-DCCT:AvgFilterTyp-Sel', 0, 0.0],
    ['BO-35D:DI-DCCT:AvgFilterWind-SP', 0, 0.0],
    ['BO-35D:DI-DCCT:Range-Sel', 0, 0.0],
    ['BO-35D:DI-DCCT:Test-Sel', 0, 0.0],
    ['BO-35D:DI-DCCT:LowLimEnbl-Sel', 0, 0.0],
    ['BO-35D:DI-DCCT:CurrThold-SP', 0, 0.0],
    ['BO-35D:DI-DCCT:HFReject-Sel', 1, 0.0],
    ['BO-35D:DI-DCCT:Enbl-Sel', 1, 0.0],
    ['SI-13C4:DI-DCCT:MeasMode-Sel', 0, 0.0],
    ['SI-13C4:DI-DCCT:MeasTrg-Sel', 0, 0.0],
    ['SI-13C4:DI-DCCT:SampleCnt-SP', 1, 0.0],
    ['SI-13C4:DI-DCCT:MeasPeriod-SP', 0.016667, 0.0],
    ['SI-13C4:DI-DCCT:Imped-Sel', 0, 0.0],
    ['SI-13C4:DI-DCCT:LineSync-Sel', 0, 0.0],
    ['SI-13C4:DI-DCCT:RelEnbl-Sel', 0, 0.0],
    ['SI-13C4:DI-DCCT:RelLvl-SP', 0, 0.0],
    ['SI-13C4:DI-DCCT:FastSampleCnt-SP', 100, 0.0],
    ['SI-13C4:DI-DCCT:FastMeasPeriod-SP', 0.016667, 0.0],
    ['SI-13C4:DI-DCCT:FastImped-Sel', 0, 0.0],
    ['SI-13C4:DI-DCCT:FastRelEnbl-Sel', 0, 0.0],
    ['SI-13C4:DI-DCCT:FastRelLvl-SP', 0, 0.0],
    ['SI-13C4:DI-DCCT:AvgFilterCnt-SP', 1, 0.0],
    ['SI-13C4:DI-DCCT:AvgFilterEnbl-Sel', 0, 0.0],
    ['SI-13C4:DI-DCCT:AvgFilterTyp-Sel', 0, 0.0],
    ['SI-13C4:DI-DCCT:AvgFilterWind-SP', 0, 0.0],
    ['SI-13C4:DI-DCCT:Range-Sel', 0, 0.0],
    ['SI-13C4:DI-DCCT:Test-Sel', 0, 0.0],
    ['SI-13C4:DI-DCCT:LowLimEnbl-Sel', 0, 0.0],
    ['SI-13C4:DI-DCCT:CurrThold-SP', 0, 0.0],
    ['SI-13C4:DI-DCCT:HFReject-Sel', 1, 0.0],
    ['SI-13C4:DI-DCCT:Enbl-Sel', 1, 0.0],
    ['SI-14C4:DI-DCCT:MeasMode-Sel', 0, 0.0],
    ['SI-14C4:DI-DCCT:MeasTrg-Sel', 0, 0.0],
    ['SI-14C4:DI-DCCT:SampleCnt-SP', 1, 0.0],
    ['SI-14C4:DI-DCCT:MeasPeriod-SP', 0.016667, 0.0],
    ['SI-14C4:DI-DCCT:Imped-Sel', 0, 0.0],
    ['SI-14C4:DI-DCCT:LineSync-Sel', 0, 0.0],
    ['SI-14C4:DI-DCCT:RelEnbl-Sel', 0, 0.0],
    ['SI-14C4:DI-DCCT:RelLvl-SP', 0, 0.0],
    ['SI-14C4:DI-DCCT:FastSampleCnt-SP', 100, 0.0],
    ['SI-14C4:DI-DCCT:FastMeasPeriod-SP', 0.016667, 0.0],
    ['SI-14C4:DI-DCCT:FastImped-Sel', 0, 0.0],
    ['SI-14C4:DI-DCCT:FastRelEnbl-Sel', 0, 0.0],
    ['SI-14C4:DI-DCCT:FastRelLvl-SP', 0, 0.0],
    ['SI-14C4:DI-DCCT:AvgFilterCnt-SP', 1, 0.0],
    ['SI-14C4:DI-DCCT:AvgFilterEnbl-Sel', 0, 0.0],
    ['SI-14C4:DI-DCCT:AvgFilterTyp-Sel', 0, 0.0],
    ['SI-14C4:DI-DCCT:AvgFilterWind-SP', 0, 0.0],
    ['SI-14C4:DI-DCCT:Range-Sel', 0, 0.0],
    ['SI-14C4:DI-DCCT:Test-Sel', 0, 0.0],
    ['SI-14C4:DI-DCCT:LowLimEnbl-Sel', 0, 0.0],
    ['SI-14C4:DI-DCCT:CurrThold-SP', 0, 0.0],
    ['SI-14C4:DI-DCCT:HFReject-Sel', 1, 0.0],
    ['SI-14C4:DI-DCCT:Enbl-Sel', 1, 0.0],
]

_ict_pvs = [
    ['TB-02:DI-ICT:SampleTrg-Sel', 0, 0.0],
    ['TB-02:DI-ICT:2ndReadDly-SP', 0.016667, 0.0],
    ['TB-02:DI-ICT:SampleCnt-SP', 200, 0.0],
    ['TB-02:DI-ICT:Imped-Sel', 0, 0.0],
    ['TB-02:DI-ICT:Aperture-SP', 1, 0.0],
    ['TB-02:DI-ICT:SampleRate-SP', 1000000, 0.0],
    ['TB-02:DI-ICT:BCMRange-SP', 8, 0.0],
    ['TB-02:DI-ICT:Range-Sel', 0, 0.0],
    ['TB-02:DI-ICT:CalEnbl-Sel', 0, 0.0],
    ['TB-02:DI-ICT:CalCharge-Sel', 0, 0.0],
    ['TB-02:DI-ICT:Threshold-SP', 0.1, 0.0],
    ['TB-02:DI-ICT:HFReject-Sel', 1, 0.0],
    ['TB-04:DI-ICT:SampleTrg-Sel', 0, 0.0],
    ['TB-04:DI-ICT:2ndReadDly-SP', 0.016667, 0.0],
    ['TB-04:DI-ICT:SampleCnt-SP', 200, 0.0],
    ['TB-04:DI-ICT:Imped-Sel', 0, 0.0],
    ['TB-04:DI-ICT:Aperture-SP', 1, 0.0],
    ['TB-04:DI-ICT:SampleRate-SP', 1000000, 0.0],
    ['TB-04:DI-ICT:BCMRange-SP', 8, 0.0],
    ['TB-04:DI-ICT:Range-Sel', 0, 0.0],
    ['TB-04:DI-ICT:CalEnbl-Sel', 0, 0.0],
    ['TB-04:DI-ICT:CalCharge-Sel', 0, 0.0],
    ['TB-04:DI-ICT:Threshold-SP', 0.1, 0.0],
    ['TB-04:DI-ICT:HFReject-Sel', 1, 0.0],
    ['TS-01:DI-ICT:SampleTrg-Sel', 0, 0.0],
    ['TS-01:DI-ICT:2ndReadDly-SP', 0.016667, 0.0],
    ['TS-01:DI-ICT:SampleCnt-SP', 200, 0.0],
    ['TS-01:DI-ICT:Imped-Sel', 0, 0.0],
    ['TS-01:DI-ICT:Aperture-SP', 1, 0.0],
    ['TS-01:DI-ICT:SampleRate-SP', 1000000, 0.0],
    ['TS-01:DI-ICT:BCMRange-SP', 8, 0.0],
    ['TS-01:DI-ICT:Range-Sel', 0, 0.0],
    ['TS-01:DI-ICT:CalEnbl-Sel', 0, 0.0],
    ['TS-01:DI-ICT:CalCharge-Sel', 0, 0.0],
    ['TS-01:DI-ICT:Threshold-SP', 0.1, 0.0],
    ['TS-01:DI-ICT:HFReject-Sel', 1, 0.0],
    ['TS-04:DI-ICT:SampleTrg-Sel', 0, 0.0],
    ['TS-04:DI-ICT:2ndReadDly-SP', 0.016667, 0.0],
    ['TS-04:DI-ICT:SampleCnt-SP', 200, 0.0],
    ['TS-04:DI-ICT:Imped-Sel', 0, 0.0],
    ['TS-04:DI-ICT:Aperture-SP', 1, 0.0],
    ['TS-04:DI-ICT:SampleRate-SP', 1000000, 0.0],
    ['TS-04:DI-ICT:BCMRange-SP', 8, 0.0],
    ['TS-04:DI-ICT:Range-Sel', 0, 0.0],
    ['TS-04:DI-ICT:CalEnbl-Sel', 0, 0.0],
    ['TS-04:DI-ICT:CalCharge-Sel', 0, 0.0],
    ['TS-04:DI-ICT:Threshold-SP', 0.1, 0.0],
    ['TS-04:DI-ICT:HFReject-Sel', 1, 0.0],
]

_slit_pvs = [
    ['TB-01:DI-SlitH:SetMode-Sel', 0, 0.0],
    ['TB-01:DI-SlitH:NegEdgeInnerLim-SP', 0, 0.0],
    ['TB-01:DI-SlitH:PosEdgeInnerLim-SP', 0, 0.0],
    ['TB-01:DI-SlitH:LowOuterLim-SP', -100, 0.0],
    ['TB-01:DI-SlitH:HighOuterLim-SP', 100, 0.0],
    ['TB-01:DI-SlitV:SetMode-Sel', 0, 0.0],
    ['TB-01:DI-SlitV:NegEdgeInnerLim-SP', 0, 0.0],
    ['TB-01:DI-SlitV:PosEdgeInnerLim-SP', 0, 0.0],
    ['TB-01:DI-SlitV:LowOuterLim-SP', -100, 0.0],
    ['TB-01:DI-SlitV:HighOuterLim-SP', 100, 0.0],

    ['TB-01:DI-SlitHCtrl-O:AmpEnbl-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:AmpGain-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:AmpCurrLoopGain-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:LowCurrMode-SP', 1, 0.0],
    ['TB-01:DI-SlitHCtrl-O:Mtr.SET', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:Mtr.MRES', 1, 0.0],
    ['TB-01:DI-SlitHCtrl-O:Mtr.SREV', 51200, 0.0],
    ['TB-01:DI-SlitHCtrl-O:Mtr.VMAX', 1.4, 0.0],
    ['TB-01:DI-SlitHCtrl-O:Mtr.VELO', 1.3, 0.0],
    ['TB-01:DI-SlitHCtrl-O:Mtr.ACCL', 2, 0.0],
    ['TB-01:DI-SlitHCtrl-O:Mtr.HLM', 100, 0.0],
    ['TB-01:DI-SlitHCtrl-O:Mtr.LLM', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:Mtr.DIR', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:Mtr.OFF', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:Mtr.BDST', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:Mtr.BVEL', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:Mtr.BACC', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:Mtr.EGU', 'mm', 0.0],
    ['TB-01:DI-SlitHCtrl-O:Mtr.NTM', 1, 0.0],
    ['TB-01:DI-SlitHCtrl-O:Mtr.RTRY', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:Mtr.RDBD', 1, 0.0],
    ['TB-01:DI-SlitHCtrl-O:Mtr.RMOD', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:MtrType-Sel', 2, 0.0],
    ['TB-01:DI-SlitHCtrl-O:LimSwType-Sel', 1, 0.0],
    ['TB-01:DI-SlitHCtrl-O:MainEncType-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:Mtr.ERES', 1, 0.0],
    ['TB-01:DI-SlitHCtrl-O:EstallTime-SP', 0.2, 0.0],
    ['TB-01:DI-SlitHCtrl-O:PollPeriod-SP', 1, 0.0],
    ['TB-01:DI-SlitHCtrl-O:Mtr.UEIP', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:RefHomePos-SP', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:RstPosAfterHome-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:JogAfterHome-SP', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:HomeEnblDir-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:Mtr.HVEL', 1.4, 0.0],
    ['TB-01:DI-SlitHCtrl-O:DigOut0-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:DigOut1-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:DigOut2-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:DigOut3-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:AnalogOut0DeadBand-SP', 0.002, 0.0],
    ['TB-01:DI-SlitHCtrl-O:AnalogOut1DeadBand-SP', 0.002, 0.0],
    ['TB-01:DI-SlitHCtrl-O:BiSSIn-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:BiSSLvl-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:BiSSPoll-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:BiSSClkDiv-SP', 9, 0.0],
    ['TB-01:DI-SlitHCtrl-O:BiSSNumBits1-SP', 33, 0.0],
    ['TB-01:DI-SlitHCtrl-O:BiSSNumBits2-SP', 33, 0.0],
    ['TB-01:DI-SlitHCtrl-O:BiSSNumZeroPad-SP', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:LimSwDsbl-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:LimProtectEnbl-Sel', 1, 0.0],
    ['TB-01:DI-SlitHCtrl-O:AuxEncType-Sel', 1, 0.0],
    ['TB-01:DI-SlitHCtrl-O:ErrLimType-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:PosErrLim-SP', 16384, 0.0],
    ['TB-01:DI-SlitHCtrl-O:StopDelay-SP', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-O:UseIdx-Sel', 1, 0.0],
    ['TB-01:DI-SlitHCtrl-O:UseSw-Sel', 1, 0.0],
    ['TB-01:DI-SlitHCtrl-I:AmpEnbl-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:AmpGain-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:AmpCurrLoopGain-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:LowCurrMode-SP', 1, 0.0],
    ['TB-01:DI-SlitHCtrl-I:Mtr.SET', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:Mtr.MRES', 1, 0.0],
    ['TB-01:DI-SlitHCtrl-I:Mtr.SREV', 51200, 0.0],
    ['TB-01:DI-SlitHCtrl-I:Mtr.VMAX', 1.4, 0.0],
    ['TB-01:DI-SlitHCtrl-I:Mtr.VELO', 1.3, 0.0],
    ['TB-01:DI-SlitHCtrl-I:Mtr.ACCL', 2, 0.0],
    ['TB-01:DI-SlitHCtrl-I:Mtr.HLM', 100, 0.0],
    ['TB-01:DI-SlitHCtrl-I:Mtr.LLM', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:Mtr.DIR', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:Mtr.OFF', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:Mtr.BDST', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:Mtr.BVEL', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:Mtr.BACC', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:Mtr.EGU', 'mm', 0.0],
    ['TB-01:DI-SlitHCtrl-I:Mtr.NTM', 1, 0.0],
    ['TB-01:DI-SlitHCtrl-I:Mtr.RTRY', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:Mtr.RDBD', 1, 0.0],
    ['TB-01:DI-SlitHCtrl-I:Mtr.RMOD', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:MtrType-Sel', 2, 0.0],
    ['TB-01:DI-SlitHCtrl-I:LimSwType-Sel', 1, 0.0],
    ['TB-01:DI-SlitHCtrl-I:MainEncType-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:Mtr.ERES', 1, 0.0],
    ['TB-01:DI-SlitHCtrl-I:EstallTime-SP', 0.2, 0.0],
    ['TB-01:DI-SlitHCtrl-I:PollPeriod-SP', 1, 0.0],
    ['TB-01:DI-SlitHCtrl-I:Mtr.UEIP', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:RefHomePos-SP', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:RstPosAfterHome-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:JogAfterHome-SP', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:HomeEnblDir-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:Mtr.HVEL', 1.4, 0.0],
    ['TB-01:DI-SlitHCtrl-I:DigOut0-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:DigOut1-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:DigOut2-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:DigOut3-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:AnalogOut0DeadBand-SP', 0.002, 0.0],
    ['TB-01:DI-SlitHCtrl-I:AnalogOut1DeadBand-SP', 0.002, 0.0],
    ['TB-01:DI-SlitHCtrl-I:BiSSIn-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:BiSSLvl-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:BiSSPoll-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:BiSSClkDiv-SP', 9, 0.0],
    ['TB-01:DI-SlitHCtrl-I:BiSSNumBits1-SP', 33, 0.0],
    ['TB-01:DI-SlitHCtrl-I:BiSSNumBits2-SP', 33, 0.0],
    ['TB-01:DI-SlitHCtrl-I:BiSSNumZeroPad-SP', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:LimSwDsbl-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:LimProtectEnbl-Sel', 1, 0.0],
    ['TB-01:DI-SlitHCtrl-I:AuxEncType-Sel', 1, 0.0],
    ['TB-01:DI-SlitHCtrl-I:ErrLimType-Sel', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:PosErrLim-SP', 16384, 0.0],
    ['TB-01:DI-SlitHCtrl-I:StopDelay-SP', 0, 0.0],
    ['TB-01:DI-SlitHCtrl-I:UseIdx-Sel', 1, 0.0],
    ['TB-01:DI-SlitHCtrl-I:UseSw-Sel', 1, 0.0],
    ['TB-01:DI-SlitVCtrl-B:AmpEnbl-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:AmpGain-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:AmpCurrLoopGain-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:LowCurrMode-SP', 1, 0.0],
    ['TB-01:DI-SlitVCtrl-B:Mtr.SET', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:Mtr.MRES', 1, 0.0],
    ['TB-01:DI-SlitVCtrl-B:Mtr.SREV', 51200, 0.0],
    ['TB-01:DI-SlitVCtrl-B:Mtr.VMAX', 1.4, 0.0],
    ['TB-01:DI-SlitVCtrl-B:Mtr.VELO', 1.3, 0.0],
    ['TB-01:DI-SlitVCtrl-B:Mtr.ACCL', 2, 0.0],
    ['TB-01:DI-SlitVCtrl-B:Mtr.HLM', 100, 0.0],
    ['TB-01:DI-SlitVCtrl-B:Mtr.LLM', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:Mtr.DIR', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:Mtr.OFF', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:Mtr.BDST', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:Mtr.BVEL', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:Mtr.BACC', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:Mtr.EGU', 'mm', 0.0],
    ['TB-01:DI-SlitVCtrl-B:Mtr.NTM', 1, 0.0],
    ['TB-01:DI-SlitVCtrl-B:Mtr.RTRY', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:Mtr.RDBD', 1, 0.0],
    ['TB-01:DI-SlitVCtrl-B:Mtr.RMOD', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:MtrType-Sel', 2, 0.0],
    ['TB-01:DI-SlitVCtrl-B:LimSwType-Sel', 1, 0.0],
    ['TB-01:DI-SlitVCtrl-B:MainEncType-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:Mtr.ERES', 1, 0.0],
    ['TB-01:DI-SlitVCtrl-B:EstallTime-SP', 0.2, 0.0],
    ['TB-01:DI-SlitVCtrl-B:PollPeriod-SP', 1, 0.0],
    ['TB-01:DI-SlitVCtrl-B:Mtr.UEIP', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:RefHomePos-SP', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:RstPosAfterHome-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:JogAfterHome-SP', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:HomeEnblDir-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:Mtr.HVEL', 1.4, 0.0],
    ['TB-01:DI-SlitVCtrl-B:DigOut0-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:DigOut1-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:DigOut2-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:DigOut3-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:AnalogOut0DeadBand-SP', 0.002, 0.0],
    ['TB-01:DI-SlitVCtrl-B:AnalogOut1DeadBand-SP', 0.002, 0.0],
    ['TB-01:DI-SlitVCtrl-B:BiSSIn-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:BiSSLvl-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:BiSSPoll-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:BiSSClkDiv-SP', 9, 0.0],
    ['TB-01:DI-SlitVCtrl-B:BiSSNumBits1-SP', 33, 0.0],
    ['TB-01:DI-SlitVCtrl-B:BiSSNumBits2-SP', 33, 0.0],
    ['TB-01:DI-SlitVCtrl-B:BiSSNumZeroPad-SP', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:LimSwDsbl-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:LimProtectEnbl-Sel', 1, 0.0],
    ['TB-01:DI-SlitVCtrl-B:AuxEncType-Sel', 1, 0.0],
    ['TB-01:DI-SlitVCtrl-B:ErrLimType-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:PosErrLim-SP', 16384, 0.0],
    ['TB-01:DI-SlitVCtrl-B:StopDelay-SP', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-B:UseIdx-Sel', 1, 0.0],
    ['TB-01:DI-SlitVCtrl-B:UseSw-Sel', 1, 0.0],
    ['TB-01:DI-SlitVCtrl-T:AmpEnbl-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:AmpGain-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:AmpCurrLoopGain-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:LowCurrMode-SP', 1, 0.0],
    ['TB-01:DI-SlitVCtrl-T:Mtr.SET', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:Mtr.MRES', 1, 0.0],
    ['TB-01:DI-SlitVCtrl-T:Mtr.SREV', 51200, 0.0],
    ['TB-01:DI-SlitVCtrl-T:Mtr.VMAX', 1.4, 0.0],
    ['TB-01:DI-SlitVCtrl-T:Mtr.VELO', 1.3, 0.0],
    ['TB-01:DI-SlitVCtrl-T:Mtr.ACCL', 2, 0.0],
    ['TB-01:DI-SlitVCtrl-T:Mtr.HLM', 100, 0.0],
    ['TB-01:DI-SlitVCtrl-T:Mtr.LLM', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:Mtr.DIR', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:Mtr.OFF', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:Mtr.BDST', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:Mtr.BVEL', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:Mtr.BACC', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:Mtr.EGU', 'mm', 0.0],
    ['TB-01:DI-SlitVCtrl-T:Mtr.NTM', 1, 0.0],
    ['TB-01:DI-SlitVCtrl-T:Mtr.RTRY', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:Mtr.RDBD', 1, 0.0],
    ['TB-01:DI-SlitVCtrl-T:Mtr.RMOD', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:MtrType-Sel', 2, 0.0],
    ['TB-01:DI-SlitVCtrl-T:LimSwType-Sel', 1, 0.0],
    ['TB-01:DI-SlitVCtrl-T:MainEncType-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:Mtr.ERES', 1, 0.0],
    ['TB-01:DI-SlitVCtrl-T:EstallTime-SP', 0.2, 0.0],
    ['TB-01:DI-SlitVCtrl-T:PollPeriod-SP', 1, 0.0],
    ['TB-01:DI-SlitVCtrl-T:Mtr.UEIP', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:RefHomePos-SP', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:RstPosAfterHome-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:JogAfterHome-SP', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:HomeEnblDir-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:Mtr.HVEL', 1.4, 0.0],
    ['TB-01:DI-SlitVCtrl-T:DigOut0-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:DigOut1-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:DigOut2-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:DigOut3-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:AnalogOut0DeadBand-SP', 0.002, 0.0],
    ['TB-01:DI-SlitVCtrl-T:AnalogOut1DeadBand-SP', 0.002, 0.0],
    ['TB-01:DI-SlitVCtrl-T:BiSSIn-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:BiSSLvl-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:BiSSPoll-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:BiSSClkDiv-SP', 9, 0.0],
    ['TB-01:DI-SlitVCtrl-T:BiSSNumBits1-SP', 33, 0.0],
    ['TB-01:DI-SlitVCtrl-T:BiSSNumBits2-SP', 33, 0.0],
    ['TB-01:DI-SlitVCtrl-T:BiSSNumZeroPad-SP', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:LimSwDsbl-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:LimProtectEnbl-Sel', 1, 0.0],
    ['TB-01:DI-SlitVCtrl-T:AuxEncType-Sel', 1, 0.0],
    ['TB-01:DI-SlitVCtrl-T:ErrLimType-Sel', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:PosErrLim-SP', 16384, 0.0],
    ['TB-01:DI-SlitVCtrl-T:StopDelay-SP', 0, 0.0],
    ['TB-01:DI-SlitVCtrl-T:UseIdx-Sel', 1, 0.0],
    ['TB-01:DI-SlitVCtrl-T:UseSw-Sel', 1, 0.0],
]

_tune_pvs = [
    ['BO-Glob:DI-Tune-H:FreqOff-SP', 0.0, 0],
    ['BO-Glob:DI-Tune-H:RevN-SP', 0.0, 0],
    ['BO-Glob:DI-Tune-H:CenterFreq-SP', 0.0, 0],
    ['BO-Glob:DI-Tune-H:CenterFreqAuto-Sel', 0, 0],
    ['BO-Glob:DI-Tune-H:SpecAnaRBW-Sel', 0, 0],
    ['BO-Glob:DI-Tune-H:SpecAnaGetSpec-Sel', 0, 0],
    ['BO-Glob:DI-Tune-H:ROIOffsetX-SP', 0.0, 0],
    ['BO-Glob:DI-Tune-H:ROIOffsetY-SP', 0.0, 0],
    ['BO-Glob:DI-Tune-H:ROIWidth-SP', 0.0, 0],
    ['BO-Glob:DI-Tune-H:ROIHeight-SP', 0.0, 0],
    ['BO-Glob:DI-Tune-H:ROIAuto-Sel', 0, 0],
    ['BO-Glob:DI-Tune-H:AmpGain-SP', 0.0, 0],
    ['BO-Glob:DI-Tune-H:RFFreq-Mon.INP', '', 0],
    ['BO-Glob:DI-Tune-H:SIH-Cte.INP', '', 0],
    ['BO-Glob:DI-Tune-H:BOH-Cte.INP', '', 0],
    ['BO-Glob:DI-Tune-H:CarFreqThold-SP', 0.0, 0],
    ['BO-Glob:DI-Tune-H:DriveAuto-Sel', 0, 0],
    ['BO-Glob:DI-Tune-H:NoiseAmpl-SP', 0.0, 0],
    ['BO-Glob:DI-TuneProc-H:EnblTrkGen-Sel', 0, 0],
    ['BO-Glob:DI-TuneProc-H:AttIn-Sel', 0, 0],
    ['BO-Glob:DI-TuneProc-H:EnblAttAuto-Sel', 0, 0],
    ['BO-Glob:DI-TuneProc-H:ImpdIn-Sel', 0, 0],
    ['BO-Glob:DI-TuneProc-H:RoscSrc-Sel', 0, 0],
    ['BO-Glob:DI-TuneProc-H:TrkGenLvl-SP', 0.0, 0],
    ['BO-Glob:DI-TuneProc-H:TrkGenLvlOffset-SP', 0.0, 0],
    ['BO-Glob:DI-TuneProc-H:GetSpectrum-Sel', 0, 0],
    ['BO-Glob:DI-TuneProc-H:TrigSrc-Sel', 0, 0],
    ['BO-Glob:DI-TuneProc-H:DispRange-SP', 0.0, 0],
    ['BO-Glob:DI-TuneProc-H:FiltType-Sel', 0, 0],

    ['BO-Glob:DI-Tune-V:FreqOff-SP', 0.0, 0],
    ['BO-Glob:DI-Tune-V:RevN-SP', 0.0, 0],
    ['BO-Glob:DI-Tune-V:CenterFreq-SP', 0.0, 0],
    ['BO-Glob:DI-Tune-V:CenterFreqAuto-Sel', 0, 0],
    ['BO-Glob:DI-Tune-V:SpecAnaRBW-Sel', 0, 0],
    ['BO-Glob:DI-Tune-V:SpecAnaGetSpec-Sel', 0, 0],
    ['BO-Glob:DI-Tune-V:ROIOffsetX-SP', 0.0, 0],
    ['BO-Glob:DI-Tune-V:ROIOffsetY-SP', 0.0, 0],
    ['BO-Glob:DI-Tune-V:ROIWidth-SP', 0.0, 0],
    ['BO-Glob:DI-Tune-V:ROIHeight-SP', 0.0, 0],
    ['BO-Glob:DI-Tune-V:ROIAuto-Sel', 0, 0],
    ['BO-Glob:DI-Tune-V:AmpGain-SP', 0.0, 0],
    ['BO-Glob:DI-Tune-V:RFFreq-Mon.INP', '', 0],
    ['BO-Glob:DI-Tune-V:SIH-Cte.INP', '', 0],
    ['BO-Glob:DI-Tune-V:BOH-Cte.INP', '', 0],
    ['BO-Glob:DI-Tune-V:CarFreqThold-SP', 0.0, 0],
    ['BO-Glob:DI-Tune-V:DriveAuto-Sel', 0, 0],
    ['BO-Glob:DI-Tune-V:NoiseAmpl-SP', 0.0, 0],
    ['BO-Glob:DI-TuneProc-V:EnblTrkGen-Sel', 0, 0],
    ['BO-Glob:DI-TuneProc-V:AttIn-Sel', 0, 0],
    ['BO-Glob:DI-TuneProc-V:EnblAttAuto-Sel', 0, 0],
    ['BO-Glob:DI-TuneProc-V:ImpdIn-Sel', 0, 0],
    ['BO-Glob:DI-TuneProc-V:RoscSrc-Sel', 0, 0],
    ['BO-Glob:DI-TuneProc-V:TrkGenLvl-SP', 0.0, 0],
    ['BO-Glob:DI-TuneProc-V:TrkGenLvlOffset-SP', 0.0, 0],
    ['BO-Glob:DI-TuneProc-V:GetSpectrum-Sel', 0, 0],
    ['BO-Glob:DI-TuneProc-V:TrigSrc-Sel', 0, 0],
    ['BO-Glob:DI-TuneProc-V:DispRange-SP', 0.0, 0],
    ['BO-Glob:DI-TuneProc-V:FiltType-Sel', 0, 0],

    ['SI-Glob:DI-Tune-H:FreqOff-SP', 0.0, 0],
    ['SI-Glob:DI-Tune-H:RevN-SP', 0.0, 0],
    ['SI-Glob:DI-Tune-H:CenterFreq-SP', 0.0, 0],
    ['SI-Glob:DI-Tune-H:CenterFreqAuto-Sel', 0, 0],
    ['SI-Glob:DI-Tune-H:SpecAnaRBW-Sel', 0, 0],
    ['SI-Glob:DI-Tune-H:SpecAnaGetSpec-Sel', 0, 0],
    ['SI-Glob:DI-Tune-H:ROIOffsetX-SP', 0.0, 0],
    ['SI-Glob:DI-Tune-H:ROIOffsetY-SP', 0.0, 0],
    ['SI-Glob:DI-Tune-H:ROIWidth-SP', 0.0, 0],
    ['SI-Glob:DI-Tune-H:ROIHeight-SP', 0.0, 0],
    ['SI-Glob:DI-Tune-H:ROIAuto-Sel', 0, 0],
    ['SI-Glob:DI-Tune-H:AmpGain-SP', 0.0, 0],
    ['SI-Glob:DI-Tune-H:RFFreq-Mon.INP', '', 0],
    ['SI-Glob:DI-Tune-H:SIH-Cte.INP', '', 0],
    ['SI-Glob:DI-Tune-H:BOH-Cte.INP', '', 0],
    ['SI-Glob:DI-Tune-H:SpecAnaTrkGenLvl-SP', 0.0, 0],
    ['SI-Glob:DI-TuneProc-H:EnblTrkGen-Sel', 0, 0],
    ['SI-Glob:DI-TuneProc-H:AttIn-Sel', 0, 0],
    ['SI-Glob:DI-TuneProc-H:EnblAttAuto-Sel', 0, 0],
    ['SI-Glob:DI-TuneProc-H:ImpdIn-Sel', 0, 0],
    ['SI-Glob:DI-TuneProc-H:RoscSrc-Sel', 0, 0],
    ['SI-Glob:DI-TuneProc-H:TrkGenLvlOffset-SP', 0.0, 0],
    ['SI-Glob:DI-TuneProc-H:GetSpectrum-Sel', 0, 0],
    ['SI-Glob:DI-TuneProc-H:TrigSrc-Sel', 0, 0],
    ['SI-Glob:DI-TuneProc-H:DispRange-SP', 0.0, 0],
    ['SI-Glob:DI-TuneProc-H:FiltType-Sel', 0, 0],

    ['SI-Glob:DI-Tune-V:FreqOff-SP', 0.0, 0],
    ['SI-Glob:DI-Tune-V:RevN-SP', 0.0, 0],
    ['SI-Glob:DI-Tune-V:CenterFreq-SP', 0.0, 0],
    ['SI-Glob:DI-Tune-V:CenterFreqAuto-Sel', 0, 0],
    ['SI-Glob:DI-Tune-V:SpecAnaRBW-Sel', 0, 0],
    ['SI-Glob:DI-Tune-V:SpecAnaGetSpec-Sel', 0, 0],
    ['SI-Glob:DI-Tune-V:ROIOffsetX-SP', 0.0, 0],
    ['SI-Glob:DI-Tune-V:ROIOffsetY-SP', 0.0, 0],
    ['SI-Glob:DI-Tune-V:ROIWidth-SP', 0.0, 0],
    ['SI-Glob:DI-Tune-V:ROIHeight-SP', 0.0, 0],
    ['SI-Glob:DI-Tune-V:ROIAuto-Sel', 0, 0],
    ['SI-Glob:DI-Tune-V:AmpGain-SP', 0.0, 0],
    ['SI-Glob:DI-Tune-V:RFFreq-Mon.INP', '', 0],
    ['SI-Glob:DI-Tune-V:SIH-Cte.INP', '', 0],
    ['SI-Glob:DI-Tune-V:BOH-Cte.INP', '', 0],
    ['SI-Glob:DI-Tune-V:SpecAnaTrkGenLvl-SP', 0.0, 0],
    ['SI-Glob:DI-TuneProc-V:EnblTrkGen-Sel', 0, 0],
    ['SI-Glob:DI-TuneProc-V:AttIn-Sel', 0, 0],
    ['SI-Glob:DI-TuneProc-V:EnblAttAuto-Sel', 0, 0],
    ['SI-Glob:DI-TuneProc-V:ImpdIn-Sel', 0, 0],
    ['SI-Glob:DI-TuneProc-V:RoscSrc-Sel', 0, 0],
    ['SI-Glob:DI-TuneProc-V:TrkGenLvlOffset-SP', 0.0, 0],
    ['SI-Glob:DI-TuneProc-V:GetSpectrum-Sel', 0, 0],
    ['SI-Glob:DI-TuneProc-V:TrigSrc-Sel', 0, 0],
    ['SI-Glob:DI-TuneProc-V:DispRange-SP', 0.0, 0],
    ['SI-Glob:DI-TuneProc-V:FiltType-Sel', 0, 0],
    ]

# When using this type of configuration to set the machine,
# the list of PVs should be processed in the same order they are stored
# in the configuration. The second numeric parameter in the pair is the
# delay [s] the client should wait before setting the next PV.

_template_dict = {
    'pvs':
        _li_diags + _bpm_pvs + _scrn_pvs + _vlightcam_pvs + _dcct_pvs +
        _ict_pvs + _slit_pvs + _tune_pvs}
